<?php
/**
 * Spacious Pro Theme Customizer
 *
 * @package    ThemeGrill
 * @subpackage Spacious
 * @since      Spacious 1.2.1
 */
function spacious_customize_register( $wp_customize ) {

	// Transport postMessage variable set
	$customizer_selective_refresh = isset( $wp_customize->selective_refresh ) ? 'postMessage' : 'refresh';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '#site-title a',
			'render_callback' => 'spacious_customize_partial_blogname',
		) );

		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '#site-description',
			'render_callback' => 'spacious_customize_partial_blogdescription',
		) );
	}

	// Theme important links started
	class Spacious_Important_Links extends WP_Customize_Control {

		public $type = "spacious-important-links";

		public function render_content() {
			//Add Theme instruction, Support Forum, Demo Link, Rating Link
			$important_links = array(
				'support'       => array(
					'link' => esc_url( 'https://themegrill.com/support-forum/' ),
					'text' => __( 'Support Forum', 'spacious' ),
				),
				'documentation' => array(
					'link' => esc_url( 'https://docs.themegrill.com/spacious/' ),
					'text' => __( 'Documentation', 'spacious' ),
				),
				'demo'          => array(
					'link' => esc_url( 'https://demo.themegrill.com/spacious-pro/' ),
					'text' => __( 'View Demo', 'spacious' ),
				),
			);
			foreach ( $important_links as $important_link ) {
				echo '<p><a target="_blank" href="' . $important_link[ 'link' ] . '" >' . esc_attr( $important_link[ 'text' ] ) . ' </a></p>';
			}
			?>
			<?php
		}

	}

	$wp_customize->add_section( 'spacious_important_links', array(
		'priority' => 700,
		'title'    => __( 'Spacious Pro', 'spacious' ),
	) );

	/**
	 * This setting has the dummy Sanitization function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'spacious_important_links', array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_links_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Important_Links( $wp_customize, 'important_links', array(
		'section'  => 'spacious_important_links',
		'settings' => 'spacious_important_links',
	) ) );

	// Theme Important Links Ended

	class Spacious_Editor_Custom_Control extends WP_Customize_Control {

		public $type = "spacious_editor_control";

		public function render_content() {
			static $i = 1;
			?>
			<script type="text/javascript">
				(function ( $ ) {
					wp.customizerCtrlEditor = {
						init : function () {

							$( window ).load( function () {

								$( 'textarea.wp-editor-area' ).each( function () {
									var tArea  = $( this ),
										id     = tArea.attr( 'id' ),
										name   = tArea.attr( 'name' ),
										input  = $( 'input[data-customize-setting-link="' + name + '"]' ),
										editor = tinyMCE.get( id ),
										setChange,
										content;

									if ( editor ) {
										editor.on( 'change', function ( e ) {
											editor.save();
											content = editor.getContent();
											clearTimeout( setChange );
											setChange = setTimeout( function () {
												input.val( content ).trigger( 'change' );
											}, 500 );
										} );
									}

									tArea.css( {
										visibility : 'visible'
									} ).on( 'keyup', function () {
										content = tArea.val();
										clearTimeout( setChange );
										setChange = setTimeout( function () {
											input.val( content ).trigger( 'change' );
										}, 500 );
									} );
								} );
							} );
						}
					};
					wp.customizerCtrlEditor.init();
				})( jQuery );
			</script>
			<style type="text/css">
				.wp-full-overlay {
					z-index: unset !important;
				}
			</style>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<input type="hidden" <?php $this->link(); ?> value="<?php echo esc_textarea( $this->value() ); ?>">
			</label>
			<?php
			$settings = array(
				'textarea_name' => $this->id,
				'teeny'         => true,
			);
			$new_id   = str_replace( array( '[', ']' ), '', $this->id );
			wp_editor( htmlspecialchars_decode( $this->value() ), $new_id, $settings );

			if ( $i == 2 ) {
				do_action( 'admin_print_footer_scripts' );
			}
			$i ++;
			?>
			<?php
		}

	}


	/****************************************Start of the Header Options****************************************/

	// Header Options Area
	$wp_customize->add_panel( 'spacious_header_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 500,
		'title'      => __( 'Header', 'spacious' ),
	) );

	// Header Logo upload option
	$wp_customize->add_section( 'spacious_header_logo', array(
		'priority' => 1,
		'title'    => __( 'Header Logo', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	if ( ! function_exists( 'the_custom_logo' ) ) {
		$wp_customize->add_setting( 'spacious[spacious_header_logo_image]', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'spacious[spacious_header_logo_image]', array(
			'label'   => __( 'Upload logo for your header.', 'spacious' ),
			'section' => 'spacious_header_logo',
			'setting' => 'spacious[spacious_header_logo_image]',
		) ) );
	}

	// Header logo and text display type option
	$wp_customize->add_section( 'spacious_show_option', array(
		'priority' => 2,
		'title'    => __( 'Show', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_show_header_logo_text]', array(
		'default'           => 'text_only',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_show_header_logo_text]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose the option that you want.', 'spacious' ),
		'section' => 'spacious_show_option',
		'choices' => array(
			'logo_only' => __( 'Header Logo Only', 'spacious' ),
			'text_only' => __( 'Header Text Only', 'spacious' ),
			'both'      => __( 'Show Both', 'spacious' ),
			'none'      => __( 'Disable', 'spacious' ),
		),
	) );

	// Header display type option
	$wp_customize->add_section( 'spacious_header_display_type_option', array(
		'priority' => 2,
		'title'    => __( 'Header Display Type', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_header_display_type]', array(
		'default'           => 'one',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_header_display_type]', array(
		'type'    => 'radio',
		'label'   => esc_html__( 'Choose the header display type that you want.', 'spacious' ),
		'section' => 'spacious_header_display_type_option',
		'choices' => array(
			'one'   => esc_html__( 'Type 1 (Default): Header text & logo on left, menu on the right', 'spacious' ),
			'two'   => esc_html__( 'Type 2: Menu on left, header text & logo on right', 'spacious' ),
			'three' => esc_html__( 'Type 3: Menu, header text & logo all on center', 'spacious' ),
		),
	) );

	// Header Top bar activate option
	$wp_customize->add_section( 'spacious_header_top_bar_activate_section', array(
		'priority' => 2,
		'title'    => __( 'Activate Header Top Bar', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_activate_top_header_bar]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_activate_top_header_bar]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to show top header bar. The top header bar includes social icons area, small text area and menu area.', 'spacious' ),
		'section'  => 'spacious_header_top_bar_activate_section',
		'settings' => 'spacious[spacious_activate_top_header_bar]',
	) );

	// Header top bar display type option
	$wp_customize->add_section( 'spacious_header_top_bar_display_type_option', array(
		'priority' => 2,
		'title'    => __( 'Header Top Bar Display Type', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_top_bar_display_type]', array(
		'default'           => 'one',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_top_bar_display_type]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose top bar display type.', 'spacious' ),
		'section' => 'spacious_header_top_bar_display_type_option',
		'choices' => array(
			'one' => __( 'Type 1 (Default): Social icons & small text area on left, menu area on right', 'spacious' ),
			'two' => __( 'Type 2: Social icons & small text area on right, menu area on left', 'spacious' ),
		),
	) );

	// Header area small text option
	$wp_customize->add_section( 'spacious_header_small_text_section', array(
		'priority' => 2,
		'title'    => __( 'Header Info Text', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_header_info_text]', array(
		'default'           => '',
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_editor_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Editor_Custom_Control( $wp_customize, 'spacious[spacious_header_info_text]', array(
		'label'   => __( 'You can add phone numbers, other contact info here as you like. This box also accepts shortcodes.', 'spacious' ),
		'section' => 'spacious_header_small_text_section',
		'setting' => 'spacious[spacious_header_info_text]',
	) ) );

	// Selective refresh for header information text
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_header_info_text]', array(
			'selector'        => '.small-info-text p',
			'render_callback' => 'spacious_header_info_text',
		) );
	}

	// Header image position option
	$wp_customize->add_section( 'spacious_header_image_position_section', array(
		'priority' => 3,
		'title'    => __( 'Header Image Position', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_header_image_position]', array(
		'default'           => 'above',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_header_image_position]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose top header image display position.', 'spacious' ),
		'section' => 'spacious_header_image_position_section',
		'choices' => array(
			'above' => __( 'Position Above (Default): Display the Header image just above the site title and main menu part.', 'spacious' ),
			'below' => __( 'Position Below: Display the Header image just below the site title and main menu part.', 'spacious' ),
		),
	) );

	// make header image as link option
	$wp_customize->add_setting( 'spacious[spacious_header_image_link]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_header_image_link]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to make header image link back to home page.', 'spacious' ),
		'section'  => 'spacious_header_image_position_section',
		'settings' => 'spacious[spacious_header_image_link]',
	) );

	// make header image as link option
	$wp_customize->add_setting( 'spacious[spacious_header_image_link_to_other_sites]', array(
		'default'           => '',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'spacious[spacious_header_image_link_to_other_sites]', array(
		'label'    => __( 'Add the url here for the header image to link it to the other pages.', 'spacious' ),
		'section'  => 'spacious_header_image_position_section',
		'settings' => 'spacious[spacious_header_image_link_to_other_sites]',
	) );

	// BreadCrumb custom text option
	$wp_customize->add_section( 'spacious_custom_breadcrumb_text_section', array(
		'priority' => 3,
		'title'    => __( 'BreadCrumb Custom Text', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_custom_breadcrumb_text]', array(
		'default'           => __( 'You are here:', 'spacious' ),
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'wp_filter_nohtml_kses',
	) );

	$wp_customize->add_control( 'spacious[spacious_custom_breadcrumb_text]', array(
		'label'    => __( 'Change the BreadCrumb text as your requirement.', 'spacious' ),
		'section'  => 'spacious_custom_breadcrumb_text_section',
		'settings' => 'spacious[spacious_custom_breadcrumb_text]',
	) );

	// Selective refresh for BreadCrumb custom text
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_custom_breadcrumb_text]', array(
			'selector'        => '.breadcrumb',
			'render_callback' => 'spacious_breadcrumb',
		) );
	}

	// New Responsive Menu
	$wp_customize->add_section( 'spacious_new_menu', array(
		'priority' => 8,
		'title'    => __( 'Responsive Menu Style', 'spacious' ),
		'panel'    => 'spacious_header_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_new_menu]', array(
		'default'           => '1',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_new_menu]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Switch to new responsive menu.', 'spacious' ),
		'section' => 'spacious_new_menu',
	) );
	// End of Header Options


	/*************************************Start of the Social Links Options*************************************/

	$wp_customize->add_panel( 'spacious_social_links_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 510,
		'title'      => __( 'Social Links', 'spacious' ),
	) );

	// Social links activate option
	$wp_customize->add_section( 'spacious_social_links_setting', array(
		'priority' => 1,
		'title'    => __( 'Activate social links area', 'spacious' ),
		'panel'    => 'spacious_social_links_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_activate_social_links]', array(
		'default'           => 0,
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_activate_social_links]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to activate social links area. You also need to activate the header top bar section in Header options to show this social links area', 'spacious' ),
		'section'  => 'spacious_social_links_setting',
		'settings' => 'spacious[spacious_activate_social_links]',
	) );

	// Selective refresh for social links enable
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_activate_social_links]', array(
			'selector'        => '.social-links',
			'render_callback' => '',
		) );
	}

	$spacious_social_links = array(
		'spacious_social_facebook'    => __( 'Facebook', 'spacious' ),
		'spacious_social_twitter'     => __( 'Twitter', 'spacious' ),
		'spacious_social_googleplus'  => __( 'GooglePlus', 'spacious' ),
		'spacious_social_instagram'   => __( 'Instagram', 'spacious' ),
		'spacious_social_codepen'     => __( 'CodePen', 'spacious' ),
		'spacious_social_digg'        => __( 'Digg', 'spacious' ),
		'spacious_social_dribbble'    => __( 'Dribbble', 'spacious' ),
		'spacious_social_flickr'      => __( 'Flickr', 'spacious' ),
		'spacious_social_github'      => __( 'GitHub', 'spacious' ),
		'spacious_social_linkedin'    => __( 'LinkedIn', 'spacious' ),
		'spacious_social_pinterest'   => __( 'Pinterest', 'spacious' ),
		'spacious_social_polldaddy'   => __( 'Polldaddy', 'spacious' ),
		'spacious_social_pocket'      => __( 'Pocket', 'spacious' ),
		'spacious_social_reddit'      => __( 'Reddit', 'spacious' ),
		'spacious_social_skype'       => __( 'Skype', 'spacious' ),
		'spacious_social_stumbleupon' => __( 'StumbleUpon', 'spacious' ),
		'spacious_social_tumblr'      => __( 'Tumblr', 'spacious' ),
		'spacious_social_vimeo'       => __( 'Vimeo', 'spacious' ),
		'spacious_social_wordpress'   => __( 'WordPress', 'spacious' ),
		'spacious_social_youtube'     => __( 'YouTube', 'spacious' ),
		'spacious_social_rss'         => __( 'RSS', 'spacious' ),
		'spacious_social_mail'        => __( 'Mail', 'spacious' ),
	);

	$i = 1;
	foreach ( $spacious_social_links as $key => $value ) {

		$wp_customize->add_section( 'spacious_social_sites_section' . $i, array(
			'priority' => 2,
			'title'    => $value,
			'panel'    => 'spacious_social_links_options',
		) );

		// adding social sites link
		$wp_customize->add_setting( 'spacious[' . $key . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'spacious[' . $key . ']', array(
			'label'   => sprintf( __( 'Add link for %1$s', 'spacious' ), $value ),
			'section' => 'spacious_social_sites_section' . $i,
			'setting' => 'spacious[' . $key . ']',
		) );

		// adding social open in new page tab setting
		$wp_customize->add_setting( 'spacious[' . $key . 'new_tab]', array(
			'default'           => 0,
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_checkbox_sanitize',
		) );

		$wp_customize->add_control( 'spacious[' . $key . 'new_tab]', array(
			'type'    => 'checkbox',
			'label'   => __( 'Check to show in new tab', 'spacious' ),
			'section' => 'spacious_social_sites_section' . $i,
			'setting' => 'spacious[' . $key . 'new_tab]',
		) );

		$i ++;

	}

	// Additional Social Icons setting
	class Spacious_Additional_Social_Icons_Control extends WP_Customize_Control {

		public $type = 'spacious-additional-social-icons';

		public function render_content() {
			_e( 'Add font awesome icon name. Example: soundcloud. You can find list <a href="http://fortawesome.github.io/Font-Awesome/icons/">here</a>', 'spacious' );
			?>
			<input type="text" value="<?php echo sanitize_text_field( $this->value() ); ?>" <?php $this->link(); ?>>
		<?php }

	}

	// Adding additional custom social links
	$spacious_social_links_additional_icons = array(
		'spacious_social_additional_icon_one'   => __( 'Additional Social Icon One', 'spacious' ),
		'spacious_social_additional_icon_two'   => __( 'Additional Social Icon Two', 'spacious' ),
		'spacious_social_additional_icon_three' => __( 'Additional Social Icon Three', 'spacious' ),
		'spacious_social_additional_icon_four'  => __( 'Additional Social Icon Four', 'spacious' ),
		'spacious_social_additional_icon_five'  => __( 'Additional Social Icon Five', 'spacious' ),
	);

	$wp_customize->add_section( 'spacious_social_sites_additional_section', array(
		'priority' => 3,
		'title'    => __( 'Additional Social Icons', 'spacious' ),
		'panel'    => 'spacious_social_links_options',
	) );

	$i = 1;
	foreach ( $spacious_social_links_additional_icons as $key => $value ) {

		// adding social sites link
		$wp_customize->add_setting( 'spacious[' . $key . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'spacious[' . $key . ']', array(
			'label'   => sprintf( __( 'Add link for %1$s', 'spacious' ), $value ),
			'section' => 'spacious_social_sites_additional_section',
			'setting' => 'spacious[' . $key . ']',
		) );

		// font-awesome call
		$wp_customize->add_setting( 'spacious[' . $key . '_fontawesome]', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
		) );

		$wp_customize->add_control( new Spacious_Additional_Social_Icons_Control( $wp_customize, 'spacious[' . $key . '_fontawesome]', array(
			'section' => 'spacious_social_sites_additional_section',
			'setting' => 'spacious[' . $key . '_fontawesome]',
		) ) );

		// icons color
		$wp_customize->add_setting( 'spacious[' . $key . '_color]', array(
			'default'              => '',
			'type'                 => 'option',
			'capability'           => 'edit_theme_options',
			'sanitize_callback'    => 'spacious_color_option_hex_sanitize',
			'sanitize_js_callback' => 'spacious_color_escaping_option_sanitize',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'spacious[' . $key . '_color]', array(
			'label'   => __( 'Add color for icon.', 'spacious' ),
			'section' => 'spacious_social_sites_additional_section',
			'setting' => 'spacious[' . $key . '_color]',
		) ) );

		// adding social open in new page tab setting
		$wp_customize->add_setting( 'spacious[' . $key . 'new_tab]', array(
			'default'           => 0,
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_checkbox_sanitize',
		) );

		$wp_customize->add_control( 'spacious[' . $key . 'new_tab]', array(
			'type'    => 'checkbox',
			'label'   => __( 'Check to show in new tab', 'spacious' ),
			'section' => 'spacious_social_sites_additional_section',
			'setting' => 'spacious[' . $key . 'new_tab]',
		) );

		$i ++;

	}
	// End of Social Links Options


	/****************************************Start of the Slider Options****************************************/
	// Adding Text Area Control For Use In Customizer
	class Spacious_Text_Area_Control extends WP_Customize_Control {

		public $type = 'text_area';

		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}

	}

	$wp_customize->add_panel( 'spacious_slider_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 520,
		'title'      => __( 'Slider', 'spacious' ),
	) );

	// Slider activate option
	$wp_customize->add_section( 'spacious_slider_activate_section', array(
		'priority' => 1,
		'title'    => __( 'Activate slider', 'spacious' ),
		'panel'    => 'spacious_slider_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_activate_slider]', array(
		'default'           => 0,
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_activate_slider]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to activate slider.', 'spacious' ),
		'section'  => 'spacious_slider_activate_section',
		'settings' => 'spacious[spacious_activate_slider]',
	) );

	// Selective refresh for slider activate
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_activate_slider]', array(
			'selector'        => '#featured-slider',
			'render_callback' => '',
		) );
	}

	// Slider status option
	$wp_customize->add_section( 'spacious_slider_status_setting', array(
		'priority' => 2,
		'title'    => __( 'Slider Status', 'spacious' ),
		'panel'    => 'spacious_slider_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_slider_status]', array(
		'default'           => 'home_front_page',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_status]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose the slider status that you want.', 'spacious' ),
		'choices' => array(
			'home_front_page' => __( 'Slider on Front and blog page', 'spacious' ),
			'front_only'      => __( 'Slider on Front page only', 'spacious' ),
			'all_page'        => __( 'Slider on all pages', 'spacious' ),
		),
		'section' => 'spacious_slider_status_setting',
	) );

	// Slider setting option
	$wp_customize->add_section( 'spacious_slider_setting_section', array(
		'priority' => 3,
		'title'    => __( 'Slider Settings', 'spacious' ),
		'panel'    => 'spacious_slider_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_slider_transition_effect]', array(
		'default'           => 'fade',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_slider_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_transition_effect]', array(
		'type'    => 'select',
		'label'   => __( 'Slider transition effect', 'spacious' ) . '  ' . __( 'Choose the transition effect that you like. Default is "fade".', 'spacious' ),
		'setting' => 'spacious[spacious_slider_transition_effect]',
		'section' => 'spacious_slider_setting_section',
		'choices' => array(
			'fade'       => __( 'Fade', 'spacious' ),
			'fadeout'    => __( 'FadeOut', 'spacious' ),
			'none'       => __( 'None', 'spacious' ),
			'scrollHorz' => __( 'ScrollHorz', 'spacious' ),
			'flipHorz'   => __( 'FlipHorz', 'spacious' ),
			'flipVert'   => __( 'FlipVert', 'spacious' ),
			'tileBlind'  => __( 'TileBlind', 'spacious' ),
			'shuffle'    => __( 'Shuffle', 'spacious' ),
		),
	) );

	// Slider transition delay time
	$wp_customize->add_setting( 'spacious[spacious_slider_transition_delay]', array(
		'default'           => 4,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_slider_transition_delay_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_transition_delay]', array(
		'label'   => __( 'Slider transition delay time', 'spacious' ) . '  ' . __( 'Add number in seconds. Default is 4.', 'spacious' ),
		'setting' => 'spacious[spacious_slider_transition_delay]',
		'section' => 'spacious_slider_setting_section',
	) );

	// Slider transition length time
	$wp_customize->add_setting( 'spacious[spacious_slider_transition_length]', array(
		'default'           => 1,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_slider_transition_length_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_transition_length]', array(
		'label'   => __( 'Slider transition length time', 'spacious' ) . '  ' . __( 'Add number in seconds. Default is 1.', 'spacious' ),
		'setting' => 'spacious[spacious_slider_transition_length]',
		'section' => 'spacious_slider_setting_section',
	) );

	// slider number sanitize
	$wp_customize->add_setting( 'spacious[spacious_slider_number]', array(
		'default'           => 5,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_slider_number_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_number]', array(
		'label'   => __( 'Number of slides', 'spacious' ) . '  ' . __( 'Enter the number of slides you want then click save.', 'spacious' ),
		'setting' => 'spacious[spacious_slider_number]',
		'section' => 'spacious_slider_setting_section',
	) );

	// Slider image as link option
	$wp_customize->add_setting( 'spacious[spacious_slider_image_link_option]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_image_link_option]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to make the slider images link back to respective links.', 'spacious' ),
		'section'  => 'spacious_slider_setting_section',
		'settings' => 'spacious[spacious_slider_image_link_option]',
	) );

	// Enable next/prev option
	$wp_customize->add_setting( 'spacious[spacious_slider_next_prev_option]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_next_prev_option]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable next/prev option.', 'spacious' ),
		'section'  => 'spacious_slider_setting_section',
		'settings' => 'spacious[spacious_slider_next_prev_option]',
	) );

	// Enable pause on hover
	$wp_customize->add_setting( 'spacious[spacious_slider_pause_on_hover_option]', array(
		'default'           => 1,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_pause_on_hover_option]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable pause on hover.', 'spacious' ),
		'section'  => 'spacious_slider_setting_section',
		'settings' => 'spacious[spacious_slider_pause_on_hover_option]',
	) );

	// Enable progressbar
	$wp_customize->add_setting( 'spacious[spacious_slider_progressbar_option]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_slider_progressbar_option]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable progressbar.', 'spacious' ),
		'section'  => 'spacious_slider_setting_section',
		'settings' => 'spacious[spacious_slider_progressbar_option]',
	) );
	/**
	 * Image upload options
	 */
	$num_of_slides = spacious_options( 'spacious_slider_number', '5' );

	for ( $i = 1; $i <= $num_of_slides; $i ++ ) {
		// adding slider section
		$wp_customize->add_section( 'spacious_slider_number_section' . $i, array(
			'priority' => 10,
			'title'    => sprintf( __( 'Image Upload #%1$s', 'spacious' ), $i ),
			'panel'    => 'spacious_slider_options',
		) );

		// adding slider image url
		$wp_customize->add_setting( 'spacious[spacious_slider_image' . $i . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'spacious[spacious_slider_image' . $i . ']', array(
			'label'   => __( 'Upload slider image.', 'spacious' ),
			'section' => 'spacious_slider_number_section' . $i,
			'setting' => 'spacious[spacious_slider_image' . $i . ']',
		) ) );

		// adding slider title
		$wp_customize->add_setting( 'spacious[spacious_slider_title' . $i . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
		) );

		$wp_customize->add_control( 'spacious[spacious_slider_title' . $i . ']', array(
			'label'   => __( 'Enter title for your slider.', 'spacious' ),
			'section' => 'spacious_slider_number_section' . $i,
			'setting' => 'spacious[spacious_slider_title' . $i . ']',
		) );

		// adding slider description
		$wp_customize->add_setting( 'spacious[spacious_slider_text' . $i . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_text_sanitize',
		) );

		$wp_customize->add_control( new Spacious_Text_Area_Control( $wp_customize, 'spacious[spacious_slider_text' . $i . ']', array(
			'label'   => __( 'Enter your slider description.', 'spacious' ),
			'section' => 'spacious_slider_number_section' . $i,
			'setting' => 'spacious[spacious_slider_text' . $i . ']',
		) ) );

		// adding slider text position
		$wp_customize->add_setting( 'spacious[spacious_slide_text_position' . $i . ']', array(
			'default'           => 'left',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_radio_sanitize',
		) );

		$wp_customize->add_control( 'spacious[spacious_slide_text_position' . $i . ']', array(
			'type'    => 'radio',
			'label'   => __( 'Slider text position.', 'spacious' ),
			'choices' => array(
				'right' => __( 'Right side', 'spacious' ),
				'left'  => __( 'Left side', 'spacious' ),
			),
			'section' => 'spacious_slider_number_section' . $i,
		) );

		// adding slider button text
		$wp_customize->add_setting( 'spacious[spacious_slider_button_text' . $i . ']', array(
			'default'           => __( 'Read more', 'spacious' ),
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
		) );

		$wp_customize->add_control( 'spacious[spacious_slider_button_text' . $i . ']', array(
			'label'   => __( 'Enter the button text. Default is "Read more"', 'spacious' ),
			'section' => 'spacious_slider_number_section' . $i,
			'setting' => 'spacious[spacious_slider_button_text' . $i . ']',
		) );

		// adding button url
		$wp_customize->add_setting( 'spacious[spacious_slider_link' . $i . ']', array(
			'default'           => '',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( 'spacious[spacious_slider_link' . $i . ']', array(
			'label'   => __( 'Enter link to redirect slider when clicked', 'spacious' ),
			'section' => 'spacious_slider_number_section' . $i,
			'setting' => 'spacious[spacious_slider_link' . $i . ']',
		) );
	}
	// End of Slider Options


	/****************************************Start of the Design Options****************************************/

	$wp_customize->add_panel( 'spacious_design_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 530,
		'title'      => __( 'Design', 'spacious' ),
	) );

	// site layout setting
	$wp_customize->add_section( 'spacious_site_layout_setting', array(
		'priority' => 1,
		'title'    => __( 'Site Layout', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_site_layout]', array(
		'default'           => 'box_1218px',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_site_layout]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose your site layout. The change is reflected in whole site.', 'spacious' ),
		'choices' => array(
			'box_1218px'  => __( 'Boxed layout with content width of 1218px', 'spacious' ),
			'box_978px'   => __( 'Boxed layout with content width of 978px', 'spacious' ),
			'wide_1218px' => __( 'Wide layout with content width of 1218px', 'spacious' ),
			'wide_978px'  => __( 'Wide layout with content width of 978px', 'spacious' ),
		),
		'section' => 'spacious_site_layout_setting',
	) );

	class Spacious_Image_Radio_Control extends WP_Customize_Control {

		public function render_content() {

			if ( empty( $this->choices ) ) {
				return;
			}

			$name = '_customize-radio-' . $this->id;

			?>
			<style>
				#spacious-img-container .spacious-radio-img-img {
					border: 3px solid #DEDEDE;
					margin: 0 5px 5px 0;
					cursor: pointer;
					border-radius: 3px;
					-moz-border-radius: 3px;
					-webkit-border-radius: 3px;
				}

				#spacious-img-container .spacious-radio-img-selected {
					border: 3px solid #AAA;
					border-radius: 3px;
					-moz-border-radius: 3px;
					-webkit-border-radius: 3px;
				}

				input[type=checkbox]:before {
					content: '';
					margin: -3px 0 0 -4px;
				}
			</style>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<ul class="controls" id='spacious-img-container'>
				<?php
				foreach ( $this->choices as $value => $label ) :
					$class = ( $this->value() == $value ) ? 'spacious-radio-img-selected spacious-radio-img-img' : 'spacious-radio-img-img';
					?>
					<li style="display: inline;">
						<label>
							<input <?php $this->link(); ?>style='display:none' type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link();
							checked( $this->value(), $value ); ?> />
							<img src='<?php echo esc_html( $label ); ?>' class='<?php echo $class; ?>'/>
						</label>
					</li>
					<?php
				endforeach;
				?>
			</ul>
			<script type="text/javascript">
				jQuery( document ).ready( function ( $ ) {
					$( '.controls#spacious-img-container li img' ).click( function () {
						$( '.controls#spacious-img-container li' ).each( function () {
							$( this ).find( 'img' ).removeClass( 'spacious-radio-img-selected' );
						} );
						$( this ).addClass( 'spacious-radio-img-selected' );
					} );
				} );
			</script>
			<?php
		}
	}

	// Site dark light skin option
	$wp_customize->add_section( 'spacious_color_skin_setting', array(
		'priority' => 2,
		'title'    => __( 'Color Skin', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_color_skin]', array(
		'default'           => 'light',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_color_skin]', array(
		'type'     => 'radio',
		'label'    => __( 'Choose the light or dark skin. This will be reflected in whole site.', 'spacious' ),
		'section'  => 'spacious_color_skin_setting',
		'settings' => 'spacious[spacious_color_skin]',
		'choices'  => array(
			'light' => SPACIOUS_ADMIN_IMAGES_URL . '/light-color.jpg',
			'dark'  => SPACIOUS_ADMIN_IMAGES_URL . '/dark-color.jpg',
		),
	) ) );

	// default layout setting
	$wp_customize->add_section( 'spacious_default_layout_setting', array(
		'priority' => 3,
		'title'    => __( 'Default layout', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_default_layout]', array(
		'default'           => 'right_sidebar',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_default_layout]', array(
		'type'     => 'radio',
		'label'    => __( 'Select default layout. This layout will be reflected in whole site archives, search etc. The layout for a single post and page can be controlled from below options.', 'spacious' ),
		'section'  => 'spacious_default_layout_setting',
		'settings' => 'spacious[spacious_default_layout]',
		'choices'  => array(
			'right_sidebar'               => SPACIOUS_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar'                => SPACIOUS_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width'       => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
		),
	) ) );

	// default layout for pages
	$wp_customize->add_section( 'spacious_default_page_layout_setting', array(
		'priority' => 4,
		'title'    => __( 'Default layout for pages only', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_pages_default_layout]', array(
		'default'           => 'right_sidebar',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_pages_default_layout]', array(
		'type'     => 'radio',
		'label'    => __( 'Select default layout for pages. This layout will be reflected in all pages unless unique layout is set for specific page.', 'spacious' ),
		'section'  => 'spacious_default_page_layout_setting',
		'settings' => 'spacious[spacious_pages_default_layout]',
		'choices'  => array(
			'right_sidebar'               => SPACIOUS_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar'                => SPACIOUS_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width'       => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
		),
	) ) );

	// default layout for single posts
	$wp_customize->add_section( 'spacious_default_single_posts_layout_setting', array(
		'priority' => 5,
		'title'    => __( 'Default layout for single posts only', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_single_posts_default_layout]', array(
		'default'           => 'right_sidebar',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_single_posts_default_layout]', array(
		'type'     => 'radio',
		'label'    => __( 'Select default layout for single posts. This layout will be reflected in all single posts unless unique layout is set for specific post.', 'spacious' ),
		'section'  => 'spacious_default_single_posts_layout_setting',
		'settings' => 'spacious[spacious_single_posts_default_layout]',
		'choices'  => array(
			'right_sidebar'               => SPACIOUS_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar'                => SPACIOUS_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width'       => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
		),
	) ) );

	// blog posts display type setting
	$wp_customize->add_section( 'spacious_archive_category_posts_display_type_setting', array(
		'priority' => 6,
		'title'    => __( 'Blog Posts display type', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_archive_display_type]', array(
		'default'           => 'blog_large',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_archive_display_type]', array(
		'type'    => 'radio',
		'label'   => __( 'Choose the display type for the archive/category view.', 'spacious' ),
		'choices' => array(
			'blog_large'                  => __( 'Blog Image Large', 'spacious' ),
			'blog_medium'                 => __( 'Blog Image Medium', 'spacious' ),
			'blog_medium_alternate'       => __( 'Blog Image Alternate Medium', 'spacious' ),
			'blog_medium_round'           => __( 'Blog Image Round Medium', 'spacious' ),
			'blog_medium_round_alternate' => __( 'Blog Image Round Alternate Medium', 'spacious' ),
			'blog_full_content'           => __( 'Blog Full Content', 'spacious' ),
		),
		'section' => 'spacious_archive_category_posts_display_type_setting',
	) );

	// Site primary color option
	$wp_customize->add_section( 'spacious_primary_color_setting', array(
		'panel'    => 'spacious_design_options',
		'priority' => 7,
		'title'    => __( 'Primary color option', 'spacious' ),
	) );

	$wp_customize->add_setting( 'spacious[spacious_primary_color]', array(
		'default'              => '#0FBE7C',
		'type'                 => 'option',
		'transport'            => 'postMessage',
		'capability'           => 'edit_theme_options',
		'sanitize_callback'    => 'spacious_color_option_hex_sanitize',
		'sanitize_js_callback' => 'spacious_color_escaping_option_sanitize',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'spacious[spacious_primary_color]', array(
		'label'    => __( 'This will reflect in links, buttons and many others. Choose a color to match your site.', 'spacious' ),
		'section'  => 'spacious_primary_color_setting',
		'settings' => 'spacious[spacious_primary_color]',
	) ) );

	if ( ! function_exists( 'wp_update_custom_css_post' ) ) {
		// Custom CSS setting
		class spacious_Custom_CSS_Control extends WP_Customize_Control {

			public $type = 'custom_css';

			public function render_content() {
				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
				</label>
				<?php
			}

		}

		$wp_customize->add_section( 'spacious_custom_css_setting', array(
			'priority' => 8,
			'title'    => __( 'Custom CSS', 'spacious' ),
			'panel'    => 'spacious_design_options',
		) );

		$wp_customize->add_setting( 'spacious[spacious_custom_css]', array(
			'default'              => '',
			'type'                 => 'option',
			'capability'           => 'edit_theme_options',
			'sanitize_callback'    => 'wp_filter_nohtml_kses',
			'sanitize_js_callback' => 'wp_filter_nohtml_kses',
		) );

		$wp_customize->add_control( new spacious_Custom_CSS_Control( $wp_customize, 'spacious[spacious_custom_css]', array(
			'label'    => __( 'Write your custom css.', 'spacious' ),
			'section'  => 'spacious_custom_css_setting',
			'settings' => 'spacious[spacious_custom_css]',
		) ) );
	}

	// Category options
	$wp_customize->add_section( 'spacious_category_options', array(
		'priority' => 9,
		'title'    => esc_html__( 'Category Options', 'spacious' ),
		'panel'    => 'spacious_design_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_term_description]', array(
		'default'           => 0,
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_term_description]', array(
		'type'     => 'checkbox',
		'label'    => esc_html__( 'Activate term description', 'spacious' ),
		'settings' => 'spacious[spacious_term_description]',
		'section'  => 'spacious_category_options',
	) );

	// Selective refresh for taxonomy description
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_term_description]', array(
			'selector'        => '.taxonomy-description',
			'render_callback' => 'spacious_taxonomy_description',
		) );
	}
	// End of Design Options


	/**************************************Start of the Additional Options**************************************/

	$wp_customize->add_panel( 'spacious_additional_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 540,
		'title'      => __( 'Additional', 'spacious' ),
	) );

	if ( ! function_exists( 'has_site_icon' ) || ( ! has_site_icon() && ( spacious_options( 'spacious_favicon', '' ) != '' ) ) ) {
		// Favicon activate option
		$wp_customize->add_section( 'spacious_additional_activate_section', array(
			'priority' => 1,
			'title'    => __( 'Activate favicon', 'spacious' ),
			'panel'    => 'spacious_additional_options',
		) );

		$wp_customize->add_setting( 'spacious[spacious_activate_favicon]', array(
			'default'           => 0,
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_checkbox_sanitize',
		) );

		$wp_customize->add_control( 'spacious[spacious_activate_favicon]', array(
			'type'     => 'checkbox',
			'label'    => __( 'Check to activate favicon. Upload fav icon from below option', 'spacious' ),
			'section'  => 'spacious_additional_activate_section',
			'settings' => 'spacious[spacious_activate_favicon]',
		) );

		// Fav icon upload option
		$wp_customize->add_section( 'spacious_favicon_upload_section', array(
			'priority' => 2,
			'title'    => __( 'Upload favicon', 'spacious' ),
			'panel'    => 'spacious_additional_options',
		) );

		$wp_customize->add_setting( 'spacious[spacious_favicon]', array(
			'default'           => 0,
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'spacious[spacious_favicon]', array(
			'label'    => __( 'Upload favicon for your site.', 'spacious' ),
			'section'  => 'spacious_favicon_upload_section',
			'settings' => 'spacious[spacious_favicon]',
		) ) );

	}

	// Sticky post and sidebar section
	$wp_customize->add_section( 'spacious_sticky_content_sidebar_setting', array(
		'priority' => 13,
		'title'    => esc_html__( 'Sticky Content And Sidebar', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_sticky_content_sidebar]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_sticky_content_sidebar]', array(
		'type'    => 'checkbox',
		'label'   => esc_html__( 'Check to activate the sticky options for content and sidebar areas.', 'spacious' ),
		'setting' => 'spacious[spacious_sticky_content_sidebar]',
		'section' => 'spacious_sticky_content_sidebar_setting',
	) );

	// Excerpt Options
	$wp_customize->add_section( 'spacious_excerpt_length_setting', array(
		'priority' => 3,
		'title'    => __( 'Excerpt Length', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_excerpt_length]', array(
		'default'           => 40,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_excerpt_length_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_excerpt_length]', array(
		'label'   => __( 'Enter the number of Words you wish to show on excerpt. Default value is 40 words.', 'spacious' ),
		'setting' => 'spacious[spacious_excerpt_length]',
		'section' => 'spacious_excerpt_length_setting',
	) );

	// excerpt text setting
	$wp_customize->add_section( 'spacious_excerpt_text_setting', array(
		'priority' => 4,
		'title'    => __( 'Excerpt Read More Text', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_read_more_text]', array(
		'default'           => __( 'Read more', 'spacious' ),
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'wp_filter_nohtml_kses',
	) );

	$wp_customize->add_control( 'spacious[spacious_read_more_text]', array(
		'label'   => __( 'Replace the default Read more text with your own words', 'spacious' ),
		'setting' => 'spacious[spacious_read_more_text]',
		'section' => 'spacious_excerpt_text_setting',
	) );

	// Selective refresh for read more text text
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_read_more_text]', array(
			'selector'        => '.read-more',
			'render_callback' => 'spacious_read_more_text_render',
		) );
	}

	// post meta full enable/disable
	$wp_customize->add_section( 'spacious_post_meta_full_setting', array(
		'priority' => 5,
		'title'    => __( 'Post Meta Display', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_post_meta_full]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_full]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the post meta for the post totally, ie, remove all of the meta data.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_full]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// author display in post meta
	$wp_customize->add_setting( 'spacious[spacious_post_meta_author]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_author]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the author only in the post meta section.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_author]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// date display in post meta
	$wp_customize->add_setting( 'spacious[spacious_post_meta_date]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_date]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the date only in the post meta section.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_date]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// category display in post meta
	$wp_customize->add_setting( 'spacious[spacious_post_meta_category]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_category]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the category only in the post meta section.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_category]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// comments display in post meta
	$wp_customize->add_setting( 'spacious[spacious_post_meta_comments]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_comments]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the comments only in the post meta section.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_comments]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// edit button display in post meta
	$wp_customize->add_setting( 'spacious[spacious_post_meta_edit_button]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_edit_button]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the edit button only in the post meta section.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_edit_button]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// tags display in just below the post
	$wp_customize->add_setting( 'spacious[spacious_post_meta_tags]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_post_meta_tags]', array(
		'type'    => 'checkbox',
		'label'   => __( 'Disable the tags display just below the post.', 'spacious' ),
		'setting' => 'spacious[spacious_post_meta_tags]',
		'section' => 'spacious_post_meta_full_setting',
	) );

	// Author Bio activate option
	$wp_customize->add_section( 'spacious_author_bio_section', array(
		'priority' => 5,
		'title'    => __( 'Author Bio', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_author_bio]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_author_bio]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable the author bio section just below the post.', 'spacious' ),
		'section'  => 'spacious_author_bio_section',
		'settings' => 'spacious[spacious_author_bio]',
	) );

	// Selective refresh for author bio
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_author_bio]', array(
			'selector'        => '.author-box',
			'render_callback' => '',
		) );
	}

	// author link
	$wp_customize->add_setting( 'spacious[spacious_author_bio_link]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_author_bio_link]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to add the all post link of author url in the author box.', 'spacious' ),
		'section'  => 'spacious_author_bio_section',
		'settings' => 'spacious[spacious_author_bio_link]',
	) );

	// author social links
	$wp_customize->add_setting( 'spacious[spacious_author_bio_social_link]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_author_bio_social_link]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to add the social links in the author bio section. Note: it suppots only the social icons provided by All In One SEO Pack or WordPress SEO plugin.', 'spacious' ),
		'section'  => 'spacious_author_bio_section',
		'settings' => 'spacious[spacious_author_bio_social_link]',
	) );

	// Featured image in single post page activate option
	$wp_customize->add_section( 'spacious_featured_image_single_post_page_section', array(
		'priority' => 6,
		'title'    => __( 'Featured Image In Single Post Page', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_featured_image_single_post_page]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_featured_image_single_post_page]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable the featured image in single post page.', 'spacious' ),
		'section'  => 'spacious_featured_image_single_post_page_section',
		'settings' => 'spacious[spacious_featured_image_single_post_page]',
	) );

	// Featured image in single page activate option
	$wp_customize->add_section( 'spacious_featured_image_single_page_section', array(
		'priority' => 6,
		'title'    => __( 'Featured Image In Single Page', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_featured_image_single_page]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_featured_image_single_page]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to enable the featured image in single page.', 'spacious' ),
		'section'  => 'spacious_featured_image_single_page_section',
		'settings' => 'spacious[spacious_featured_image_single_page]',
	) );

	// Scroll to top feature activate option
	$wp_customize->add_section( 'spacious_scroll_to_top_feature_section', array(
		'priority' => 6,
		'title'    => __( 'Scroll To Top Button', 'spacious' ),
		'panel'    => 'spacious_additional_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_scroll_to_top_feature]', array(
		'default'           => 0,
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_checkbox_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_scroll_to_top_feature]', array(
		'type'     => 'checkbox',
		'label'    => __( 'Check to disable the scroll to top button.', 'spacious' ),
		'section'  => 'spacious_scroll_to_top_feature_section',
		'settings' => 'spacious[spacious_scroll_to_top_feature]',
	) );
	// End of Additional Options


	/****************************************Start of the Footer Options****************************************/

	$wp_customize->add_panel( 'spacious_footer_options', array(
		'capabitity' => 'edit_theme_options',
		'priority'   => 545,
		'title'      => __( 'Footer', 'spacious' ),
	) );

	// Footer widgets select type
	$wp_customize->add_section( 'spacious_footer_column_select_section', array(
		'priority' => 5,
		'title'    => __( 'Footer Widgets Column', 'spacious' ),
		'panel'    => 'spacious_footer_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_footer_widget_column_select_type]', array(
		'default'           => 'four',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_footer_widget_column_select_type]', array(
		'type'    => 'select',
		'label'   => __( 'Choose the number of column for the footer widgetized areas.', 'spacious' ),
		'choices' => array(
			'one'   => __( 'One Column', 'spacious' ),
			'two'   => __( 'Two Column', 'spacious' ),
			'three' => __( 'Three Column', 'spacious' ),
			'four'  => __( 'Four Column', 'spacious' ),
		),
		'section' => 'spacious_footer_column_select_section',
	) );

	// Footer editor option
	$default_footer_value = __( 'Copyright &copy; ', 'spacious' ) . '[the-year] [site-link] ' . __( 'Theme by: ', 'spacious' ) . '[tg-link] ' . __( 'Powered by: ', 'spacious' ) . '[wp-link]';

	$wp_customize->add_section( 'spacious_footer_copyright_section', array(
		'priority' => 10,
		'title'    => __( 'Footer Copyright Editor', 'spacious' ),
		'panel'    => 'spacious_footer_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_footer_editor]', array(
		'default'           => $default_footer_value,
		'type'              => 'option',
		'transport'         => $customizer_selective_refresh,
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_footer_editor_sanitize',
	) );

	$wp_customize->add_control( new spacious_Editor_Custom_Control( $wp_customize, 'spacious[spacious_footer_editor]', array(
		'label'   => __( 'Edit the Copyright information in your footer. You can also use shortcodes [the-year], [site-link], [wp-link], [tg-link] for current year, your site link, WordPress site link and ThemeGrill site link respectively.', 'spacious' ),
		'section' => 'spacious_footer_copyright_section',
		'setting' => 'spacious[spacious_footer_editor]',
	) ) );

	// Selective refresh for footer copyright information
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'spacious[spacious_footer_editor]', array(
			'selector'        => '.copyright',
			'render_callback' => 'spacious_footer_copyright',
		) );
	}

	// Footer Copyright Layout
	$wp_customize->add_section( 'spacious_copyright_layout_section', array(
		'priority' => 15,
		'title'    => __( 'Copyright Alignment', 'spacious' ),
		'panel'    => 'spacious_footer_options',
	) );

	$wp_customize->add_setting( 'spacious[spacious_copyright_layout]', array(
		'default'           => 'left',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'spacious_radio_sanitize',
	) );

	$wp_customize->add_control( 'spacious[spacious_copyright_layout]', array(
		'type'    => 'select',
		'label'   => __( 'Display Copyright and Footer Menu either on left/right or on center Position.', 'spacious' ),
		'choices' => array(
			'left'   => __( 'Left/Right', 'spacious' ),
			'center' => __( 'Center', 'spacious' ),
		),
		'section' => 'spacious_copyright_layout_section',
	) );
	// End of Footer Options


	/***************************************Start of the Typography Option**************************************/

	$wp_customize->add_panel( 'spacious_typography_options', array(
		'priority'   => 550,
		'title'      => __( 'Typography', 'spacious' ),
		'capability' => 'edit_theme_options',
	) );

	// Font family options
	$wp_customize->add_section( 'spacious_google_fonts_settings', array(
		'priority' => 1,
		'title'    => __( 'Google Font Options', 'spacious' ),
		'panel'    => 'spacious_typography_options',
	) );

	$spacious_fonts = array(
		'spacious_site_title_font'   => array(
			'id'      => 'spacious[spacious_site_title_font]',
			'default' => 'Lato',
			'title'   => __( 'Site title font. Default is "Lato".', 'spacious' ),
		),
		'spacious_site_tagline_font' => array(
			'id'      => 'spacious[spacious_site_tagline_font]',
			'default' => 'Lato',
			'title'   => __( 'Site tagline font. Default is "Lato".', 'spacious' ),
		),
		'spacious_menu_font'         => array(
			'id'      => 'spacious[spacious_menu_font]',
			'default' => 'Lato',
			'title'   => __( 'Menu font. Default is "Lato".', 'spacious' ),
		),
		'spacious_titles_font'       => array(
			'id'      => 'spacious[spacious_titles_font]',
			'default' => 'Lato',
			'title'   => __( 'All Titles font. Default is "Lato".', 'spacious' ),
		),
		'spacious_content_font'      => array(
			'id'      => 'spacious[spacious_content_font]',
			'default' => 'Lato',
			'title'   => __( 'Content font and for others. Default is "Lato".', 'spacious' ),
		),
	);

	foreach ( $spacious_fonts as $spacious_font ) {

		$wp_customize->add_setting( $spacious_font[ 'id' ], array(
			'default'           => $spacious_font[ 'default' ],
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_font_sanitize',
		) );

		$spacious_google_fonts_choices = spacious_google_fonts();

		$wp_customize->add_control( $spacious_font[ 'id' ], array(
			'label'    => $spacious_font[ 'title' ],
			'type'     => 'select',
			'settings' => $spacious_font[ 'id' ],
			'section'  => 'spacious_google_fonts_settings',
			'choices'  => $spacious_google_fonts_choices,
		) );
	}

	// Font Size Option
	$spacious_fonts_size_options = spacious_font_size_func();

	foreach ( $spacious_fonts_size_options as $spacious_section ) {

		$wp_customize->add_section( $spacious_section[ 'section_id' ], array(
			'title' => $spacious_section[ 'title' ],
			'panel' => 'spacious_typography_options',
		) );

		$spacious_section_id        = $spacious_section[ 'section_id' ];
		$spacious_font_size_setting = $spacious_section[ 'spacious_font_size_setting' ];

		foreach ( $spacious_font_size_setting as $spacious_font_setting ) {

			$wp_customize->add_setting( 'spacious[' . $spacious_font_setting[ 'id' ] . ']', array(
				'default'           => $spacious_font_setting[ 'default' ],
				'type'              => 'option',
				'transport'         => 'postMessage',
				'capability'        => 'edit_theme_options',
				'sanitize_callback' => 'spacious_radio_sanitize',
			) );

			$wp_customize->add_control( 'spacious[' . $spacious_font_setting[ 'id' ] . ']', array(
				'label'    => $spacious_font_setting[ 'label' ],
				'type'     => 'select',
				'settings' => 'spacious[' . $spacious_font_setting[ 'id' ] . ']',
				'section'  => $spacious_section_id,
				'choices'  => $spacious_font_setting[ 'choice' ],
			) );
		}
	}
	// End of the Typography Options


	/*****************************************Start of the Color Options****************************************/

	$wp_customize->add_panel( 'spacious_color_options', array(
		'priority'   => 560,
		'title'      => __( 'Color', 'spacious' ),
		'capability' => 'edit_theme_options',
	) );

	$spacious_colors_options = spacious_color_func();

	foreach ( $spacious_colors_options as $spacious_color_section ) {

		$wp_customize->add_section( $spacious_color_section[ 'section_id' ], array(
			'title' => $spacious_color_section[ 'title' ],
			'panel' => 'spacious_color_options',
		) );

		$spacious_color_section_id = $spacious_color_section[ 'section_id' ];
		$spacious_color_settings   = $spacious_color_section[ 'spacious_color_settings' ];

		foreach ( $spacious_color_settings as $spacious_color_setting ) {

			$wp_customize->add_setting( 'spacious[' . $spacious_color_setting[ 'id' ] . ']', array(
				'default'              => $spacious_color_setting[ 'default' ],
				'type'                 => 'option',
				'transport'            => 'postMessage',
				'capability'           => 'edit_theme_options',
				'sanitize_callback'    => 'spacious_color_option_hex_sanitize',
				'sanitize_js_callback' => 'spacious_color_escaping_option_sanitize',
			) );

			$wp_customize->add_control(
				new WP_Customize_Color_Control( $wp_customize, 'spacious[' . $spacious_color_setting[ 'id' ] . ']', array(
					'label'    => $spacious_color_setting[ 'label' ],
					'settings' => 'spacious[' . $spacious_color_setting[ 'id' ] . ']',
					'section'  => $spacious_color_section_id,
				) )
			);
		}
	}

	$wp_customize->add_section( 'spacious_general_color_settings', array(
		'title' => __( 'General Color Options', 'spacious' ),
		'panel' => 'spacious_color_options',
	) );
	$wp_customize->add_setting( 'spacious[spacious_border_lines_color]', array(
		'default'              => '#EAEAEA',
		'type'                 => 'option',
		'capability'           => 'edit_theme_options',
		'sanitize_callback'    => 'spacious_color_option_hex_sanitize',
		'sanitize_js_callback' => 'spacious_color_escaping_option_sanitize',
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control( $wp_customize, 'spacious[spacious_border_lines_color]', array(
			'label'    => __( 'Border lines. These lines are used in various parts as seperator and as borders. Default is #EAEAEA.', 'spacious' ),
			'settings' => 'spacious[spacious_border_lines_color]',
			'section'  => 'spacious_general_color_settings',
		) )
	);
	// End of the Color Options


	/**************************************Start of the WooCommerce Options*************************************/

	if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {

		$wp_customize->add_panel( 'spacious_woocommerce_options', array(
			'priority'   => 570,
			'title'      => __( 'WooCommerce', 'spacious' ),
			'capability' => 'edit_theme_options',
		) );

		// woocommerce archive page layout
		$wp_customize->add_section( 'spacious_woocommerce_archive_page_layout_setting', array(
			'priority' => 1,
			'title'    => __( 'Archive Page Layout', 'spacious' ),
			'panel'    => 'spacious_woocommerce_options',
		) );

		$wp_customize->add_setting( 'spacious[spacious_woo_archive_layout]', array(
			'default'           => 'no_sidebar_full_width',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_radio_sanitize',
		) );

		$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_woo_archive_layout]', array(
			'type'     => 'radio',
			'label'    => __( 'This layout will be reflected in woocommerce archive page only.', 'spacious' ),
			'section'  => 'spacious_woocommerce_archive_page_layout_setting',
			'settings' => 'spacious[spacious_woo_archive_layout]',
			'choices'  => array(
				'right_sidebar'               => SPACIOUS_ADMIN_IMAGES_URL . '/right-sidebar.png',
				'left_sidebar'                => SPACIOUS_ADMIN_IMAGES_URL . '/left-sidebar.png',
				'no_sidebar_full_width'       => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
				'no_sidebar_content_centered' => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
			),
		) ) );

		// WooCommerce product page layout
		$wp_customize->add_section( 'spacious_woocommerce_product_page_layout_setting', array(
			'priority' => 2,
			'title'    => __( 'Product Page Layout', 'spacious' ),
			'panel'    => 'spacious_woocommerce_options',
		) );

		$wp_customize->add_setting( 'spacious[spacious_woo_product_layout]', array(
			'default'           => 'no_sidebar_full_width',
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_radio_sanitize',
		) );

		$wp_customize->add_control( new Spacious_Image_Radio_Control( $wp_customize, 'spacious[spacious_woo_product_layout]', array(
			'type'     => 'radio',
			'label'    => __( 'This layout will be reflected in woocommerce Product page.', 'spacious' ),
			'section'  => 'spacious_woocommerce_product_page_layout_setting',
			'settings' => 'spacious[spacious_woo_product_layout]',
			'choices'  => array(
				'right_sidebar'               => SPACIOUS_ADMIN_IMAGES_URL . '/right-sidebar.png',
				'left_sidebar'                => SPACIOUS_ADMIN_IMAGES_URL . '/left-sidebar.png',
				'no_sidebar_full_width'       => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
				'no_sidebar_content_centered' => SPACIOUS_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
			),
		) ) );

		// Section: WooCommerce additional options
		$wp_customize->add_section( 'spacious_woocommerce_additional', array(
			'priority' => 3,
			'title'    => __( 'Additional', 'spacious' ),
			'panel'    => 'spacious_woocommerce_options',
		) );

		// Setting: WooCommerce cart icon
		$wp_customize->add_setting( 'spacious[spacious_cart_icon]', array(
			'default'           => 0,
			'type'              => 'option',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'spacious_checkbox_sanitize',
		) );

		$wp_customize->add_control( 'spacious[spacious_cart_icon]', array(
			'type'     => 'checkbox',
			'label'    => __( 'Check to show WooCommerce cart icon on menu bar', 'spacious' ),
			'section'  => 'spacious_woocommerce_additional',
			'settings' => 'spacious[spacious_cart_icon]',
		) );

	}
	// End of the WooCommerce Options

	/************************************************************************************************************/

	// Google Font Sanitization
	function spacious_font_sanitize( $input, $setting ) {
		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// Radio and Select Sanitization
	function spacious_radio_sanitize( $input, $setting ) {
		// Ensure input is a slug.
		$input = sanitize_key( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// Slider radio sanitize
	function spacious_slider_radio_sanitize( $input, $setting ) {
		// Ensuring that the input is a slug.
		$input = sanitize_text_field( $input );
		// Get the list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it, else, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// checkbox sanitize
	function spacious_checkbox_sanitize( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}

	// editor sanitization
	function spacious_editor_sanitize( $input ) {
		if ( isset( $input ) ) {
			$input = stripslashes( wp_filter_post_kses( addslashes( $input ) ) );
		}

		return $input;
	}

	// Color sanitization
	function spacious_color_option_hex_sanitize( $color ) {
		if ( $unhashed = sanitize_hex_color_no_hash( $color ) ) {
			return '#' . $unhashed;
		}

		return $color;
	}

	function spacious_color_escaping_option_sanitize( $input ) {
		$input = esc_attr( $input );

		return $input;
	}

	// text-area sanitize
	function spacious_text_sanitize( $input ) {
		return wp_kses_post( force_balance_tags( $input ) );
	}

	// excerpt length sanitize
	function spacious_excerpt_length_sanitize( $input ) {
		if ( is_numeric( $input ) ) {
			return intval( $input );
		} else {
			return 40;
		}
	}

	// slider transition delay time sanitize
	function spacious_slider_transition_delay_sanitize( $input ) {
		if ( is_numeric( $input ) ) {
			return intval( $input );
		} else {
			return 4;
		}
	}

	// slider transition length sanitize
	function spacious_slider_transition_length_sanitize( $input ) {
		if ( is_numeric( $input ) ) {
			return intval( $input );
		} else {
			return 1;
		}
	}

	// slider number sanitize
	function spacious_slider_number_sanitize( $input ) {
		if ( is_numeric( $input ) ) {
			return intval( $input );
		} else {
			return 5;
		}
	}

	// footer section sanitization
	function spacious_footer_editor_sanitize( $input ) {
		if ( isset( $input ) ) {
			$input = stripslashes( wp_filter_post_kses( addslashes( $input ) ) );
		}

		return $input;
	}

	// sanitization of links
	function spacious_links_sanitize() {
		return false;
	}
}

add_action( 'customize_register', 'spacious_customize_register' );

/*****************************************************************************************/

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function spacious_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function spacious_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Render callback function for Read More text.
 */
function spacious_read_more_text_render() { ?>
	<a class="read-more" href="<?php the_permalink(); ?>"><?php echo spacious_options( 'spacious_read_more_text', __( 'Read more', 'spacious' ) ); ?></a>
<?php }

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 *
 * @since Spacious 2.1.6
 */
function spacious_customize_preview_js() {
	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';
	wp_enqueue_script( 'spacious-customizer', get_template_directory_uri() . '/js/customizer' . $suffix . '.js', array( 'customize-preview' ), false, true );
}

add_action( 'customize_preview_init', 'spacious_customize_preview_js' );

/**************************************************************************************/

if ( ! function_exists( 'spacious_font_size_range_generator' ) ) :
	/**
	 * Function to generate font size range for font size options.
	 */
	function spacious_font_size_range_generator( $start_range, $end_range ) {
		$range_string = array();
		for ( $i = $start_range; $i <= $end_range; $i ++ ) {
			$range_string[ $i ] = $i;
		}

		return $range_string;
	}
endif;

/**************************************************************************************/

if ( ! function_exists( 'spacious_font_size_func' ) ) :
	/**
	 * Function that contain Font Size customze setting
	 */
	function spacious_font_size_func() {
		$spacious_fonts_size_options = array(
			'spacious_header_font_size_setting'  => array(
				'section_id'                 => 'spacious_header_font_size_setting',
				'title'                      => __( 'Header font size Options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_site_title_font_size'        => array(
						'id'         => 'spacious_site_title_font_size',
						'default'    => '36',
						'label'      => __( 'Site title font size. Default is 36px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 26, 46 ),
						'custom_css' => ' #site-title a',
					),
					'spacious_tagline_font_size'           => array(
						'id'         => 'spacious_tagline_font_size',
						'default'    => '16',
						'label'      => __( 'Site tagline font size. Default is 16px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 12, 20 ),
						'custom_css' => ' #site-description',
					),
					'spacious_primary_menu_font_size'      => array(
						'id'         => 'spacious_primary_menu_font_size',
						'default'    => '16',
						'label'      => __( 'Primary menu. Default is 16px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 12, 20 ),
						'custom_css' => ' .main-navigation ul li a',
					),
					'spacious_primary_sub_menu_font_size'  => array(
						'id'         => 'spacious_primary_sub_menu_font_size',
						'default'    => '13',
						'label'      => __( 'Primary sub menu. Default is 13px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 18 ),
						'custom_css' => ' .main-navigation ul li ul li a, .main-navigation ul li ul li a, .main-navigation ul li.current-menu-item ul li a, .main-navigation ul li ul li.current-menu-item a, .main-navigation ul li.current_page_ancestor ul li a, .main-navigation ul li.current-menu-ancestor ul li a, .main-navigation ul li.current_page_item ul li a',
					),
					'spacious_small_header_menu_font_size' => array(
						'id'         => 'spacious_small_header_menu_font_size',
						'default'    => '12',
						'label'      => __( 'Header small menu. Default is 12px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 16 ),
						'custom_css' => ' .small-menu a',
					),
					'spacious_small_info_text_size'        => array(
						'id'         => 'spacious_small_info_text_size',
						'default'    => '12',
						'label'      => __( 'Header top bar small info text. Default is 12px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 16 ),
						'custom_css' => ' .small-info-text p',
					),
				),
			),
			'spacious_slider_font_size_setting'  => array(
				'section_id'                 => 'spacious_slider_font_size_setting',
				'title'                      => __( 'Slider font size Options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_slider_title_font_size'   => array(
						'id'         => 'spacious_slider_title_font_size',
						'default'    => '26',
						'label'      => __( 'Slider title. Default is 26px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 20, 34 ),
						'custom_css' => ' #featured-slider .entry-title span',
					),
					'spacious_slider_content_font_size' => array(
						'id'         => 'spacious_slider_content_font_size',
						'default'    => '16',
						'label'      => __( 'Slider content. Default is 16px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 12, 20 ),
						'custom_css' => ' #featured-slider .entry-content p',
					),
					'spacious_slider_button_font_size'  => array(
						'id'         => 'spacious_slider_button_font_size',
						'default'    => '20',
						'label'      => __( 'Slider button text. Default is 20px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 16, 30 ),
						'custom_css' => ' #featured-slider .slider-read-more-button',
					),
				),
			),
			'spacious_header_bar_setting'        => array(
				'section_id'                 => 'spacious_header_bar_setting',
				'title'                      => __( 'Header Bar font size options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_breadcrumb_text_font_size' => array(
						'id'         => 'spacious_breadcrumb_text_font_size',
						'default'    => '12',
						'label'      => __( 'Breadcrumb Text. Default is 12px. Breadcrumb appears in header bar right side after installing Breadcrumb NavXT', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 16 ),
						'custom_css' => ' .breadcrumb',
					),
					'spacious_title_font_size'           => array(
						'id'         => 'spacious_title_font_size',
						'default'    => '22',
						'label'      => __( 'Page title and post title in single view. Default is 22px. Appears in header bar just before content.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 18, 30 ),
						'custom_css' => ' .header-post-title-class',
					),
				),
			),
			'spacious_widget_title_size_setting' => array(
				'section_id'                 => 'spacious_widget_title_size_setting',
				'title'                      => __( 'Title and widget related font size options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_archive_title_font_size'         => array(
						'id'         => 'spacious_archive_title_font_size',
						'default'    => '26',
						'label'      => __( 'Title in posts listing or blog/category view. Also for posts titles in TG:Featured Posts widget. Default is 26px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 20, 34 ),
						'custom_css' => ' .post .entry-title, .page .entry-title, .widget_featured_posts .tg-one-half .entry-title',
					),
					'spacious_widget_title_font_size'          => array(
						'id'         => 'spacious_widget_title_font_size',
						'default'    => '22',
						'label'      => __( 'Widget title font size. Default is 22px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 18, 30 ),
						'custom_css' => ' #secondary h3.widget-title, .widget_service_block .widget-title, .widget_featured_single_post .widget-title, .widget_testimonial .widget-title, .widget_recent_work .tg-one-half .widget-title, .widget_recent_work .tg-one-third .widget-title, .widget_recent_work .tg-one-fourth .widget-title',
					),
					'spacious_client_widget_title_font_size'   => array(
						'id'         => 'spacious_client_widget_title_font_size',
						'default'    => '30',
						'label'      => __( 'Main title of TG: Featured Posts widget and TG: Our Clients widget. Default is 30px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 24, 40 ),
						'custom_css' => ' .widget_our_clients .widget-title, .widget_featured_posts .widget-title',
					),
					'spacious_call_to_action_title_font_size'  => array(
						'id'         => 'spacious_call_to_action_title_font_size',
						'default'    => '24',
						'label'      => __( 'Title of TG: Call To Action widget. Default is 24px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 20, 34 ),
						'custom_css' => ' .call-to-action-content h3',
					),
					'spacious_call_to_action_button_font_size' => array(
						'id'         => 'spacious_call_to_action_button_font_size',
						'default'    => '22',
						'label'      => __( 'Button text of TG: Call To Action widget. Default is 22px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 18, 30 ),
						'custom_css' => ' .call-to-action-button',
					),
					'spacious_comment_title_font_size'         => array(
						'id'         => 'spacious_comment_title_font_size',
						'default'    => '26',
						'label'      => __( 'Comment Title. Default is 26px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 20, 34 ),
						'custom_css' => ' .comments-title, .comment-reply-title',
					),
				),
			),
			'spacious_content_size_setting'      => array(
				'section_id'                 => 'spacious_content_size_setting',
				'title'                      => __( 'Content font size options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_content_font_size'   => array(
						'id'         => 'spacious_content_font_size',
						'default'    => '16',
						'label'      => __( 'Content font size, also applies to other text like in search fields, post comment button etc. Default is 16px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 12, 20 ),
						'custom_css' => ' body, button, input, select, textarea, p, dl, .spacious-button, input[type="reset"], input[type="button"], input[type="submit"], button, .previous a, .next a, .widget_testimonial .testimonial-author span, .nav-previous a, .nav-next a, #respond h3#reply-title #cancel-comment-reply-link, #respond form input[type="text"], #respond form textarea, #secondary .widget, .error-404 .widget',
					),
					'spacious_post_meta_font_size' => array(
						'id'         => 'spacious_post_meta_font_size',
						'default'    => '14',
						'label'      => __( 'Post meta font size. Default is 14px. Post meta includes date, author, category etc. information of post.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 18 ),
						'custom_css' => ' .entry-meta',
					),
					'spacious_read_more_font_size' => array(
						'id'         => 'spacious_read_more_font_size',
						'default'    => '14',
						'label'      => __( 'Read more link font size. Default is 14px. Read more in post meta, TG: Featured Single Page widget and TG: Services widget.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 18 ),
						'custom_css' => ' .read-more, .more-link',
					),
				),
			),
			'spacious_footer_font_size_setting'  => array(
				'section_id'                 => 'spacious_footer_font_size_setting',
				'title'                      => __( 'Footer font size options', 'spacious' ),
				'spacious_font_size_setting' => array(
					'spacious_footer_widget_title_font_size'   => array(
						'id'         => 'spacious_footer_widget_title_font_size',
						'default'    => '22',
						'label'      => __( 'Footer widget title font size. Default is 22px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 18, 30 ),
						'custom_css' => ' #colophon .widget-title',
					),
					'spacious_footer_widget_content_font_size' => array(
						'id'         => 'spacious_footer_widget_content_font_size',
						'default'    => '14',
						'label'      => __( 'Footer widget content font size. Default is 14px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 18 ),
						'custom_css' => ' #colophon, #colophon p',
					),
					'spacious_footer_copyright_text_font_size' => array(
						'id'         => 'spacious_footer_copyright_text_font_size',
						'default'    => '12',
						'label'      => __( 'Footer copyright text font size. Default is 12px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 16 ),
						'custom_css' => ' #colophon .footer-socket-wrapper .copyright, #colophon .footer-socket-wrapper .copyright p',
					),
					'spacious_small_footer_menu_font_size'     => array(
						'id'         => 'spacious_small_footer_menu_font_size',
						'default'    => '12',
						'label'      => __( 'Footer small menu. Default is 12px.', 'spacious' ),
						'choice'     => spacious_font_size_range_generator( 10, 16 ),
						'custom_css' => ' #colophon .small-menu a',
					),
				),
			),
		);

		return $spacious_fonts_size_options;
	}
endif;

/**************************************************************************************/

if ( ! function_exists( 'spacious_color_func' ) ) :
	/**
	 * Function that contain Color customze setting
	 */
	function spacious_color_func() {
		$spacious_color_options = array(
			'spacious_header_color_settings'     => array(
				'section_id'              => 'spacious_header_color_settings',
				'title'                   => __( 'Header Color Options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_primary_menu_text_color'         => array(
						'id'               => 'spacious_primary_menu_text_color',
						'default'          => '#444444',
						'label'            => __( 'Primary menu text color. Default is #444444.', 'spacious' ),
						'color_custom_css' => ' .main-navigation a { color: ',
					),
					'spacious_primary_sub_menu_text_color'     => array(
						'id'               => 'spacious_primary_sub_menu_text_color',
						'default'          => '#666666',
						'label'            => __( 'Primary sub menu text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' .main-navigation ul li ul li a { color: ',
					),
					'spacious_header_background_color'         => array(
						'id'               => 'spacious_header_background_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Header background color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #header-text-nav-container { background-color: ',
					),
					'spacious_header_top_bar_background_color' => array(
						'id'               => 'spacious_header_top_bar_background_color',
						'default'          => '#F8F8F8',
						'label'            => __( 'Header top bar background color. Default is #F8F8F8.', 'spacious' ),
						'color_custom_css' => ' #header-meta { background-color: ',
					),
					'spacious_header_info_text_color'          => array(
						'id'               => 'spacious_header_info_text_color',
						'default'          => '#555555',
						'label'            => __( 'Header top bar info text color. Default is #555555.', 'spacious' ),
						'color_custom_css' => ' .small-info-text p { color: ',
					),
					'spacious_header_small_menu_text_color'    => array(
						'id'               => 'spacious_header_small_menu_text_color',
						'default'          => '#666666',
						'label'            => __( 'Header small menu text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' .small-menu a { color: ',
					),
				),
			),
			'spacious_slider_color_settings'     => array(
				'section_id'              => 'spacious_slider_color_settings',
				'title'                   => __( 'Slider part color options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_slider_title_color'             => array(
						'id'               => 'spacious_slider_title_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Slider title. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #featured-slider .entry-title span { color: ',
					),
					'spacious_slider_content_color'           => array(
						'id'               => 'spacious_slider_content_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Slider content. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #featured-slider .entry-content p { color: ',
					),
					'spacious_slider_button_color'            => array(
						'id'               => 'spacious_slider_button_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Slider button text color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #featured-slider .slider-read-more-button { color: ',
					),
					'spacious_slider_button_background_color' => array(
						'id'               => 'spacious_slider_button_background_color',
						'default'          => '#0FBE7C',
						'label'            => __( 'Slider button background color. Default is #0FBE7C.', 'spacious' ),
						'color_custom_css' => ' #featured-slider .slider-read-more-button { background-color: ',
					),
				),
			),
			'spacious_header_bar_color_settings' => array(
				'section_id'              => 'spacious_header_bar_color_settings',
				'title'                   => __( 'Header Bar Color Options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_page_post_title_color'       => array(
						'id'               => 'spacious_page_post_title_color',
						'default'          => '#222222',
						'label'            => __( 'Page title and post title in single view. Default is #222222', 'spacious' ),
						'color_custom_css' => ' .header-post-title-class { color: ',
					),
					'spacious_breadcrumb_text_color'       => array(
						'id'               => 'spacious_breadcrumb_text_color',
						'default'          => '#666666',
						'label'            => __( 'Breadcrumb text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' .breadcrumb, .breadcrumb a { color: ',
					),
					'spacious_header_bar_background_color' => array(
						'id'               => 'spacious_header_bar_background_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Header bar background color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' .header-post-title-container { background-color: ',
					),
				),
			),
			'spacious_content_color_settings'    => array(
				'section_id'              => 'spacious_content_color_settings',
				'title'                   => __( 'Content part color options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_posts_title_color'                    => array(
						'id'               => 'spacious_posts_title_color',
						'default'          => '#222222',
						'label'            => __( 'Title in posts listing or blog/category view. Also for posts titles in TG:Featured Posts widget. Default is #222222.', 'spacious' ),
						'color_custom_css' => ' .post .entry-title a, .page .entry-title a, .widget_featured_posts .tg-one-half .entry-title a { color: ',
					),
					'spacious_widget_title_color'                   => array(
						'id'               => 'spacious_widget_title_color',
						'default'          => '#222222',
						'label'            => __( 'Widget title color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #secondary h3.widget-title, .widget_service_block .widget-title a, .widget_featured_single_post .widget-title a, .widget_testimonial .widget-title, .widget_recent_work .tg-one-half .widget-title, .widget_recent_work .tg-one-third .widget-title, .widget_recent_work .tg-one-fourth .widget-title, .widget_our_clients .widget-title, .widget_featured_posts .widget-title { color: ',
					),
					'spacious_content_text_color'                   => array(
						'id'               => 'spacious_content_text_color',
						'default'          => '#666666',
						'label'            => __( 'Content text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' body, button, input, select, textarea, p, dl, .spacious-button, input[type="reset"], input[type="button"], input[type="submit"], button, .previous a, .next a, .widget_testimonial .testimonial-author span, .nav-previous a, .nav-next a, #respond h3#reply-title #cancel-comment-reply-link, #respond form input[type="text"], #respond form textarea, #secondary .widget, .error-404 .widget { color: ',
					),
					'spacious_post_meta_icon_color'                 => array(
						'id'               => 'spacious_post_meta_icon_color',
						'default'          => '#999999',
						'label'            => __( 'Post meta icon color. Post meta includes date, author, category etc. information of post. Default is #999999.', 'spacious' ),
						'color_custom_css' => ' .entry-meta { color: ',
					),
					'spacious_post_meta_color'                      => array(
						'id'               => 'spacious_post_meta_color',
						'default'          => '#999999',
						'label'            => __( 'Post meta text color. Post meta includes date, author, category etc. information of post. Default is #999999.', 'spacious' ),
						'color_custom_css' => ' .entry-meta a, .type-page .entry-meta a { color: ',
					),
					'spacious_post_meta_read_more_color'            => array(
						'id'               => 'spacious_post_meta_read_more_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Read more text in post meta. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' .entry-meta a.read-more { color: ',
					),
					'spacious_post_meta_read_more_background_color' => array(
						'id'               => 'spacious_post_meta_read_more_background_color',
						'default'          => '#0FBE7C',
						'label'            => __( 'Read more text background color. Default is #0FBE7C.', 'spacious' ),
						'color_custom_css' => ' .entry-meta .read-more-link { background-color: ',
					),
					'spacious_tg_widget_read_more_color'            => array(
						'id'               => 'spacious_tg_widget_read_more_color',
						'default'          => '#0FBE7C',
						'label'            => __( 'Read more link color for TG: Featured Single Page widget and TG: Services widget. Default is #0FBE7C.', 'spacious' ),
						'color_custom_css' => ' a.read-more, a.more-link { color: ',
					),
					'spacious_content_background_color'             => array(
						'id'               => 'spacious_content_background_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Content part background color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #main { background-color: ',
					),
				),
			),
			'spacious_comment_color_settings'    => array(
				'section_id'              => 'spacious_comment_color_settings',
				'title'                   => __( 'Comment part color options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_comment_part_background_color'     => array(
						'id'               => 'spacious_comment_part_background_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Comment part background color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' #comments { background-color: ',
					),
					'spacious_comment_title_color'               => array(
						'id'               => 'spacious_comment_title_color',
						'default'          => '#222222',
						'label'            => __( 'Comment title color. Default is #222222.', 'spacious' ),
						'color_custom_css' => ' .comments-title, .comment-reply-title { color: ',
					),
					'spacious_comment_meta_color'                => array(
						'id'               => 'spacious_comment_meta_color',
						'default'          => '#999999',
						'label'            => __( 'Comment meta color. Like name, date etc. Default is #999999.', 'spacious' ),
						'color_custom_css' => '  .comments-area .comment-edit-link, .comments-area .comment-permalink, .comments-area .comment-date-time, .comments-area .comment-author-link { color: ',
					),
					'spacious_single_comment_background_color'   => array(
						'id'               => 'spacious_single_comment_background_color',
						'default'          => '#F8F8F8',
						'label'            => __( 'Single comment background color. Like name, date etc. Default is #F8F8F8.', 'spacious' ),
						'color_custom_css' => ' .comment-content { background-color: ',
					),
					'spacious_commenting_field_background_color' => array(
						'id'               => 'spacious_commenting_field_background_color',
						'default'          => '#F8F8F8',
						'label'            => __( 'Commenting field background color. Like name, date etc. Default is #F8F8F8.', 'spacious' ),
						'color_custom_css' => ' input[type="text"], input[type="email"], input[type="password"], textarea { background-color: ',
					),
				),
			),
			'spacious_cta_color_settings'        => array(
				'section_id'              => 'spacious_cta_color_settings',
				'title'                   => __( 'TG:Call to action widget color options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_call_to_action_title_color'             => array(
						'id'               => 'spacious_call_to_action_title_color',
						'default'          => '#222222',
						'label'            => __( 'Title color. Default is #222222.', 'spacious' ),
						'color_custom_css' => ' .call-to-action-content h3 { color: ',
					),
					'spacious_call_to_action_background_color'        => array(
						'id'               => 'spacious_call_to_action_background_color',
						'default'          => '#F8F8F8',
						'label'            => __( 'Background color. Default is #F8F8F8.', 'spacious' ),
						'color_custom_css' => ' .call-to-action-content-wrapper { background-color: ',
					),
					'spacious_call_to_action_button_color'            => array(
						'id'               => 'spacious_call_to_action_button_color',
						'default'          => '#FFFFFF',
						'label'            => __( 'Button text color. Default is #FFFFFF.', 'spacious' ),
						'color_custom_css' => ' .call-to-action-button  { color: ',
					),
					'spacious_call_to_action_button_background_color' => array(
						'id'               => 'spacious_call_to_action_button_background_color',
						'default'          => '#0FBE7C',
						'label'            => __( 'Button background color. Default is #0FBE7C.', 'spacious' ),
						'color_custom_css' => ' .call-to-action-button  { background-color: ',
					),
				),
			),
			'spacious_footer_color_settings'     => array(
				'section_id'              => 'spacious_footer_color_settings',
				'title'                   => __( 'Footer part color options', 'spacious' ),
				'spacious_color_settings' => array(
					'spacious_footer_widget_title_color'              => array(
						'id'               => 'spacious_footer_widget_title_color',
						'default'          => '#D5D5D5',
						'label'            => __( 'Widget title color. Default is #D5D5D5.', 'spacious' ),
						'color_custom_css' => '  #colophon .widget-title   { color: ',
					),
					'spacious_footer_widget_content_color'            => array(
						'id'               => 'spacious_footer_widget_content_color',
						'default'          => '#999999',
						'label'            => __( 'Widget content color. Default is #999999.', 'spacious' ),
						'color_custom_css' => ' .footer-widgets-area, .footer-widgets-area .tg-one-fourth p { color: ',
					),
					'spacious_footer_widget_background_color'         => array(
						'id'               => 'spacious_footer_widget_background_color',
						'default'          => '#333333',
						'label'            => __( 'Widget background color. Default is #333333.', 'spacious' ),
						'color_custom_css' => ' .footer-widgets-wrapper { background-color: ',
					),
					'spacious_footer_copyright_text_color'            => array(
						'id'               => 'spacious_footer_copyright_text_color',
						'default'          => '#666666',
						'label'            => __( 'Footer copyright text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' .footer-socket-wrapper .copyright, .footer-socket-wrapper .copyright a { color: ',
					),
					'spacious_footer_small_menu_color'                => array(
						'id'               => 'spacious_footer_small_menu_color',
						'default'          => '#666666',
						'label'            => __( 'Footer small menu text color. Default is #666666.', 'spacious' ),
						'color_custom_css' => ' #colophon .small-menu a { color: ',
					),
					'spacious_footer_copyright_part_background_color' => array(
						'id'               => 'spacious_footer_copyright_part_background_color',
						'default'          => '#F8F8F8',
						'label'            => __( 'Footer copyright part background color. Default is #F8F8F8.', 'spacious' ),
						'color_custom_css' => ' .footer-socket-wrapper { background-color: ',
					),
				),
			),
		);

		return $spacious_color_options;
	}
endif;

/**************************************************************************************/

if ( ! function_exists( 'spacious_google_fonts' ) ) :
	/**
	 * Google Font addition
	 */
	function spacious_google_fonts() {

		$spacious_googlefonts = array(
			'ABeeZee'                   => 'ABeeZee',
			'Abel'                      => 'Abel',
			'Abhaya Libre'              => 'Abhaya Libre',
			'Abril Fatface'             => 'Abril Fatface',
			'Aclonica'                  => 'Aclonica',
			'Acme'                      => 'Acme',
			'Actor'                     => 'Actor',
			'Adamina'                   => 'Adamina',
			'Advent Pro'                => 'Advent Pro',
			'Aguafina Script'           => 'Aguafina Script',
			'Akronim'                   => 'Akronim',
			'Aladin'                    => 'Aladin',
			'Aldrich'                   => 'Aldrich',
			'Alef'                      => 'Alef',
			'Alegreya'                  => 'Alegreya',
			'Alegreya SC'               => 'Alegreya SC',
			'Alegreya Sans'             => 'Alegreya Sans',
			'Alegreya Sans SC'          => 'Alegreya Sans SC',
			'Alex Brush'                => 'Alex Brush',
			'Alfa Slab One'             => 'Alfa Slab One',
			'Alice'                     => 'Alice',
			'Alike'                     => 'Alike',
			'Alike Angular'             => 'Alike Angular',
			'Allan'                     => 'Allan',
			'Allerta'                   => 'Allerta',
			'Allerta Stencil'           => 'Allerta Stencil',
			'Allura'                    => 'Allura',
			'Almendra'                  => 'Almendra',
			'Almendra Display'          => 'Almendra Display',
			'Almendra SC'               => 'Almendra SC',
			'Amarante'                  => 'Amarante',
			'Amaranth'                  => 'Amaranth',
			'Amatic SC'                 => 'Amatic SC',
			'Amatica SC'                => 'Amatica SC',
			'Amethysta'                 => 'Amethysta',
			'Amiko'                     => 'Amiko',
			'Amiri'                     => 'Amiri',
			'Amita'                     => 'Amita',
			'Anaheim'                   => 'Anaheim',
			'Andada'                    => 'Andada',
			'Andika'                    => 'Andika',
			'Angkor'                    => 'Angkor',
			'Annie Use Your Telescope'  => 'Annie Use Your Telescope',
			'Anonymous Pro'             => 'Anonymous Pro',
			'Antic'                     => 'Antic',
			'Antic Didone'              => 'Antic Didone',
			'Antic Slab'                => 'Antic Slab',
			'Anton'                     => 'Anton',
			'Arapey'                    => 'Arapey',
			'Arbutus'                   => 'Arbutus',
			'Arbutus Slab'              => 'Arbutus Slab',
			'Architects Daughter'       => 'Architects Daughter',
			'Archivo Black'             => 'Archivo Black',
			'Archivo Narrow'            => 'Archivo Narrow',
			'Aref Ruqaa'                => 'Aref Ruqaa',
			'Arima Madurai'             => 'Arima Madurai',
			'Arimo'                     => 'Arimo',
			'Arizonia'                  => 'Arizonia',
			'Armata'                    => 'Armata',
			'Arsenal'                   => 'Arsenal',
			'Artifika'                  => 'Artifika',
			'Arvo'                      => 'Arvo',
			'Arya'                      => 'Arya',
			'Asap'                      => 'Asap',
			'Asar'                      => 'Asar',
			'Asset'                     => 'Asset',
			'Assistant'                 => 'Assistant',
			'Astloch'                   => 'Astloch',
			'Asul'                      => 'Asul',
			'Athiti'                    => 'Athiti',
			'Atma'                      => 'Atma',
			'Atomic Age'                => 'Atomic Age',
			'Aubrey'                    => 'Aubrey',
			'Audiowide'                 => 'Audiowide',
			'Autour One'                => 'Autour One',
			'Average'                   => 'Average',
			'Average Sans'              => 'Average Sans',
			'Averia Gruesa Libre'       => 'Averia Gruesa Libre',
			'Averia Libre'              => 'Averia Libre',
			'Averia Sans Libre'         => 'Averia Sans Libre',
			'Averia Serif Libre'        => 'Averia Serif Libre',
			'Bad Script'                => 'Bad Script',
			'Bahiana'                   => 'Bahiana',
			'Baloo'                     => 'Baloo',
			'Baloo Bhai'                => 'Baloo Bhai',
			'Baloo Bhaina'              => 'Baloo Bhaina',
			'Baloo Chettan'             => 'Baloo Chettan',
			'Baloo Da'                  => 'Baloo Da',
			'Baloo Paaji'               => 'Baloo Paaji',
			'Baloo Tamma'               => 'Baloo Tamma',
			'Baloo Thambi'              => 'Baloo Thambi',
			'Balthazar'                 => 'Balthazar',
			'Bangers'                   => 'Bangers',
			'Barrio'                    => 'Barrio',
			'Basic'                     => 'Basic',
			'Battambang'                => 'Battambang',
			'Baumans'                   => 'Baumans',
			'Bayon'                     => 'Bayon',
			'Belgrano'                  => 'Belgrano',
			'Belleza'                   => 'Belleza',
			'BenchNine'                 => 'BenchNine',
			'Bentham'                   => 'Bentham',
			'Berkshire Swash'           => 'Berkshire Swash',
			'Bevan'                     => 'Bevan',
			'Bigelow Rules'             => 'Bigelow Rules',
			'Bigshot One'               => 'Bigshot One',
			'Bilbo'                     => 'Bilbo',
			'Bilbo Swash Caps'          => 'Bilbo Swash Caps',
			'BioRhyme'                  => 'BioRhyme',
			'BioRhyme Expanded'         => 'BioRhyme Expanded',
			'Biryani'                   => 'Biryani',
			'Bitter'                    => 'Bitter',
			'Black Ops One'             => 'Black Ops One',
			'Bokor'                     => 'Bokor',
			'Bonbon'                    => 'Bonbon',
			'Boogaloo'                  => 'Boogaloo',
			'Bowlby One'                => 'Bowlby One',
			'Bowlby One SC'             => 'Bowlby One SC',
			'Brawler'                   => 'Brawler',
			'Bree Serif'                => 'Bree Serif',
			'Bubblegum Sans'            => 'Bubblegum Sans',
			'Bubbler One'               => 'Bubbler One',
			'Buda'                      => 'Buda',
			'Buenard'                   => 'Buenard',
			'Bungee'                    => 'Bungee',
			'Bungee Hairline'           => 'Bungee Hairline',
			'Bungee Inline'             => 'Bungee Inline',
			'Bungee Outline'            => 'Bungee Outline',
			'Bungee Shade'              => 'Bungee Shade',
			'Butcherman'                => 'Butcherman',
			'Butterfly Kids'            => 'Butterfly Kids',
			'Cabin'                     => 'Cabin',
			'Cabin Condensed'           => 'Cabin Condensed',
			'Cabin Sketch'              => 'Cabin Sketch',
			'Caesar Dressing'           => 'Caesar Dressing',
			'Cagliostro'                => 'Cagliostro',
			'Cairo'                     => 'Cairo',
			'Calligraffitti'            => 'Calligraffitti',
			'Cambay'                    => 'Cambay',
			'Cambo'                     => 'Cambo',
			'Candal'                    => 'Candal',
			'Cantarell'                 => 'Cantarell',
			'Cantata One'               => 'Cantata One',
			'Cantora One'               => 'Cantora One',
			'Capriola'                  => 'Capriola',
			'Cardo'                     => 'Cardo',
			'Carme'                     => 'Carme',
			'Carrois Gothic'            => 'Carrois Gothic',
			'Carrois Gothic SC'         => 'Carrois Gothic SC',
			'Carter One'                => 'Carter One',
			'Catamaran'                 => 'Catamaran',
			'Caudex'                    => 'Caudex',
			'Caveat'                    => 'Caveat',
			'Caveat Brush'              => 'Caveat Brush',
			'Cedarville Cursive'        => 'Cedarville Cursive',
			'Ceviche One'               => 'Ceviche One',
			'Changa'                    => 'Changa',
			'Changa One'                => 'Changa One',
			'Chango'                    => 'Chango',
			'Chathura'                  => 'Chathura',
			'Chau Philomene One'        => 'Chau Philomene One',
			'Chela One'                 => 'Chela One',
			'Chelsea Market'            => 'Chelsea Market',
			'Chenla'                    => 'Chenla',
			'Cherry Cream Soda'         => 'Cherry Cream Soda',
			'Cherry Swash'              => 'Cherry Swash',
			'Chewy'                     => 'Chewy',
			'Chicle'                    => 'Chicle',
			'Chivo'                     => 'Chivo',
			'Chonburi'                  => 'Chonburi',
			'Cinzel'                    => 'Cinzel',
			'Cinzel Decorative'         => 'Cinzel Decorative',
			'Clicker Script'            => 'Clicker Script',
			'Coda'                      => 'Coda',
			'Coda Caption'              => 'Coda Caption',
			'Codystar'                  => 'Codystar',
			'Coiny'                     => 'Coiny',
			'Combo'                     => 'Combo',
			'Comfortaa'                 => 'Comfortaa',
			'Coming Soon'               => 'Coming Soon',
			'Concert One'               => 'Concert One',
			'Condiment'                 => 'Condiment',
			'Content'                   => 'Content',
			'Contrail One'              => 'Contrail One',
			'Convergence'               => 'Convergence',
			'Cookie'                    => 'Cookie',
			'Copse'                     => 'Copse',
			'Corben'                    => 'Corben',
			'Cormorant'                 => 'Cormorant',
			'Cormorant Garamond'        => 'Cormorant Garamond',
			'Cormorant Infant'          => 'Cormorant Infant',
			'Cormorant SC'              => 'Cormorant SC',
			'Cormorant Unicase'         => 'Cormorant Unicase',
			'Cormorant Upright'         => 'Cormorant Upright',
			'Courgette'                 => 'Courgette',
			'Cousine'                   => 'Cousine',
			'Coustard'                  => 'Coustard',
			'Covered By Your Grace'     => 'Covered By Your Grace',
			'Crafty Girls'              => 'Crafty Girls',
			'Creepster'                 => 'Creepster',
			'Crete Round'               => 'Crete Round',
			'Crimson Text'              => 'Crimson Text',
			'Croissant One'             => 'Croissant One',
			'Crushed'                   => 'Crushed',
			'Cuprum'                    => 'Cuprum',
			'Cutive'                    => 'Cutive',
			'Cutive Mono'               => 'Cutive Mono',
			'Damion'                    => 'Damion',
			'Dancing Script'            => 'Dancing Script',
			'Dangrek'                   => 'Dangrek',
			'David Libre'               => 'David Libre',
			'Dawning of a New Day'      => 'Dawning of a New Day',
			'Days One'                  => 'Days One',
			'Dekko'                     => 'Dekko',
			'Delius'                    => 'Delius',
			'Delius Swash Caps'         => 'Delius Swash Caps',
			'Delius Unicase'            => 'Delius Unicase',
			'Della Respira'             => 'Della Respira',
			'Denk One'                  => 'Denk One',
			'Devonshire'                => 'Devonshire',
			'Dhurjati'                  => 'Dhurjati',
			'Didact Gothic'             => 'Didact Gothic',
			'Diplomata'                 => 'Diplomata',
			'Diplomata SC'              => 'Diplomata SC',
			'Domine'                    => 'Domine',
			'Donegal One'               => 'Donegal One',
			'Doppio One'                => 'Doppio One',
			'Dorsa'                     => 'Dorsa',
			'Dosis'                     => 'Dosis',
			'Dr Sugiyama'               => 'Dr Sugiyama',
			'Droid Sans'                => 'Droid Sans',
			'Droid Sans Mono'           => 'Droid Sans Mono',
			'Droid Serif'               => 'Droid Serif',
			'Duru Sans'                 => 'Duru Sans',
			'Dynalight'                 => 'Dynalight',
			'EB Garamond'               => 'EB Garamond',
			'Eagle Lake'                => 'Eagle Lake',
			'Eater'                     => 'Eater',
			'Economica'                 => 'Economica',
			'Eczar'                     => 'Eczar',
			'Ek Mukta'                  => 'Ek Mukta',
			'El Messiri'                => 'El Messiri',
			'Electrolize'               => 'Electrolize',
			'Elsie'                     => 'Elsie',
			'Elsie Swash Caps'          => 'Elsie Swash Caps',
			'Emblema One'               => 'Emblema One',
			'Emilys Candy'              => 'Emilys Candy',
			'Engagement'                => 'Engagement',
			'Englebert'                 => 'Englebert',
			'Enriqueta'                 => 'Enriqueta',
			'Erica One'                 => 'Erica One',
			'Esteban'                   => 'Esteban',
			'Euphoria Script'           => 'Euphoria Script',
			'Ewert'                     => 'Ewert',
			'Exo'                       => 'Exo',
			'Exo 2'                     => 'Exo 2',
			'Expletus Sans'             => 'Expletus Sans',
			'Fanwood Text'              => 'Fanwood Text',
			'Farsan'                    => 'Farsan',
			'Fascinate'                 => 'Fascinate',
			'Fascinate Inline'          => 'Fascinate Inline',
			'Faster One'                => 'Faster One',
			'Fasthand'                  => 'Fasthand',
			'Fauna One'                 => 'Fauna One',
			'Federant'                  => 'Federant',
			'Federo'                    => 'Federo',
			'Felipa'                    => 'Felipa',
			'Fenix'                     => 'Fenix',
			'Finger Paint'              => 'Finger Paint',
			'Fira Mono'                 => 'Fira Mono',
			'Fira Sans'                 => 'Fira Sans',
			'Fira Sans Condensed'       => 'Fira Sans Condensed',
			'Fira Sans Extra Condensed' => 'Fira Sans Extra Condensed',
			'Fjalla One'                => 'Fjalla One',
			'Fjord One'                 => 'Fjord One',
			'Flamenco'                  => 'Flamenco',
			'Flavors'                   => 'Flavors',
			'Fondamento'                => 'Fondamento',
			'Fontdiner Swanky'          => 'Fontdiner Swanky',
			'Forum'                     => 'Forum',
			'Francois One'              => 'Francois One',
			'Frank Ruhl Libre'          => 'Frank Ruhl Libre',
			'Freckle Face'              => 'Freckle Face',
			'Fredericka the Great'      => 'Fredericka the Great',
			'Fredoka One'               => 'Fredoka One',
			'Freehand'                  => 'Freehand',
			'Fresca'                    => 'Fresca',
			'Frijole'                   => 'Frijole',
			'Fruktur'                   => 'Fruktur',
			'Fugaz One'                 => 'Fugaz One',
			'GFS Didot'                 => 'GFS Didot',
			'GFS Neohellenic'           => 'GFS Neohellenic',
			'Gabriela'                  => 'Gabriela',
			'Gafata'                    => 'Gafata',
			'Galada'                    => 'Galada',
			'Galdeano'                  => 'Galdeano',
			'Galindo'                   => 'Galindo',
			'Gentium Basic'             => 'Gentium Basic',
			'Gentium Book Basic'        => 'Gentium Book Basic',
			'Geo'                       => 'Geo',
			'Geostar'                   => 'Geostar',
			'Geostar Fill'              => 'Geostar Fill',
			'Germania One'              => 'Germania One',
			'Gidugu'                    => 'Gidugu',
			'Gilda Display'             => 'Gilda Display',
			'Give You Glory'            => 'Give You Glory',
			'Glass Antiqua'             => 'Glass Antiqua',
			'Glegoo'                    => 'Glegoo',
			'Gloria Hallelujah'         => 'Gloria Hallelujah',
			'Goblin One'                => 'Goblin One',
			'Gochi Hand'                => 'Gochi Hand',
			'Gorditas'                  => 'Gorditas',
			'Goudy Bookletter 1911'     => 'Goudy Bookletter 1911',
			'Graduate'                  => 'Graduate',
			'Grand Hotel'               => 'Grand Hotel',
			'Gravitas One'              => 'Gravitas One',
			'Great Vibes'               => 'Great Vibes',
			'Griffy'                    => 'Griffy',
			'Gruppo'                    => 'Gruppo',
			'Gudea'                     => 'Gudea',
			'Gurajada'                  => 'Gurajada',
			'Habibi'                    => 'Habibi',
			'Halant'                    => 'Halant',
			'Hammersmith One'           => 'Hammersmith One',
			'Hanalei'                   => 'Hanalei',
			'Hanalei Fill'              => 'Hanalei Fill',
			'Handlee'                   => 'Handlee',
			'Hanuman'                   => 'Hanuman',
			'Happy Monkey'              => 'Happy Monkey',
			'Harmattan'                 => 'Harmattan',
			'Headland One'              => 'Headland One',
			'Heebo'                     => 'Heebo',
			'Henny Penny'               => 'Henny Penny',
			'Herr Von Muellerhoff'      => 'Herr Von Muellerhoff',
			'Hind'                      => 'Hind',
			'Hind Guntur'               => 'Hind Guntur',
			'Hind Madurai'              => 'Hind Madurai',
			'Hind Siliguri'             => 'Hind Siliguri',
			'Hind Vadodara'             => 'Hind Vadodara',
			'Holtwood One SC'           => 'Holtwood One SC',
			'Homemade Apple'            => 'Homemade Apple',
			'Homenaje'                  => 'Homenaje',
			'IM Fell DW Pica'           => 'IM Fell DW Pica',
			'IM Fell DW Pica SC'        => 'IM Fell DW Pica SC',
			'IM Fell Double Pica'       => 'IM Fell Double Pica',
			'IM Fell Double Pica SC'    => 'IM Fell Double Pica SC',
			'IM Fell English'           => 'IM Fell English',
			'IM Fell English SC'        => 'IM Fell English SC',
			'IM Fell French Canon'      => 'IM Fell French Canon',
			'IM Fell French Canon SC'   => 'IM Fell French Canon SC',
			'IM Fell Great Primer'      => 'IM Fell Great Primer',
			'IM Fell Great Primer SC'   => 'IM Fell Great Primer SC',
			'Iceberg'                   => 'Iceberg',
			'Iceland'                   => 'Iceland',
			'Imprima'                   => 'Imprima',
			'Inconsolata'               => 'Inconsolata',
			'Inder'                     => 'Inder',
			'Indie Flower'              => 'Indie Flower',
			'Inika'                     => 'Inika',
			'Inknut Antiqua'            => 'Inknut Antiqua',
			'Irish Grover'              => 'Irish Grover',
			'Istok Web'                 => 'Istok Web',
			'Italiana'                  => 'Italiana',
			'Italianno'                 => 'Italianno',
			'Itim'                      => 'Itim',
			'Jacques Francois'          => 'Jacques Francois',
			'Jacques Francois Shadow'   => 'Jacques Francois Shadow',
			'Jaldi'                     => 'Jaldi',
			'Jim Nightshade'            => 'Jim Nightshade',
			'Jockey One'                => 'Jockey One',
			'Jolly Lodger'              => 'Jolly Lodger',
			'Jomhuria'                  => 'Jomhuria',
			'Josefin Sans'              => 'Josefin Sans',
			'Josefin Slab'              => 'Josefin Slab',
			'Joti One'                  => 'Joti One',
			'Judson'                    => 'Judson',
			'Julee'                     => 'Julee',
			'Julius Sans One'           => 'Julius Sans One',
			'Junge'                     => 'Junge',
			'Jura'                      => 'Jura',
			'Just Another Hand'         => 'Just Another Hand',
			'Just Me Again Down Here'   => 'Just Me Again Down Here',
			'Kadwa'                     => 'Kadwa',
			'Kalam'                     => 'Kalam',
			'Kameron'                   => 'Kameron',
			'Kanit'                     => 'Kanit',
			'Kantumruy'                 => 'Kantumruy',
			'Karla'                     => 'Karla',
			'Karma'                     => 'Karma',
			'Katibeh'                   => 'Katibeh',
			'Kaushan Script'            => 'Kaushan Script',
			'Kavivanar'                 => 'Kavivanar',
			'Kavoon'                    => 'Kavoon',
			'Kdam Thmor'                => 'Kdam Thmor',
			'Keania One'                => 'Keania One',
			'Kelly Slab'                => 'Kelly Slab',
			'Kenia'                     => 'Kenia',
			'Khand'                     => 'Khand',
			'Khmer'                     => 'Khmer',
			'Khula'                     => 'Khula',
			'Kite One'                  => 'Kite One',
			'Knewave'                   => 'Knewave',
			'Kotta One'                 => 'Kotta One',
			'Koulen'                    => 'Koulen',
			'Kranky'                    => 'Kranky',
			'Kreon'                     => 'Kreon',
			'Kristi'                    => 'Kristi',
			'Krona One'                 => 'Krona One',
			'Kumar One'                 => 'Kumar One',
			'Kumar One Outline'         => 'Kumar One Outline',
			'Kurale'                    => 'Kurale',
			'La Belle Aurore'           => 'La Belle Aurore',
			'Laila'                     => 'Laila',
			'Lakki Reddy'               => 'Lakki Reddy',
			'Lalezar'                   => 'Lalezar',
			'Lancelot'                  => 'Lancelot',
			'Lateef'                    => 'Lateef',
			'Lato'                      => 'Lato',
			'League Script'             => 'League Script',
			'Leckerli One'              => 'Leckerli One',
			'Ledger'                    => 'Ledger',
			'Lekton'                    => 'Lekton',
			'Lemon'                     => 'Lemon',
			'Lemonada'                  => 'Lemonada',
			'Libre Baskerville'         => 'Libre Baskerville',
			'Libre Franklin'            => 'Libre Franklin',
			'Life Savers'               => 'Life Savers',
			'Lilita One'                => 'Lilita One',
			'Lily Script One'           => 'Lily Script One',
			'Limelight'                 => 'Limelight',
			'Linden Hill'               => 'Linden Hill',
			'Lobster'                   => 'Lobster',
			'Lobster Two'               => 'Lobster Two',
			'Londrina Outline'          => 'Londrina Outline',
			'Londrina Shadow'           => 'Londrina Shadow',
			'Londrina Sketch'           => 'Londrina Sketch',
			'Londrina Solid'            => 'Londrina Solid',
			'Lora'                      => 'Lora',
			'Love Ya Like A Sister'     => 'Love Ya Like A Sister',
			'Loved by the King'         => 'Loved by the King',
			'Lovers Quarrel'            => 'Lovers Quarrel',
			'Luckiest Guy'              => 'Luckiest Guy',
			'Lusitana'                  => 'Lusitana',
			'Lustria'                   => 'Lustria',
			'Macondo'                   => 'Macondo',
			'Macondo Swash Caps'        => 'Macondo Swash Caps',
			'Mada'                      => 'Mada',
			'Magra'                     => 'Magra',
			'Maiden Orange'             => 'Maiden Orange',
			'Maitree'                   => 'Maitree',
			'Mako'                      => 'Mako',
			'Mallanna'                  => 'Mallanna',
			'Mandali'                   => 'Mandali',
			'Marcellus'                 => 'Marcellus',
			'Marcellus SC'              => 'Marcellus SC',
			'Marck Script'              => 'Marck Script',
			'Margarine'                 => 'Margarine',
			'Marko One'                 => 'Marko One',
			'Marmelad'                  => 'Marmelad',
			'Martel'                    => 'Martel',
			'Martel Sans'               => 'Martel Sans',
			'Marvel'                    => 'Marvel',
			'Mate'                      => 'Mate',
			'Mate SC'                   => 'Mate SC',
			'Maven Pro'                 => 'Maven Pro',
			'McLaren'                   => 'McLaren',
			'Meddon'                    => 'Meddon',
			'MedievalSharp'             => 'MedievalSharp',
			'Medula One'                => 'Medula One',
			'Meera Inimai'              => 'Meera Inimai',
			'Megrim'                    => 'Megrim',
			'Meie Script'               => 'Meie Script',
			'Merienda'                  => 'Merienda',
			'Merienda One'              => 'Merienda One',
			'Merriweather'              => 'Merriweather',
			'Merriweather Sans'         => 'Merriweather Sans',
			'Metal'                     => 'Metal',
			'Metal Mania'               => 'Metal Mania',
			'Metamorphous'              => 'Metamorphous',
			'Metrophobic'               => 'Metrophobic',
			'Michroma'                  => 'Michroma',
			'Milonga'                   => 'Milonga',
			'Miltonian'                 => 'Miltonian',
			'Miltonian Tattoo'          => 'Miltonian Tattoo',
			'Miniver'                   => 'Miniver',
			'Miriam Libre'              => 'Miriam Libre',
			'Mirza'                     => 'Mirza',
			'Miss Fajardose'            => 'Miss Fajardose',
			'Mitr'                      => 'Mitr',
			'Modak'                     => 'Modak',
			'Modern Antiqua'            => 'Modern Antiqua',
			'Mogra'                     => 'Mogra',
			'Molengo'                   => 'Molengo',
			'Molle'                     => 'Molle',
			'Monda'                     => 'Monda',
			'Monofett'                  => 'Monofett',
			'Monoton'                   => 'Monoton',
			'Monsieur La Doulaise'      => 'Monsieur La Doulaise',
			'Montaga'                   => 'Montaga',
			'Montez'                    => 'Montez',
			'Montserrat'                => 'Montserrat',
			'Montserrat Alternates'     => 'Montserrat Alternates',
			'Montserrat Subrayada'      => 'Montserrat Subrayada',
			'Moul'                      => 'Moul',
			'Moulpali'                  => 'Moulpali',
			'Mountains of Christmas'    => 'Mountains of Christmas',
			'Mouse Memoirs'             => 'Mouse Memoirs',
			'Mr Bedfort'                => 'Mr Bedfort',
			'Mr Dafoe'                  => 'Mr Dafoe',
			'Mr De Haviland'            => 'Mr De Haviland',
			'Mrs Saint Delafield'       => 'Mrs Saint Delafield',
			'Mrs Sheppards'             => 'Mrs Sheppards',
			'Mukta Vaani'               => 'Mukta Vaani',
			'Muli'                      => 'Muli',
			'Mystery Quest'             => 'Mystery Quest',
			'NTR'                       => 'NTR',
			'Neucha'                    => 'Neucha',
			'Neuton'                    => 'Neuton',
			'New Rocker'                => 'New Rocker',
			'News Cycle'                => 'News Cycle',
			'Niconne'                   => 'Niconne',
			'Nixie One'                 => 'Nixie One',
			'Nobile'                    => 'Nobile',
			'Nokora'                    => 'Nokora',
			'Norican'                   => 'Norican',
			'Nosifer'                   => 'Nosifer',
			'Nothing You Could Do'      => 'Nothing You Could Do',
			'Noticia Text'              => 'Noticia Text',
			'Noto Sans'                 => 'Noto Sans',
			'Noto Serif'                => 'Noto Serif',
			'Nova Cut'                  => 'Nova Cut',
			'Nova Flat'                 => 'Nova Flat',
			'Nova Mono'                 => 'Nova Mono',
			'Nova Oval'                 => 'Nova Oval',
			'Nova Round'                => 'Nova Round',
			'Nova Script'               => 'Nova Script',
			'Nova Slim'                 => 'Nova Slim',
			'Nova Square'               => 'Nova Square',
			'Numans'                    => 'Numans',
			'Nunito'                    => 'Nunito',
			'Nunito Sans'               => 'Nunito Sans',
			'Odor Mean Chey'            => 'Odor Mean Chey',
			'Offside'                   => 'Offside',
			'Old Standard TT'           => 'Old Standard TT',
			'Oldenburg'                 => 'Oldenburg',
			'Oleo Script'               => 'Oleo Script',
			'Oleo Script Swash Caps'    => 'Oleo Script Swash Caps',
			'Open Sans'                 => 'Open Sans',
			'Open Sans Condensed'       => 'Open Sans Condensed',
			'Oranienbaum'               => 'Oranienbaum',
			'Orbitron'                  => 'Orbitron',
			'Oregano'                   => 'Oregano',
			'Orienta'                   => 'Orienta',
			'Original Surfer'           => 'Original Surfer',
			'Oswald'                    => 'Oswald',
			'Over the Rainbow'          => 'Over the Rainbow',
			'Overlock'                  => 'Overlock',
			'Overlock SC'               => 'Overlock SC',
			'Overpass'                  => 'Overpass',
			'Overpass Mono'             => 'Overpass Mono',
			'Ovo'                       => 'Ovo',
			'Oxygen'                    => 'Oxygen',
			'Oxygen Mono'               => 'Oxygen Mono',
			'PT Mono'                   => 'PT Mono',
			'PT Sans'                   => 'PT Sans',
			'PT Sans Caption'           => 'PT Sans Caption',
			'PT Sans Narrow'            => 'PT Sans Narrow',
			'PT Serif'                  => 'PT Serif',
			'PT Serif Caption'          => 'PT Serif Caption',
			'Pacifico'                  => 'Pacifico',
			'Padauk'                    => 'Padauk',
			'Palanquin'                 => 'Palanquin',
			'Palanquin Dark'            => 'Palanquin Dark',
			'Pangolin'                  => 'Pangolin',
			'Paprika'                   => 'Paprika',
			'Parisienne'                => 'Parisienne',
			'Passero One'               => 'Passero One',
			'Passion One'               => 'Passion One',
			'Pathway Gothic One'        => 'Pathway Gothic One',
			'Patrick Hand'              => 'Patrick Hand',
			'Patrick Hand SC'           => 'Patrick Hand SC',
			'Pattaya'                   => 'Pattaya',
			'Patua One'                 => 'Patua One',
			'Pavanam'                   => 'Pavanam',
			'Paytone One'               => 'Paytone One',
			'Peddana'                   => 'Peddana',
			'Peralta'                   => 'Peralta',
			'Permanent Marker'          => 'Permanent Marker',
			'Petit Formal Script'       => 'Petit Formal Script',
			'Petrona'                   => 'Petrona',
			'Philosopher'               => 'Philosopher',
			'Piedra'                    => 'Piedra',
			'Pinyon Script'             => 'Pinyon Script',
			'Pirata One'                => 'Pirata One',
			'Plaster'                   => 'Plaster',
			'Play'                      => 'Play',
			'Playball'                  => 'Playball',
			'Playfair Display'          => 'Playfair Display',
			'Playfair Display SC'       => 'Playfair Display SC',
			'Podkova'                   => 'Podkova',
			'Poiret One'                => 'Poiret One',
			'Poller One'                => 'Poller One',
			'Poly'                      => 'Poly',
			'Pompiere'                  => 'Pompiere',
			'Pontano Sans'              => 'Pontano Sans',
			'Poppins'                   => 'Poppins',
			'Port Lligat Sans'          => 'Port Lligat Sans',
			'Port Lligat Slab'          => 'Port Lligat Slab',
			'Pragati Narrow'            => 'Pragati Narrow',
			'Prata'                     => 'Prata',
			'Preahvihear'               => 'Preahvihear',
			'Press Start 2P'            => 'Press Start 2P',
			'Pridi'                     => 'Pridi',
			'Princess Sofia'            => 'Princess Sofia',
			'Prociono'                  => 'Prociono',
			'Prompt'                    => 'Prompt',
			'Prosto One'                => 'Prosto One',
			'Proza Libre'               => 'Proza Libre',
			'Puritan'                   => 'Puritan',
			'Purple Purse'              => 'Purple Purse',
			'Quando'                    => 'Quando',
			'Quantico'                  => 'Quantico',
			'Quattrocento'              => 'Quattrocento',
			'Quattrocento Sans'         => 'Quattrocento Sans',
			'Questrial'                 => 'Questrial',
			'Quicksand'                 => 'Quicksand',
			'Quintessential'            => 'Quintessential',
			'Qwigley'                   => 'Qwigley',
			'Racing Sans One'           => 'Racing Sans One',
			'Radley'                    => 'Radley',
			'Rajdhani'                  => 'Rajdhani',
			'Rakkas'                    => 'Rakkas',
			'Raleway'                   => 'Raleway',
			'Raleway Dots'              => 'Raleway Dots',
			'Ramabhadra'                => 'Ramabhadra',
			'Ramaraja'                  => 'Ramaraja',
			'Rambla'                    => 'Rambla',
			'Rammetto One'              => 'Rammetto One',
			'Ranchers'                  => 'Ranchers',
			'Rancho'                    => 'Rancho',
			'Ranga'                     => 'Ranga',
			'Rasa'                      => 'Rasa',
			'Rationale'                 => 'Rationale',
			'Ravi Prakash'              => 'Ravi Prakash',
			'Redressed'                 => 'Redressed',
			'Reem Kufi'                 => 'Reem Kufi',
			'Reenie Beanie'             => 'Reenie Beanie',
			'Revalia'                   => 'Revalia',
			'Rhodium Libre'             => 'Rhodium Libre',
			'Ribeye'                    => 'Ribeye',
			'Ribeye Marrow'             => 'Ribeye Marrow',
			'Righteous'                 => 'Righteous',
			'Risque'                    => 'Risque',
			'Roboto'                    => 'Roboto',
			'Roboto Condensed'          => 'Roboto Condensed',
			'Roboto Mono'               => 'Roboto Mono',
			'Roboto Slab'               => 'Roboto Slab',
			'Rochester'                 => 'Rochester',
			'Rock Salt'                 => 'Rock Salt',
			'Rokkitt'                   => 'Rokkitt',
			'Romanesco'                 => 'Romanesco',
			'Ropa Sans'                 => 'Ropa Sans',
			'Rosario'                   => 'Rosario',
			'Rosarivo'                  => 'Rosarivo',
			'Rouge Script'              => 'Rouge Script',
			'Rozha One'                 => 'Rozha One',
			'Rubik'                     => 'Rubik',
			'Rubik Mono One'            => 'Rubik Mono One',
			'Ruda'                      => 'Ruda',
			'Rufina'                    => 'Rufina',
			'Ruge Boogie'               => 'Ruge Boogie',
			'Ruluko'                    => 'Ruluko',
			'Rum Raisin'                => 'Rum Raisin',
			'Ruslan Display'            => 'Ruslan Display',
			'Russo One'                 => 'Russo One',
			'Ruthie'                    => 'Ruthie',
			'Rye'                       => 'Rye',
			'Sacramento'                => 'Sacramento',
			'Sahitya'                   => 'Sahitya',
			'Sail'                      => 'Sail',
			'Salsa'                     => 'Salsa',
			'Sanchez'                   => 'Sanchez',
			'Sancreek'                  => 'Sancreek',
			'Sansita'                   => 'Sansita',
			'Sarala'                    => 'Sarala',
			'Sarina'                    => 'Sarina',
			'Sarpanch'                  => 'Sarpanch',
			'Satisfy'                   => 'Satisfy',
			'Scada'                     => 'Scada',
			'Scheherazade'              => 'Scheherazade',
			'Schoolbell'                => 'Schoolbell',
			'Scope One'                 => 'Scope One',
			'Seaweed Script'            => 'Seaweed Script',
			'Secular One'               => 'Secular One',
			'Sevillana'                 => 'Sevillana',
			'Seymour One'               => 'Seymour One',
			'Shadows Into Light'        => 'Shadows Into Light',
			'Shadows Into Light Two'    => 'Shadows Into Light Two',
			'Shanti'                    => 'Shanti',
			'Share'                     => 'Share',
			'Share Tech'                => 'Share Tech',
			'Share Tech Mono'           => 'Share Tech Mono',
			'Shojumaru'                 => 'Shojumaru',
			'Short Stack'               => 'Short Stack',
			'Shrikhand'                 => 'Shrikhand',
			'Siemreap'                  => 'Siemreap',
			'Sigmar One'                => 'Sigmar One',
			'Signika'                   => 'Signika',
			'Signika Negative'          => 'Signika Negative',
			'Simonetta'                 => 'Simonetta',
			'Sintony'                   => 'Sintony',
			'Sirin Stencil'             => 'Sirin Stencil',
			'Six Caps'                  => 'Six Caps',
			'Skranji'                   => 'Skranji',
			'Slabo 13px'                => 'Slabo 13px',
			'Slabo 27px'                => 'Slabo 27px',
			'Slackey'                   => 'Slackey',
			'Smokum'                    => 'Smokum',
			'Smythe'                    => 'Smythe',
			'Sniglet'                   => 'Sniglet',
			'Snippet'                   => 'Snippet',
			'Snowburst One'             => 'Snowburst One',
			'Sofadi One'                => 'Sofadi One',
			'Sofia'                     => 'Sofia',
			'Sonsie One'                => 'Sonsie One',
			'Sorts Mill Goudy'          => 'Sorts Mill Goudy',
			'Source Code Pro'           => 'Source Code Pro',
			'Source Sans Pro'           => 'Source Sans Pro',
			'Source Serif Pro'          => 'Source Serif Pro',
			'Space Mono'                => 'Space Mono',
			'Special Elite'             => 'Special Elite',
			'Spicy Rice'                => 'Spicy Rice',
			'Spinnaker'                 => 'Spinnaker',
			'Spirax'                    => 'Spirax',
			'Squada One'                => 'Squada One',
			'Sree Krushnadevaraya'      => 'Sree Krushnadevaraya',
			'Sriracha'                  => 'Sriracha',
			'Stalemate'                 => 'Stalemate',
			'Stalinist One'             => 'Stalinist One',
			'Stardos Stencil'           => 'Stardos Stencil',
			'Stint Ultra Condensed'     => 'Stint Ultra Condensed',
			'Stint Ultra Expanded'      => 'Stint Ultra Expanded',
			'Stoke'                     => 'Stoke',
			'Strait'                    => 'Strait',
			'Sue Ellen Francisco'       => 'Sue Ellen Francisco',
			'Suez One'                  => 'Suez One',
			'Sumana'                    => 'Sumana',
			'Sunshiney'                 => 'Sunshiney',
			'Supermercado One'          => 'Supermercado One',
			'Sura'                      => 'Sura',
			'Suranna'                   => 'Suranna',
			'Suravaram'                 => 'Suravaram',
			'Suwannaphum'               => 'Suwannaphum',
			'Swanky and Moo Moo'        => 'Swanky and Moo Moo',
			'Syncopate'                 => 'Syncopate',
			'Tangerine'                 => 'Tangerine',
			'Taprom'                    => 'Taprom',
			'Tauri'                     => 'Tauri',
			'Taviraj'                   => 'Taviraj',
			'Teko'                      => 'Teko',
			'Telex'                     => 'Telex',
			'Tenali Ramakrishna'        => 'Tenali Ramakrishna',
			'Tenor Sans'                => 'Tenor Sans',
			'Text Me One'               => 'Text Me One',
			'The Girl Next Door'        => 'The Girl Next Door',
			'Tienne'                    => 'Tienne',
			'Tillana'                   => 'Tillana',
			'Timmana'                   => 'Timmana',
			'Tinos'                     => 'Tinos',
			'Titan One'                 => 'Titan One',
			'Titillium Web'             => 'Titillium Web',
			'Trade Winds'               => 'Trade Winds',
			'Trirong'                   => 'Trirong',
			'Trocchi'                   => 'Trocchi',
			'Trochut'                   => 'Trochut',
			'Trykker'                   => 'Trykker',
			'Tulpen One'                => 'Tulpen One',
			'Ubuntu'                    => 'Ubuntu',
			'Ubuntu Condensed'          => 'Ubuntu Condensed',
			'Ubuntu Mono'               => 'Ubuntu Mono',
			'Ultra'                     => 'Ultra',
			'Uncial Antiqua'            => 'Uncial Antiqua',
			'Underdog'                  => 'Underdog',
			'Unica One'                 => 'Unica One',
			'UnifrakturCook'            => 'UnifrakturCook',
			'UnifrakturMaguntia'        => 'UnifrakturMaguntia',
			'Unkempt'                   => 'Unkempt',
			'Unlock'                    => 'Unlock',
			'Unna'                      => 'Unna',
			'VT323'                     => 'VT323',
			'Vampiro One'               => 'Vampiro One',
			'Varela'                    => 'Varela',
			'Varela Round'              => 'Varela Round',
			'Vast Shadow'               => 'Vast Shadow',
			'Vesper Libre'              => 'Vesper Libre',
			'Vibur'                     => 'Vibur',
			'Vidaloka'                  => 'Vidaloka',
			'Viga'                      => 'Viga',
			'Voces'                     => 'Voces',
			'Volkhov'                   => 'Volkhov',
			'Vollkorn'                  => 'Vollkorn',
			'Voltaire'                  => 'Voltaire',
			'Waiting for the Sunrise'   => 'Waiting for the Sunrise',
			'Wallpoet'                  => 'Wallpoet',
			'Walter Turncoat'           => 'Walter Turncoat',
			'Warnes'                    => 'Warnes',
			'Wellfleet'                 => 'Wellfleet',
			'Wendy One'                 => 'Wendy One',
			'Wire One'                  => 'Wire One',
			'Work Sans'                 => 'Work Sans',
			'Yanone Kaffeesatz'         => 'Yanone Kaffeesatz',
			'Yantramanav'               => 'Yantramanav',
			'Yatra One'                 => 'Yatra One',
			'Yellowtail'                => 'Yellowtail',
			'Yeseva One'                => 'Yeseva One',
			'Yesteryear'                => 'Yesteryear',
			'Yrsa'                      => 'Yrsa',
			'Zeyada'                    => 'Zeyada',
		);

		return $spacious_googlefonts;
	}
endif;
