<?php
/**
 * Functions for configuring demo importer.
 *
 * @author   ThemeGrill
 * @category Admin
 * @package  Importer/Functions
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

add_filter( 'themegrill_demo_importer_config', 'tg_demo_importer_config' );

/**
 * Setup demo importer config.
 *
 * @param  array $demo_config
 * @return array
 */
function tg_demo_importer_config( $demo_config ) {
	$new_demo_config = array(
		'spacious-pro' => array(
			'name'         => __( 'Spacious Pro', 'spacious' ),
			'demo_url'     => 'https://demo.themegrill.com/spacious-pro/',
			'demo_pack'    => false,
			'theme'        => 'Spacious Pro',
			'template'     => 'spacious-pro',
			'core_options' => array(
				'blogname'       => 'Spacious Pro',
				'page_on_front'  => 'Home',
				'page_for_posts' => 'Blog',
			),
			'widgets_data_update' => array(

				/**
				 * Dropdown Pages - Handles widgets Page ID.
				 *
				 * 1. spacious_service_widget
				 * 2. spacious_featured_single_page_widget
				 * 3. spacious_recent_work_widget
				 * 4. spacious_team_widget
				 */
				'dropdown_pages' => array(
					'spacious_service_widget' => array(
						2 => array(
							'page_id0' => 'Responsive and Retina Ready',
							'page_id1' => 'Unlimited Color Options',
							'page_id2' => 'Advanced Typography Options',
						)
					),
					'spacious_featured_single_page_widget' => array(
						2 => array(
							'page_id' => 'Endless Possibilities',
						)
					),
					'spacious_recent_work_widget' => array(
						2 => array(
							'page_id0' => 'Awesome photography',
							'page_id1' => 'Recent Work Mac',
							'page_id2' => 'Filament bulb',
						)
					),
					'spacious_team_widget' => array(
						3 => array(
							'page_0' => 'Anjila Lamahal',
							'page_1' => 'Shirley Mathew',
							'page_2' => 'Deniala Willson',
						)
					)
				),
			),
			'customizer_data_update' => array(
				'nav_menu_locations' => array(
					'header'    => 'Header Top Menu',
					'primary'   => 'Primary',
					'footer'    => 'Spacious Pro',
				)
			),
			'plugins_list' => array(
				'recommended' => array(
					'contact-form-7' => array(
						'name' => __( 'Contact Form', 'spacious' ),
						'slug' => 'contact-form-7/wp-contact-form-7.php',
					),
					'breadcrumb-navxt' => array(
						'name' => __( 'Breadcrumb NavXT', 'spacious' ),
						'slug' => 'breadcrumb-navxt/breadcrumb-navxt.php',
					),
					'woocommerce' => array(
						'name' => __( 'WooCommerce', 'spacious' ),
						'slug' => 'woocommerce/woocommerce.php',
					),
					'recent-posts-widget-extended' => array(
						'name' => __( 'Recent Posts Widget Extended', 'spacious' ),
						'slug' => 'recent-posts-widget-extended/rpwe.php',
					)
				)
			)
		),
	);

	return array_merge( $new_demo_config, $demo_config );
}
