<?php
/**
 * Spacious functions and definitions
 *
 * This file contains all the functions and it's defination that particularly can't be
 * in other files.
 *
 * @package    ThemeGrill
 * @subpackage Spacious
 * @since      Spacious 1.0
 */

/****************************************************************************************/

// Spacious theme options
function spacious_options( $id, $default = false ) {
	// getting options value
	$spacious_options = get_option( 'spacious' );
	if ( isset( $spacious_options[ $id ] ) ) {
		return $spacious_options[ $id ];
	} else {
		return $default;
	}
}

/****************************************************************************************/

add_action( 'wp_enqueue_scripts', 'spacious_scripts_styles_method' );
/**
 * Register jquery scripts
 */
function spacious_scripts_styles_method() {

	$suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	/**
	 * Loads our main stylesheet.
	 */
	wp_enqueue_style( 'spacious_style', get_stylesheet_uri() );

	if ( spacious_options( 'spacious_color_skin', 'light' ) == 'dark' ) {
		wp_enqueue_style( 'spacious_dark_style', SPACIOUS_CSS_URL . '/dark' . $suffix . '.css' );
	}

	// Add Genericons, used in the main stylesheet.
	wp_enqueue_style( 'spacious-genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.3.1' );

	// Enqueue font-awesome style.
	wp_enqueue_style( 'spacious-font-awesome', get_template_directory_uri() . '/font-awesome/css/font-awesome' . $suffix . '.css', array(), '4.6.3' );

	$spacious_googlefonts = array();
	array_push( $spacious_googlefonts, spacious_options( 'spacious_site_title_font', 'Lato' ) );
	array_push( $spacious_googlefonts, spacious_options( 'spacious_site_tagline_font', 'Lato' ) );
	array_push( $spacious_googlefonts, spacious_options( 'spacious_menu_font', 'Lato' ) );
	array_push( $spacious_googlefonts, spacious_options( 'spacious_titles_font', 'Lato' ) );
	array_push( $spacious_googlefonts, spacious_options( 'spacious_content_font', 'Lato' ) );

	$spacious_googlefonts = array_unique( $spacious_googlefonts );
	$spacious_googlefonts = implode( "|", $spacious_googlefonts );

	wp_register_style( 'spacious_googlefonts', '//fonts.googleapis.com/css?family=' . $spacious_googlefonts );
	wp_enqueue_style( 'spacious_googlefonts' );

	/**
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/**
	 * Enqueue Slider setup js file.
	 */
	// Register jQuery Cycle 2 JS
	wp_register_script( 'jquery_cycle', SPACIOUS_JS_URL . '/jquery.cycle2' . $suffix . '.js', array( 'jquery' ), '2.1.6', true );
	wp_register_script( 'jquery-swipe', SPACIOUS_JS_URL . '/jquery.cycle2.swipe' . $suffix . '.js', array( 'jquery' ), false, true );


	if ( spacious_options( 'spacious_activate_slider', '0' ) == '1' ) {

		$transition_effect   = spacious_options( 'spacious_slider_transition_effect', 'fade' );
		$transition_delay    = spacious_options( 'spacious_slider_transition_delay', 4 );
		$transition_duration = spacious_options( 'spacious_slider_transition_length', 1 );
		$pauseonhover        = spacious_options( 'spacious_slider_pause_on_hover_option', 1 );

		$transition_delay    = intval( $transition_delay );
		$transition_duration = intval( $transition_duration );

		if ( $transition_delay != 0 ) {
			$transition_delay = $transition_delay * 1000;
		} else {
			$transition_delay = 4000;
		}

		if ( $transition_duration != 0 ) {
			$transition_duration = $transition_duration * 1000;
		} else {
			$transition_duration = 1000;
		}
		if ( ( spacious_options( 'spacious_slider_status', 'home_front_page' ) == 'all_page' ) || is_front_page() || ( is_home() && spacious_options( 'spacious_slider_status', 'home_front_page' ) == 'home_front_page' ) ) {
			wp_enqueue_script( 'jquery_cycle' );
			wp_enqueue_script( 'jquery-swipe' );
			wp_localize_script( 'jquery_cycle', 'spacious_slider_value',
				array(
					'transition_effect'   => $transition_effect,
					'transition_delay'    => $transition_delay,
					'transition_duration' => $transition_duration,
					'pauseonhover'        => $pauseonhover,
				)
			);
		}
	}

	// Waypoints Script Register
	wp_register_script( 'jquery-waypoints', SPACIOUS_JS_URL . '/waypoints' . $suffix . '.js', array( 'jquery' ), '2.0.3', true );

	// CounterUp Script Register
	wp_register_script( 'jquery-counterup', SPACIOUS_JS_URL . '/jquery.counterup' . $suffix . '.js', array( 'jquery' ), false, true );

	// Theia Sticky Sidebar enqueue
	if ( spacious_options( 'spacious_sticky_content_sidebar', '0' ) == '1' ) {
		wp_enqueue_script( 'theia-sticky-sidebar', SPACIOUS_JS_URL . '/theia-sticky-sidebar/theia-sticky-sidebar' . $suffix . '.js', array( 'jquery' ), '1.7.0', true );
		wp_enqueue_script( 'ResizeSensor', SPACIOUS_JS_URL . '/theia-sticky-sidebar/ResizeSensor' . $suffix . '.js', array( 'jquery' ), false, true );
	}

	wp_enqueue_script( 'spacious-navigation', SPACIOUS_JS_URL . '/navigation' . $suffix . '.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'spacious-custom', SPACIOUS_JS_URL . '/spacious-custom' . $suffix . '.js', array( 'jquery' ), false, true );

	wp_enqueue_style( 'google_fonts' );

	// HTML5Shiv for Lower IE versions
	wp_enqueue_script( 'html5', SPACIOUS_JS_URL . '/html5shiv' . $suffix . '.js', true );
	wp_script_add_data( 'html5', 'conditional', 'lte IE 8' );

}

/****************************************************************************************/

/**
 * Add admin scripts and styles.
 */

function spacious_admin_scripts( $hook ) {
	global $post_type;

	if ( $hook == 'widgets.php' || $hook == 'customize.php' ) {

		//For image uploader
		wp_enqueue_media();

		//For color
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'spacious-color-picker', SPACIOUS_JS_URL . '/color-picker.js', array( 'jquery' ), false, true );

		// Load media uploader and admin js
		wp_enqueue_script( 'media-upload' );
		wp_enqueue_media();
		wp_enqueue_script( 'spacious-admin-script', SPACIOUS_JS_URL . '/spacious-admin.js', array( 'jquery' ) );
	}
}

add_action( 'admin_enqueue_scripts', 'spacious_admin_scripts' );

/****************************************************************************************/

add_filter( 'excerpt_length', 'spacious_excerpt_length' );
/**
 * Sets the post excerpt length to 40 words.
 *
 * function tied to the excerpt_length filter hook.
 *
 * @uses filter excerpt_length
 */
function spacious_excerpt_length( $length ) {
	$excerpt_length = spacious_options( 'spacious_excerpt_length', '40' );

	return $excerpt_length;
}

add_filter( 'excerpt_more', 'spacious_continue_reading' );
/**
 * Returns a "Continue Reading" link for excerpts
 */
function spacious_continue_reading() {
	return '';
}

/****************************************************************************************/

/**
 * Removing the default style of wordpress gallery
 */
add_filter( 'use_default_gallery_style', '__return_false' );

/**
 * Filtering the size to be medium from thumbnail to be used in WordPress gallery as a default size
 */
function spacious_gallery_atts( $out, $pairs, $atts ) {
	$atts = shortcode_atts( array(
		'size' => 'medium',
	), $atts );

	$out[ 'size' ] = $atts[ 'size' ];

	return $out;

}

add_filter( 'shortcode_atts_gallery', 'spacious_gallery_atts', 10, 3 );

/****************************************************************************************/

add_filter( 'body_class', 'spacious_body_class' );
/**
 * Filter the body_class
 *
 * Throwing different body class for the different layouts in the body tag
 */
function spacious_body_class( $classes ) {
	global $post;

	if ( $post ) {
		$layout_meta = get_post_meta( $post->ID, 'spacious_page_layout', true );
	}

	if ( is_home() ) {
		$queried_id  = get_option( 'page_for_posts' );
		$layout_meta = get_post_meta( $queried_id, 'spacious_page_layout', true );
	}

	if ( empty( $layout_meta ) || is_archive() || is_search() ) {
		$layout_meta = 'default_layout';
	}

	$spacious_default_layout      = spacious_options( 'spacious_default_layout', 'right_sidebar' );
	$spacious_default_page_layout = spacious_options( 'spacious_pages_default_layout', 'right_sidebar' );
	$spacious_default_post_layout = spacious_options( 'spacious_single_posts_default_layout', 'right_sidebar' );
	$spacious_woo_archive_layout  = spacious_options( 'spacious_woo_archive_layout', 'no_sidebar_full_width' );
	$spacious_woo_product_layout  = spacious_options( 'spacious_woo_product_layout', 'no_sidebar_full_width' );

	if ( $layout_meta == 'default_layout' ) {
		if ( is_page() ) {
			if ( $spacious_default_page_layout == 'right_sidebar' ) {
				$classes[] = '';
			} else if ( $spacious_default_page_layout == 'left_sidebar' ) {
				$classes[] = 'left-sidebar';
			} else if ( $spacious_default_page_layout == 'no_sidebar_full_width' ) {
				$classes[] = 'no-sidebar-full-width';
			} else if ( $spacious_default_page_layout == 'no_sidebar_content_centered' ) {
				$classes[] = 'no-sidebar';
			}
		} else if ( function_exists( 'spacious_is_in_woocommerce_page' ) && is_product() ) {
			if ( $spacious_woo_product_layout == 'right_sidebar' ) {
				$classes[] = '';
			} else if ( $spacious_woo_product_layout == 'left_sidebar' ) {
				$classes[] = 'left-sidebar';
			} else if ( $spacious_woo_product_layout == 'no_sidebar_full_width' ) {
				$classes[] = 'no-sidebar-full-width';
			} else if ( $spacious_woo_product_layout == 'no_sidebar_content_centered' ) {
				$classes[] = 'no-sidebar';
			}
		} else if ( is_single() ) {
			if ( $spacious_default_post_layout == 'right_sidebar' ) {
				$classes[] = '';
			} else if ( $spacious_default_post_layout == 'left_sidebar' ) {
				$classes[] = 'left-sidebar';
			} else if ( $spacious_default_post_layout == 'no_sidebar_full_width' ) {
				$classes[] = 'no-sidebar-full-width';
			} else if ( $spacious_default_post_layout == 'no_sidebar_content_centered' ) {
				$classes[] = 'no-sidebar';
			}
		} else if ( function_exists( 'spacious_is_in_woocommerce_page' ) && spacious_is_in_woocommerce_page() ) {
			if ( $spacious_woo_archive_layout == 'right_sidebar' ) {
				$classes[] = '';
			} else if ( $spacious_woo_archive_layout == 'left_sidebar' ) {
				$classes[] = 'left-sidebar';
			} else if ( $spacious_woo_archive_layout == 'no_sidebar_full_width' ) {
				$classes[] = 'no-sidebar-full-width';
			} else if ( $spacious_woo_archive_layout == 'no_sidebar_content_centered' ) {
				$classes[] = 'no-sidebar';
			}
		} else if ( $spacious_default_layout == 'right_sidebar' ) {
			$classes[] = '';
		} else if ( $spacious_default_layout == 'left_sidebar' ) {
			$classes[] = 'left-sidebar';
		} else if ( $spacious_default_layout == 'no_sidebar_full_width' ) {
			$classes[] = 'no-sidebar-full-width';
		} else if ( $spacious_default_layout == 'no_sidebar_content_centered' ) {
			$classes[] = 'no-sidebar';
		}
	} else if ( $layout_meta == 'right_sidebar' ) {
		$classes[] = '';
	} else if ( $layout_meta == 'left_sidebar' ) {
		$classes[] = 'left-sidebar';
	} else if ( $layout_meta == 'no_sidebar_full_width' ) {
		$classes[] = 'no-sidebar-full-width';
	} else if ( $layout_meta == 'no_sidebar_content_centered' ) {
		$classes[] = 'no-sidebar';
	}

	if ( spacious_options( 'spacious_new_menu', '1' ) == '1' ) {
		$classes[] = 'better-responsive-menu';
	}

	if ( is_page_template( 'page-templates/blog-image-alternate-medium.php' ) || ( ( is_archive() || is_home() ) && spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_alternate' ) ) {
		$classes[] = 'blog-alternate-medium';
	}
	if ( is_page_template( 'page-templates/blog-image-medium.php' ) || ( ( is_archive() || is_home() ) && spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium' ) ) {
		$classes[] = 'blog-medium';
	}
	if ( is_page_template( 'page-templates/blog-image-round-alternate-medium.php' ) || ( ( is_archive() || is_home() ) && spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_round_alternate' ) ) {
		$classes[] = 'blog-alternate-medium blog-round-alternate-medium';
	}
	if ( is_page_template( 'page-templates/blog-image-round-medium.php' ) || ( ( is_archive() || is_home() ) && spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_round' ) ) {
		$classes[] = 'blog-medium blog-round-medium';
	}
	if ( spacious_options( 'spacious_site_layout', 'box_1218px' ) == 'wide_978px' ) {
		$classes[] = 'wide-978';
	} else if ( spacious_options( 'spacious_site_layout', 'box_1218px' ) == 'box_978px' ) {
		$classes[] = 'narrow-978';
	} else if ( spacious_options( 'spacious_site_layout', 'box_1218px' ) == 'wide_1218px' ) {
		$classes[] = 'wide-1218';
	} else {
		$classes[] = '';
	}

	return $classes;
}

/****************************************************************************************/

if ( ! function_exists( 'spacious_sidebar_select' ) ) :
	/**
	 * Fucntion to select the sidebar
	 */
	function spacious_sidebar_select() {
		global $post;

		if ( $post ) {
			$layout_meta = get_post_meta( $post->ID, 'spacious_page_layout', true );
		}

		if ( is_home() ) {
			$queried_id  = get_option( 'page_for_posts' );
			$layout_meta = get_post_meta( $queried_id, 'spacious_page_layout', true );
		}

		if ( empty( $layout_meta ) || is_archive() || is_search() ) {
			$layout_meta = 'default_layout';
		}

		$spacious_default_layout      = spacious_options( 'spacious_default_layout', 'right_sidebar' );
		$spacious_default_page_layout = spacious_options( 'spacious_pages_default_layout', 'right_sidebar' );
		$spacious_default_post_layout = spacious_options( 'spacious_single_posts_default_layout', 'right_sidebar' );

		if ( $layout_meta == 'default_layout' ) {
			if ( is_page() ) {
				if ( $spacious_default_page_layout == 'right_sidebar' ) {
					get_sidebar();
				} else if ( $spacious_default_page_layout == 'left_sidebar' ) {
					get_sidebar( 'left' );
				}
			} else if ( is_single() ) {
				if ( $spacious_default_post_layout == 'right_sidebar' ) {
					get_sidebar();
				} else if ( $spacious_default_post_layout == 'left_sidebar' ) {
					get_sidebar( 'left' );
				}
			} else if ( $spacious_default_layout == 'right_sidebar' ) {
				get_sidebar();
			} else if ( $spacious_default_layout == 'left_sidebar' ) {
				get_sidebar( 'left' );
			}
		} else if ( $layout_meta == 'right_sidebar' ) {
			get_sidebar();
		} else if ( $layout_meta == 'left_sidebar' ) {
			get_sidebar( 'left' );
		}
	}
endif;

/****************************************************************************************/

if ( ! function_exists( 'spacious_posts_listing_display_type_select' ) ) :
	/**
	 * Function to select the posts listing display type
	 */
	function spacious_posts_listing_display_type_select() {
		if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_large' ) {
			$format = 'blog-image-large';
		} else if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium' ) {
			$format = 'blog-image-medium';
		} else if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_alternate' ) {
			$format = 'blog-image-medium';
		} else if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_round' ) {
			$format = 'blog-image-medium';
		} else if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_medium_round_alternate' ) {
			$format = 'blog-image-medium';
		} else if ( spacious_options( 'spacious_archive_display_type', 'blog_large' ) == 'blog_full_content' ) {
			$format = 'blog-full-content';
		} else {
			$format = get_post_format();
		}

		return $format;
	}
endif;

/****************************************************************************************/

add_action( 'admin_head', 'spacious_favicon' );
add_action( 'wp_head', 'spacious_favicon' );
/**
 * Fav icon for the site
 */
function spacious_favicon() {
	if ( spacious_options( 'spacious_activate_favicon', '0' ) == '1' ) {
		$spacious_favicon        = spacious_options( 'spacious_favicon', '' );
		$spacious_favicon_output = '';
		if ( function_exists( 'has_site_icon' ) && ( ! empty( $spacious_favicon ) && ! has_site_icon() ) ) {
			$spacious_favicon_output .= '<link rel="shortcut icon" href="' . esc_url( $spacious_favicon ) . '" type="image/x-icon" />';
		}
		echo $spacious_favicon_output;
	}
}

/****************************************************************************************/

/**
 * Change hex code to RGB
 * Source: https://css-tricks.com/snippets/php/convert-hex-to-rgb/#comment-1052011
 */
function spacious_hex2rgb( $hexstr ) {
	$int = hexdec( $hexstr );
	$rgb = array( "red" => 0xFF & ( $int >> 0x10 ), "green" => 0xFF & ( $int >> 0x8 ), "blue" => 0xFF & $int );
	$r   = $rgb[ 'red' ];
	$g   = $rgb[ 'green' ];
	$b   = $rgb[ 'blue' ];

	return "rgba($r,$g,$b, 0.85)";
}

/**
 * Generate darker color
 * Source: http://stackoverflow.com/questions/3512311/how-to-generate-lighter-darker-color-with-php
 */
function spacious_darkcolor( $hex, $steps ) {
	// Steps should be between -255 and 255. Negative = darker, positive = lighter
	$steps = max( - 255, min( 255, $steps ) );

	// Normalize into a six character long hex string
	$hex = str_replace( '#', '', $hex );
	if ( strlen( $hex ) == 3 ) {
		$hex = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
	}

	// Split into three parts: R, G and B
	$color_parts = str_split( $hex, 2 );
	$return      = '#';

	foreach ( $color_parts as $color ) {
		$color  = hexdec( $color ); // Convert to decimal
		$color  = max( 0, min( 255, $color + $steps ) ); // Adjust color
		$return .= str_pad( dechex( $color ), 2, '0', STR_PAD_LEFT ); // Make two char hex code
	}

	return $return;
}


/****************************************************************************************/

add_action( 'wp_head', 'spacious_custom_css', 100 );
/**
 * Hooks the Custom Internal CSS to head section
 */
function spacious_custom_css() {
	$spacious_internal_css = '';

	if ( spacious_options( 'spacious_header_display_type', 'one' ) == 'two' ) {
		$spacious_internal_css .= ' #header-left-section { float: right; margin-right: 0; } #header-right-section { float: left; } #header-logo-image { padding: 0 0 0 20px; } #header-text { padding: 15px 0 0 20px; } #header-right-section .widget { text-align: left; } .main-navigation li { padding: 0 20px 0 0; } .main-navigation ul li ul { left: 0 } #masthead .search-wrap span { left: 170px; } @media screen and (max-width:768px){#header-left-section{float:none;max-width:100%;margin-right:0}#header-logo-image{float:none;text-align:center;margin-bottom:10px}#header-text{float:none;text-align:center;padding:0;margin-bottom:10px}#site-description{padding-bottom:5px}#header-right-section{float:none;max-width:100%}#header-right-section .widget{padding:0 0 10px;float:none;text-align:center}#masthead .search-wrap span{right: auto;left: auto;}}' . "\n";
	} else if ( spacious_options( 'spacious_header_display_type', 'one' ) == 'three' ) {
		$spacious_internal_css .= ' #header-text-nav-wrap {text-align: center;} #header-left-section {float: none;margin: 0 auto;display: inline-block;} #header-logo-image{float: none;display: inline-block;vertical-align: top;} #header-text {float: none;display: inline-block;vertical-align: top;} #header-right-section .widget {text-align: center;} #header-right-section {float: none;} .main-navigation {float: none;} .main-navigation li {float: none;display: inline-block;} @media screen and (max-width:768px){.main-small-navigation li{text-align:left;}}' . "\n";
	} else {
		$spacious_internal_css .= '';
	}

	if ( spacious_options( 'spacious_top_bar_display_type', 'one' ) == 'two' ) {
		$spacious_internal_css .= ' .social-links { float: right; padding: 0 0 0 15px; } .social-links ul li { float: left; padding: 5px 0 5px 10px; } .small-info-text { float: right; padding: 0 0 0 15px; } #masthead .small-menu { float: left; } #masthead .small-menu a { padding: 5px 16px 0 0; } @media screen and (max-width:767px){.social-links{text-align:center;float:none;padding-left:0;padding-top:10px}.small-info-text{text-align:center;float:none;padding-left:0}.social-links ul li,.social-links ul li a{float:none;display:inline}#header-meta .small-menu{text-align:center;float:none}#header-meta .small-menu li{float:none;display:inline}#header-meta .small-menu a{float:none;display:inline;padding:5px 5px 0}}' . "\n";
	} else {
		$spacious_internal_css .= '';
	}

	$primary_color   = spacious_options( 'spacious_primary_color', '#0FBE7C' );
	$primary_opacity = spacious_hex2rgb( $primary_color );
	$primary_dark    = spacious_darkcolor( $primary_color, - 50 );

	if ( $primary_color != '#0FBE7C' && $primary_color != '#0fbe7c' ) {
		$spacious_internal_css .= ' blockquote { border-left: 3px solid ' . $primary_color . '; }
			.spacious-button, input[type="reset"], input[type="button"], input[type="submit"], button { background-color: ' . $primary_color . '; }
			.previous a:hover, .next a:hover { 	color: ' . $primary_color . '; }
			a { color: ' . $primary_color . '; }
			#site-title a:hover,.widget_fun_facts .counter-icon,.team-title a:hover { color: ' . $primary_color . '; }
			.main-navigation ul li.current_page_item a, .main-navigation ul li:hover > a { color: ' . $primary_color . '; }
			.main-navigation ul li ul { border-top: 1px solid ' . $primary_color . '; }
			.main-navigation ul li ul li a:hover, .main-navigation ul li ul li:hover > a,
			.main-navigation ul li.current-menu-item ul li a:hover { color: ' . $primary_color . '; }
			.site-header .menu-toggle:hover.entry-meta a.read-more:hover,#featured-slider .slider-read-more-button:hover,
			.call-to-action-button:hover,.entry-meta .read-more-link:hover,.spacious-button:hover, input[type="reset"]:hover,
			input[type="button"]:hover, input[type="submit"]:hover,	button:hover { background: ' . $primary_dark . '; }
			.main-small-navigation li:hover { background: ' . $primary_color . '; }
			.main-small-navigation ul > .current_page_item, .main-small-navigation ul > .current-menu-item { background: ' . $primary_color . '; }
			.main-navigation a:hover, .main-navigation ul li.current-menu-item a, .main-navigation ul li.current_page_ancestor a,
			.main-navigation ul li.current-menu-ancestor a, .main-navigation ul li.current_page_item a,
			.main-navigation ul li:hover > a  { color: ' . $primary_color . '; }
			.small-menu a:hover, .small-menu ul li.current-menu-item a, .small-menu ul li.current_page_ancestor a,
			.small-menu ul li.current-menu-ancestor a, .small-menu ul li.current_page_item a,
			.small-menu ul li:hover > a { color: ' . $primary_color . '; }
			#featured-slider .slider-read-more-button,.widget_our_clients .clients-cycle-prev,
			.widget_our_clients .clients-cycle-next { background-color: ' . $primary_color . '; }
			#controllers a:hover, #controllers a.active { background-color: ' . $primary_color . '; color: ' . $primary_color . '; }
			.widget_service_block a.more-link:hover, .widget_featured_single_post a.read-more:hover,
			#secondary a:hover,logged-in-as:hover  a{ color: ' . $primary_dark . '; }
			.breadcrumb a:hover { color: ' . $primary_color . '; }
			.tg-one-half .widget-title a:hover, .tg-one-third .widget-title a:hover,
			.tg-one-fourth .widget-title a:hover { color: ' . $primary_color . '; }
			.pagination span,.site-header .menu-toggle:hover,#team-controllers a.active,
			#team-controllers a:hover { background-color: ' . $primary_color . '; }
			.pagination a span:hover { color: ' . $primary_color . '; border-color: ' . $primary_color . '; }
			.widget_testimonial .testimonial-post { border-color: ' . $primary_color . ' #EAEAEA #EAEAEA #EAEAEA; }
			.call-to-action-content-wrapper { border-color: #EAEAEA #EAEAEA #EAEAEA ' . $primary_color . '; }
			.call-to-action-button { background-color: ' . $primary_color . '; }
			#content .comments-area a.comment-permalink:hover { color: ' . $primary_color . '; }
			.comments-area .comment-author-link a:hover { color: ' . $primary_color . '; }
			.comments-area .comment-author-link spanm,.team-social-icon a:hover { background-color: ' . $primary_color . '; }
			.comment .comment-reply-link:hover { color: ' . $primary_color . '; }
			.team-social-icon a:hover{ border-color: ' . $primary_color . '; }
			.nav-previous a:hover, .nav-next a:hover { color: ' . $primary_color . '; }
			#wp-calendar #today { color: ' . $primary_color . '; }
			.widget-title span { border-bottom: 2px solid ' . $primary_color . '; }
			.footer-widgets-area a:hover { color: ' . $primary_color . ' !important; }
			.footer-socket-wrapper .copyright a:hover { color: ' . $primary_color . '; }
			a#back-top:before { background-color: ' . $primary_color . '; }
			.read-more, .more-link { color: ' . $primary_color . '; }
			.post .entry-title a:hover, .page .entry-title a:hover { color: ' . $primary_color . '; }
			.entry-meta .read-more-link { background-color: ' . $primary_color . '; }
			.entry-meta a:hover, .type-page .entry-meta a:hover { color: ' . $primary_color . '; }
			.single #content .tags a:hover { color: ' . $primary_color . '; }
			.widget_testimonial .testimonial-icon:before { color: ' . $primary_color . '; }
			a#scroll-up { background-color: ' . $primary_color . '; }
			#search-form span { background-color: ' . $primary_color . '; }
			.single #content .tags a:hover,.previous a:hover, .next a:hover{border-color: ' . $primary_color . ';}
			.widget_featured_posts .tg-one-half .entry-title a:hover,
			.main-small-navigation li:hover > .sub-toggle { color: ' . $primary_color . '; }
			.woocommerce a.button, .woocommerce button.button, .woocommerce input.button,
			.woocommerce #respond input#submit, .woocommerce #content input.button,
			.woocommerce-page a.button, .woocommerce-page button.button, .woocommerce-page input.button,
			.woocommerce-page #respond input#submit, .woocommerce-page #content input.button { background-color: ' . $primary_color . '; }
			.woocommerce a.button:hover,.woocommerce button.button:hover,
			.woocommerce input.button:hover,.woocommerce #respond input#submit:hover,
			.woocommerce #content input.button:hover,.woocommerce-page a.button:hover,
			.woocommerce-page button.button:hover,.woocommerce-page input.button:hover,
			.woocommerce-page #respond input#submit:hover,
			.woocommerce-page #content input.button:hover { background-color: ' . $primary_color . '; }
			#content .wp-pagenavi .current, #content .wp-pagenavi a:hover,.sub-toggle { background-color: ' . $primary_color . '; }';
	}

	/* Typography */
	// Font family option
	if ( spacious_options( 'spacious_site_title_font', 'Lato' ) ) {
		$spacious_internal_css .= ' #site-title a { font-family: "' . spacious_options( 'spacious_site_title_font', 'Lato' ) . '"; }';
	}
	if ( spacious_options( 'spacious_site_tagline_font', 'Lato' ) != 'Lato' ) {
		$spacious_internal_css .= ' #site-description { font-family: "' . spacious_options( 'spacious_site_tagline_font', 'Lato' ) . '"; }';
	}
	if ( spacious_options( 'spacious_menu_font', 'Lato' ) != 'Lato' ) {
		$spacious_internal_css .= ' .main-navigation li, .small-menu li { font-family: "' . spacious_options( 'spacious_menu_font', 'Lato' ) . '"; }';
	}
	if ( spacious_options( 'spacious_titles_font', 'Lato' ) != 'Lato' ) {
		$spacious_internal_css .= ' h1, h2, h3, h4, h5, h6 { font-family: "' . spacious_options( 'spacious_titles_font', 'Lato' ) . '"; }';
	}
	if ( spacious_options( 'spacious_content_font', 'Lato' ) != 'Lato' ) {
		$spacious_internal_css .= ' body, button, input, select, textarea, p, .entry-meta, .read-more, .more-link, .widget_testimonial .testimonial-author, #featured-slider .slider-read-more-button { font-family: "' . spacious_options( 'spacious_content_font', 'Lato' ) . '"; }';
	}

	//Font size option
	$spacious_fonts_size_custom = spacious_font_size_func();

	foreach ( $spacious_fonts_size_custom as $spacious_font ) {

		$spacious_font_size_setting = $spacious_font[ 'spacious_font_size_setting' ];
		foreach ( $spacious_font_size_setting as $spacious_font_size_css ) {

			if ( spacious_options( $spacious_font_size_css[ 'id' ], $spacious_font_size_css[ 'default' ] ) != $spacious_font_size_css[ 'default' ] ) {
				$spacious_internal_css .= $spacious_font_size_css[ 'custom_css' ] . '{ font-size: ' . spacious_options( $spacious_font_size_css[ 'id' ], $spacious_font_size_css[ 'default' ] ) . 'px; }';
			}
		}
	}// End of Font Size Options

	// Color Options
	$spacious_color_custom = spacious_color_func();

	foreach ( $spacious_color_custom as $spacious_color ) {

		$spacious_color_settings = $spacious_color[ 'spacious_color_settings' ];
		foreach ( $spacious_color_settings as $spacious_color_css ) {

			if ( spacious_options( $spacious_color_css[ 'id' ], $spacious_color_css[ 'default' ] ) != $spacious_color_css[ 'default' ] ) {
				$spacious_internal_css .= $spacious_color_css[ 'color_custom_css' ] . spacious_options( $spacious_color_css[ 'id' ], $spacious_color_css[ 'default' ] ) . '; }';
			}
		}
	}
	if ( spacious_options( 'spacious_border_lines_color', '#EAEAEA' ) != '#EAEAEA' ) {
		$border_color          = spacious_options( 'spacious_border_lines_color', '#EAEAEA' );
		$primary_color         = spacious_options( 'spacious_primary_color', '#0FBE7C' );
		$spacious_internal_css .= ' th, td { border: 1px solid ' . $border_color . '; } hr { border-color: ' . $border_color . '; } blockquote,input.s,input[type=email],input[type=email]:focus,input[type=password],input[type=password]:focus,input[type=search]:focus,input[type=text],input[type=text]:focus,pre,textarea,textarea:focus{border:1px solid ' . $border_color . '}input.s:focus{border-color:' . $border_color . '}.next a,.previous a{border:1px solid ' . $border_color . '}#featured-slider,#header-meta,#header-text-nav-container,.header-image,.header-post-title-container,.main-navigation ul li ul li{border-bottom:1px solid ' . $border_color . '}.meta{border-bottom:1px dashed ' . $border_color . ';border-top:1px dashed ' . $border_color . '}.meta li{border-left:1px solid ' . $border_color . '}.pagination span{border:1px solid ' . $border_color . '}.widget_testimonial .testimonial-post{border-color:' . $primary_color . ' ' . $border_color . ' ' . $border_color . '}.call-to-action-content-wrapper{border-color:' . $border_color . ' ' . $border_color . ' ' . $border_color . ' ' . $primary_color . '}.comment-content,.nav-next a,.nav-previous a{border:1px solid ' . $border_color . '}#colophon .widget ul li,#secondary .widget ul li{border-bottom:1px solid ' . $border_color . '}.footer-socket-wrapper,.footer-widgets-wrapper{border-top:1px solid ' . $border_color . '}.entry-meta,.single #content .tags a{border:1px solid ' . $border_color . '};';
	} // End of Color Options

	// entry meta for author remove
	if ( spacious_options( 'spacious_post_meta_author', 0 ) == 1 ) {
		$spacious_internal_css .= '.entry-meta .by-author{display:none;}';
	}

	// entry meta for date remove
	if ( spacious_options( 'spacious_post_meta_date', 0 ) == 1 ) {
		$spacious_internal_css .= '.entry-meta .date{display:none;}';
	}

	// entry meta bar full disable
	if ( spacious_options( 'spacious_post_meta_full', 0 ) == 1 ) {
		$spacious_internal_css .= '.entry-meta-bar{display:none;}';
	}

	if ( ! empty( $spacious_internal_css ) ) {
		?>
		<style type="text/css"><?php echo $spacious_internal_css; ?></style>
		<?php
	}

	$spacious_custom_css = spacious_options( 'spacious_custom_css', '' );
	if ( ! empty( $spacious_custom_css ) ) {
		?>
		<style type="text/css"><?php echo $spacious_custom_css; ?></style>
		<?php
	}
}

/**************************************************************************************/

if ( ! function_exists( 'spacious_content_nav' ) ) :
	/**
	 * Display navigation to next/previous pages when applicable
	 */
	function spacious_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next     = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

		?>
		<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo $nav_class; ?>">
			<h3 class="screen-reader-text"><?php _e( 'Post navigation', 'spacious' ); ?></h3>

			<?php if ( is_single() ) : // navigation links for single posts ?>

				<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'spacious' ) . '</span> %title' ); ?>
				<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'spacious' ) . '</span>' ); ?>

			<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

				<?php if ( get_next_posts_link() ) : ?>
					<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'spacious' ) ); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link() ) : ?>
					<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'spacious' ) ); ?></div>
				<?php endif; ?>

			<?php endif; ?>

		</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
		<?php
	}
endif; // spacious_content_nav

/**************************************************************************************/

if ( ! function_exists( 'spacious_comment' ) ) :
	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 */
	function spacious_comment( $comment, $args, $depth ) {
		$GLOBALS[ 'comment' ] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
				// Display trackbacks differently than normal comments.
				?>
				<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
				<p><?php _e( 'Pingback:', 'spacious' ); ?><?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'spacious' ), '<span class="edit-link">', '</span>' ); ?></p>
				<?php
				break;
			default :
				// Proceed with normal comments.
				global $post;
				?>
				<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<article id="comment-<?php comment_ID(); ?>" class="comment">
					<header class="comment-meta comment-author vcard">
						<?php
						echo get_avatar( $comment, 74 );
						printf( '<div class="comment-author-link">%1$s%2$s</div>',
							get_comment_author_link(),
							// If current post author is also comment author, make it known visually.
							( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'spacious' ) . '</span>' : ''
						);
						printf( '<div class="comment-date-time">%1$s</div>',
							sprintf( __( '%1$s at %2$s', 'spacious' ), get_comment_date(), get_comment_time() )
						);
						printf( __( '<a class="comment-permalink" href="%1$s">Permalink</a>', 'spacious' ), esc_url( get_comment_link( $comment->comment_ID ) ) );
						edit_comment_link();
						?>
					</header><!-- .comment-meta -->

					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'spacious' ); ?></p>
					<?php endif; ?>

					<section class="comment-content comment">
						<?php comment_text(); ?>
						<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'spacious' ), 'after' => '', 'depth' => $depth, 'max_depth' => $args[ 'max_depth' ] ) ) ); ?>
					</section><!-- .comment-content -->

				</article><!-- #comment-## -->
				<?php
				break;
		endswitch; // end comment_type check
	}
endif;

/**************************************************************************************/

/* Register shortcodes. */
add_action( 'init', 'spacious_add_shortcodes' );
/**
 * Creates new shortcodes for use in any shortcode-ready area.  This function uses the add_shortcode()
 * function to register new shortcodes with WordPress.
 *
 * @uses add_shortcode() to create new shortcodes.
 */
function spacious_add_shortcodes() {
	/* Add theme-specific shortcodes. */
	add_shortcode( 'the-year', 'spacious_the_year_shortcode' );
	add_shortcode( 'site-link', 'spacious_site_link_shortcode' );
	add_shortcode( 'wp-link', 'spacious_wp_link_shortcode' );
	add_shortcode( 'tg-link', 'spacious_themegrill_link_shortcode' );
}

/**
 * Shortcode to display the current year.
 *
 * @uses date() Gets the current year.
 * @return string
 */
function spacious_the_year_shortcode() {
	return date( 'Y' );
}

/**
 * Shortcode to display a link back to the site.
 *
 * @uses get_bloginfo() Gets the site link
 * @return string
 */
function spacious_site_link_shortcode() {
	return '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" ><span>' . get_bloginfo( 'name', 'display' ) . '</span></a>';
}

/**
 * Shortcode to display a link to WordPress.org.
 *
 * @return string
 */
function spacious_wp_link_shortcode() {
	return '<a href="' . esc_url( 'http://wordpress.org' ) . '" target="_blank" title="' . esc_attr__( 'WordPress', 'spacious' ) . '"><span>' . __( 'WordPress', 'spacious' ) . '</span></a>';
}

/**
 * Shortcode to display a link to spacious.com.
 *
 * @return string
 */
function spacious_themegrill_link_shortcode() {
	return '<a href="' . esc_url( 'https://themegrill.com/wordpress-themes/' ) . '" target="_blank" title="' . esc_attr__( 'ThemeGrill', 'spacious' ) . '" ><span>' . __( 'ThemeGrill', 'spacious' ) . '</span></a>';
}

if ( ! function_exists( 'spacious_footer_copyright' ) ) :

	/**
	 * Function to show the footer info, copyright information
	 */
	function spacious_footer_copyright() {

		$default_footer_value = spacious_options( 'spacious_footer_editor', __( 'Copyright &copy; ', 'spacious' ) . '[the-year] [site-link] ' . __( 'Theme by: ', 'spacious' ) . '[tg-link] ' . __( 'Powered by: ', 'spacious' ) . '[wp-link]' );

		$spacious_footer_copyright = '<div class="copyright">' . $default_footer_value . '</div>';

		echo do_shortcode( $spacious_footer_copyright );
	}

endif;

add_action( 'spacious_footer_copyright', 'spacious_footer_copyright', 10 );

/**************************************************************************************/

/**
 * Making the theme Woocommrece compatible
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

add_filter( 'woocommerce_show_page_title', '__return_false' );

add_action( 'woocommerce_before_main_content', 'spacious_wrapper_start', 10 );
add_action( 'woocommerce_after_main_content', 'spacious_wrapper_end', 10 );

function spacious_wrapper_start() {
	echo '<div id="primary">';
}

function spacious_wrapper_end() {
	echo '</div>';
}

function spacious_woocommerce_support() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}

add_action( 'after_setup_theme', 'spacious_woocommerce_support' );

if ( ! function_exists( 'spacious_woo_related_products_limit' ) ) {

	/**
	 * WooCommerce Extra Feature
	 * --------------------------
	 *
	 * Change number of related products on product page
	 * Set your own value for 'posts_per_page'
	 *
	 */
	function spacious_woo_related_products_limit() {
		global $product;
		$args = array(
			'posts_per_page' => 4,
			'columns'        => 4,
			'orderby'        => 'rand',
		);

		return $args;
	}
}
add_filter( 'woocommerce_output_related_products_args', 'spacious_woo_related_products_limit' );

if ( class_exists( 'woocommerce' ) && ! function_exists( 'spacious_is_in_woocommerce_page' ) ):
	/*
	 * woocommerce - conditional to check if woocommerce related page showed
	 */
	function spacious_is_in_woocommerce_page() {
		return ( is_shop() || is_product_category() || is_product_tag() || is_product() || is_cart() || is_checkout() || is_account_page() ) ? true : false;
	}
endif;

/****************************************************************************************/

if ( ! function_exists( 'spacious_entry_meta' ) ) :
	/**
	 * Shows meta information of post.
	 */
	function spacious_entry_meta( $spacious_show_readmore = true ) {
		if ( 'post' == get_post_type() ) :
			echo '<footer class="entry-meta-bar clearfix">';
			echo '<div class="entry-meta clearfix">';
			?>

			<span class="by-author author vcard"><a class="url fn n" href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>"><?php the_author(); ?></a></span>

			<?php
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
			}
			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);
			printf( __( '<span class="date"><a href="%1$s" title="%2$s" rel="bookmark">%3$s</a></span>', 'spacious' ),
				esc_url( get_permalink() ),
				esc_attr( get_the_time() ),
				$time_string
			); ?>

			<?php if ( spacious_options( 'spacious_post_meta_category', 0 ) == 0 ) { ?>
			<?php if ( has_category() ) { ?>
				<span class="category"><?php the_category( ', ' ); ?></span>
			<?php } ?>
		<?php } ?>

			<?php if ( spacious_options( 'spacious_post_meta_comments', 0 ) == 0 ) { ?>
			<?php if ( comments_open() ) { ?>
				<span class="comments"><?php comments_popup_link( __( 'No Comments', 'spacious' ), __( '1 Comment', 'spacious' ), __( '% Comments', 'spacious' ), '', __( 'Comments Off', 'spacious' ) ); ?></span>
			<?php } ?>
		<?php } ?>

			<?php if ( spacious_options( 'spacious_post_meta_edit_button', 0 ) == 0 ) { ?>
			<?php edit_post_link( __( 'Edit', 'spacious' ), '<span class="edit-link">', '</span>' ); ?>
		<?php } ?>

			<?php if ( $spacious_show_readmore ) { ?>
			<span class="read-more-link"><a class="read-more" href="<?php the_permalink(); ?>"><?php echo spacious_options( 'spacious_read_more_text', __( 'Read more', 'spacious' ) ); ?></a></span>
		<?php } ?>

			<?php
			echo '</div>';
			echo '</footer>';
		endif;
	}
endif;

/**
 * function to add the social links in the Author Bio section
 */
if ( ! function_exists( 'spacious_author_bio_links' ) ) :

	function spacious_author_bio_links() {
		$author_name = get_the_author_meta( 'display_name' );

		// pulling the author social links url which are provided through WordPress SEO and All In One SEO Pack plugin
		$author_facebook_link   = get_the_author_meta( 'facebook' );
		$author_twitter_link    = get_the_author_meta( 'twitter' );
		$author_googleplus_link = get_the_author_meta( 'googleplus' );

		if ( $author_twitter_link || $author_googleplus_link || $author_facebook_link ) {
			echo '<div class="author-social-links">';
			printf( __( '<span>Follow %s on:</span>', 'spacious' ), $author_name );
			if ( $author_facebook_link ) {
				echo '<a href="' . esc_url( $author_facebook_link ) . '" title="' . esc_html__( 'Facebook', 'spacious' ) . '" target="_blank"><i class="fa fa-facebook"></i><span class="screen-reader-text">' . esc_html__( 'Facebook', 'spacious' ) . '</span></a>';
			}
			if ( $author_twitter_link ) {
				echo '<a href="https://twitter.com/' . esc_attr( $author_twitter_link ) . '" title="' . esc_html__( 'Twitter', 'spacious' ) . '" target="_blank"><i class="fa fa-twitter"></i><span class="screen-reader-text">' . esc_html__( 'Twitter', 'spacious' ) . '</span></a>';
			}
			if ( $author_googleplus_link ) {
				echo '<a href="' . esc_url( $author_googleplus_link ) . '" title="' . esc_html__( 'Google Plus', 'spacious' ) . '" rel="author" target="_blank"><i class="fa fa-google-plus"></i><span class="screen-reader-text">' . esc_html__( 'Google Plus', 'spacious' ) . '</span></a>';
			}
			echo '</div>';
		}
	}

endif;

/**
 * Function to transfer the favicon added in Customizer Options of theme to Site Icon in Site Identity section
 */
function spacious_site_icon_migrate() {
	if ( get_option( 'spacious_site_icon_transfer' ) ) {
		return;
	}

	$spacious_favicon = spacious_options( 'spacious_favicon', 0 );

	// Migrate spacious site icon.
	if ( function_exists( 'has_site_icon' ) && ( ! empty( $spacious_favicon ) && ! has_site_icon() ) ) {
		$theme_options = get_option( 'spacious' );
		$attachment_id = attachment_url_to_postid( $spacious_favicon );

		// Update site icon transfer options.
		if ( $theme_options && $attachment_id ) {
			update_option( 'site_icon', $attachment_id );
			update_option( 'spacious_site_icon_transfer', 1 );

			// Remove old favicon options.
			foreach ( $theme_options as $option_key => $option_value ) {
				if ( in_array( $option_key, array( 'spacious_favicon', 'spacious_activate_favicon' ) ) ) {
					unset( $theme_options[ $option_key ] );
				}
			}
		}

		// Finally, update spacious theme options.
		update_option( 'spacious', $theme_options );
	}
}

add_action( 'after_setup_theme', 'spacious_site_icon_migrate' );

/**
 * Migrate any existing theme CSS codes added in Customize Options to the core option added in WordPress 4.7
 */
function spacious_custom_css_migrate() {
	if ( function_exists( 'wp_update_custom_css_post' ) ) {
		$custom_css = spacious_options( 'spacious_custom_css' );
		if ( $custom_css ) {
			$core_css = wp_get_custom_css(); // Preserve any CSS already added to the core option.
			$return   = wp_update_custom_css_post( $core_css . $custom_css );

			if ( ! is_wp_error( $return ) ) {
				$theme_options = get_option( 'spacious' );
				// Remove the old theme_mod, so that the CSS is stored in only one place moving forward.
				if ( isset( $theme_options[ 'spacious_custom_css' ] ) ) {
					unset( $theme_options[ 'spacious_custom_css' ] );
				}

				// Finally, update spacious theme options.
				update_option( 'spacious', $theme_options );
			}
		}
	}
}

add_action( 'after_setup_theme', 'spacious_custom_css_migrate' );

/**
 * Migrate any existing theme CSS codes added in Additional CSS from free to pro version
 */
function spacious_custom_css_free_pro_migrate() {
	if ( function_exists( 'wp_update_custom_css_post' ) ) {
		if ( get_option( 'spacious_custom_css_transfer' ) ) {
			return;
		}

		$theme_options = get_option( 'theme_mods_spacious' );
		if ( $theme_options ) {
			$core_css        = wp_get_custom_css(); // Preserve any CSS already added to the core option.
			$free_custom_css = wp_get_custom_css( 'spacious' );
			$return          = wp_update_custom_css_post( $core_css . $free_custom_css );

			if ( ! is_wp_error( $return ) ) {
				// Set the transfer as true
				update_option( 'spacious_custom_css_transfer', 1 );
			}
		}
	}
}

add_action( 'after_switch_theme', 'spacious_custom_css_free_pro_migrate' );

// Displays the site logo
if ( ! function_exists( 'spacious_the_custom_logo' ) ) {
	/**
	 * Displays the optional custom logo.
	 */
	function spacious_the_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) && ( spacious_options( 'spacious_header_logo_image', '' ) == '' ) ) {
			the_custom_logo();
		}
	}
}

/**
 * Function to transfer the Header Logo added in Customizer Options of theme to Site Logo in Site Identity section
 */
function spacious_site_logo_migrate() {
	if ( function_exists( 'the_custom_logo' ) && ! has_custom_logo( $blog_id = 0 ) ) {
		$logo_url = spacious_options( 'spacious_header_logo_image' );

		if ( $logo_url ) {
			$customizer_site_logo_id = attachment_url_to_postid( $logo_url );
			set_theme_mod( 'custom_logo', $customizer_site_logo_id );

			// Delete the old Site Logo theme_mod option.
			$theme_options = get_option( 'spacious' );

			if ( isset( $theme_options[ 'spacious_header_logo_image' ] ) ) {
				unset( $theme_options[ 'spacious_header_logo_image' ] );
			}

			// Finally, update spacious theme options.
			update_option( 'spacious', $theme_options );
		}
	}
}

add_action( 'after_setup_theme', 'spacious_site_logo_migrate' );

/**
 * List of allowed social protocols in HTML attributes.
 *
 * @param  array $protocols Array of allowed protocols.
 *
 * @return array
 */
function spacious_allowed_social_protocols( $protocols ) {
	$social_protocols = array(
		'skype',
	);

	return array_merge( $protocols, $social_protocols );
}

add_filter( 'kses_allowed_protocols', 'spacious_allowed_social_protocols' );
