<?php
/**
 * Contains all the functions related to sidebar and widget.
 *
 * @package    ThemeGrill
 * @subpackage Spacious
 * @since      Spacious 1.0
 */

add_action( 'widgets_init', 'spacious_widgets_init' );
/**
 * Function to register the widget areas(sidebar) and widgets.
 */
function spacious_widgets_init() {

	// Registering main right sidebar
	register_sidebar( array(
		'name'          => __( 'Right Sidebar', 'spacious' ),
		'id'            => 'spacious_right_sidebar',
		'description'   => __( 'Shows widgets at Right side.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	// Registering main left sidebar
	register_sidebar( array(
		'name'          => __( 'Left Sidebar', 'spacious' ),
		'id'            => 'spacious_left_sidebar',
		'description'   => __( 'Shows widgets at Left side.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	// Registering Header sidebar
	register_sidebar( array(
		'name'          => __( 'Header Sidebar', 'spacious' ),
		'id'            => 'spacious_header_sidebar',
		'description'   => __( 'Shows widgets in header section just above the main navigation menu.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// Registering Business Page template top section sidebar
	register_sidebar( array(
		'name'          => __( 'Business Top Sidebar', 'spacious' ),
		'id'            => 'spacious_business_page_top_section_sidebar',
		'description'   => __( 'Shows widgets on Business Page Template Top Section.', 'spacious' ) . ' ' . __( 'Suitable widget: TG: Services, TG: Call To Action Widget, TG: Featured Posts, TG: Featured Widget, TG: Our Clients', 'spacious' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s clearfix">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// Registering Business Page template middle section left half sidebar
	register_sidebar( array(
		'name'          => __( 'Business Middle Left Sidebar', 'spacious' ),
		'id'            => 'spacious_business_page_middle_section_left_half_sidebar',
		'description'   => __( 'Shows widgets on Business Page Template Middle Section Left Half.', 'spacious' ) . ' ' . __( 'Suitable widget: TG: Testimonial, TG: Featured Single Page', 'spacious' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s clearfix">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// Registering Business Page template middle section right half sidebar
	register_sidebar( array(
		'name'          => __( 'Business Middle Right Sidebar', 'spacious' ),
		'id'            => 'spacious_business_page_middle_section_right_half_sidebar',
		'description'   => __( 'Shows widgets on Business Page Template Middle Section Right Half.', 'spacious' ) . ' ' . __( 'Suitable widget: TG: Testimonial, TG: Featured Single Page', 'spacious' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s clearfix">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );


	// Registering Business Page template bottom section sidebar
	register_sidebar( array(
		'name'          => __( 'Business Bottom Sidebar', 'spacious' ),
		'id'            => 'spacious_business_page_bottom_section_sidebar',
		'description'   => __( 'Shows widgets on Business Page Template Bottom Section.', 'spacious' ) . ' ' . __( 'Suitable widget: TG: Services, TG: Call To Action Widget, TG: Featured Posts, TG: Featured Widget, TG: Our Clients', 'spacious' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s clearfix">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	// Registering contact Page sidebar
	register_sidebar( array(
		'name'          => __( 'Contact Page Sidebar', 'spacious' ),
		'id'            => 'spacious_contact_page_sidebar',
		'description'   => __( 'Shows widgets on Contact Page Template.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	// Registering woocommerce sidebar
	if ( class_exists( 'woocommerce' ) ) {
		register_sidebar( array(
			'name'          => __( 'Shop Sidebar', 'spacious' ),
			'id'            => 'spacious_woocommerce_sidebar',
			'description'   => __( 'Widget area for WooCommerce Pages.', 'spacious' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		) );
	}

	// Registering Error 404 Page sidebar
	register_sidebar( array(
		'name'          => __( 'Error 404 Page Sidebar', 'spacious' ),
		'id'            => 'spacious_error_404_page_sidebar',
		'description'   => __( 'Shows widgets on Error 404 page.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	// Registering footer sidebar one
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar One', 'spacious' ),
		'id'            => 'spacious_footer_sidebar_one',
		'description'   => __( 'Shows widgets at footer sidebar one.', 'spacious' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	// custom footer sidebar column select
	$sidebar_num = '';
	$sidebar_num = spacious_options( 'spacious_footer_widget_column_select_type', 'four' );
	if ( $sidebar_num == 'four' || $sidebar_num == 'three' || $sidebar_num == 'two' ) {
		// Registering footer sidebar two
		register_sidebar( array(
			'name'          => __( 'Footer Sidebar Two', 'spacious' ),
			'id'            => 'spacious_footer_sidebar_two',
			'description'   => __( 'Shows widgets at footer sidebar two.', 'spacious' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		) );
	}

	if ( $sidebar_num == 'four' || $sidebar_num == 'three' ) {
		// Registering footer sidebar three
		register_sidebar( array(
			'name'          => __( 'Footer Sidebar Three', 'spacious' ),
			'id'            => 'spacious_footer_sidebar_three',
			'description'   => __( 'Shows widgets at footer sidebar three.', 'spacious' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		) );
	}

	if ( $sidebar_num == 'four' ) {
		// Registering footer sidebar four
		register_sidebar( array(
			'name'          => __( 'Footer Sidebar Four', 'spacious' ),
			'id'            => 'spacious_footer_sidebar_four',
			'description'   => __( 'Shows widgets at footer sidebar four.', 'spacious' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		) );
	}

	// Registering widgets
	register_widget( "spacious_featured_single_page_widget" );
	register_widget( "spacious_service_widget" );
	register_widget( "spacious_call_to_action_widget" );
	register_widget( "spacious_testimonial_widget" );
	register_widget( "spacious_recent_work_widget" );
	register_widget( "spacious_featured_posts_widget" );
	register_widget( "spacious_our_clients_widget" );
	register_widget( "spacious_team_widget" );
	register_widget( "spacious_fun_facts_widget" );
	register_widget( "spacious_pricing_table_widget" );
	register_widget( "spacious_accordian_widget" );
}

/****************************************************************************************/

/**
 * Featured Single page widget.
 *
 */
class spacious_featured_single_page_widget extends WP_Widget {
	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_featured_single_post',
			'description'                 => __( 'Display Featured Single Page', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Featured Single Page', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$instance                = wp_parse_args( (array) $instance, array( 'page_id' => '', 'title' => '', 'disable_feature_image' => 0, 'image_position' => 'above', 'disable_three_dots' => 0, 'read_more_button_enable' => 0, 'enable_permalink_image' => 0 ) );
		$title                   = esc_attr( $instance[ 'title' ] );
		$page_id                 = absint( $instance[ 'page_id' ] );
		$enable_permalink_image  = $instance[ 'enable_permalink_image' ] ? 'checked="checked"' : '';
		$disable_feature_image   = $instance[ 'disable_feature_image' ] ? 'checked="checked"' : '';
		$image_position          = $instance[ 'image_position' ];
		$disable_three_dots      = $instance[ 'disable_three_dots' ] ? 'checked="checked"' : '';
		$read_more_button_enable = $instance[ 'read_more_button_enable' ] ? 'checked="checked"' : '';
		_e( 'Suitable for Home Top Sidebar, Home Bottom Left Sidebar and Side Sidbar.', 'spacious' );
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
		</p>
		<p><?php _e( 'Displays the title of the Page if title input is empty.', 'spacious' ); ?></p>

		<p>
			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>"><?php _e( 'Page', 'spacious' ); ?>:</label>
			<?php wp_dropdown_pages( array( 'name' => $this->get_field_name( 'page_id' ), 'selected' => $instance[ 'page_id' ] ) ); ?>
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $disable_feature_image; ?> id="<?php echo $this->get_field_id( 'disable_feature_image' ); ?>" name="<?php echo $this->get_field_name( 'disable_feature_image' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'disable_feature_image' ); ?>"><?php _e( 'Remove Featured image', 'spacious' ); ?></label>
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $enable_permalink_image; ?> id="<?php echo $this->get_field_id( 'enable_permalink_image' ); ?>" name="<?php echo $this->get_field_name( 'enable_permalink_image' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'enable_permalink_image' ); ?>"><?php _e( 'Link the featured image to the respective page.', 'spacious' ); ?></label>
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $disable_three_dots; ?> id="<?php echo $this->get_field_id( 'disable_three_dots' ); ?>" name="<?php echo $this->get_field_name( 'disable_three_dots' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'disable_three_dots' ); ?>"><?php _e( 'Remove the dots at the end of content', 'spacious' ); ?></label>
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $read_more_button_enable; ?> id="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>" name="<?php echo $this->get_field_name( 'read_more_button_enable' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>"><?php _e( 'Disable the read more button.', 'spacious' ); ?></label>
		</p>

		<?php if ( $image_position == 'above' ) { ?>
			<p>
				<input type="radio" id="<?php echo $this->get_field_id( 'image_position' ); ?>" name="<?php echo $this->get_field_name( 'image_position' ); ?>" value="above" style="" checked/><?php _e( 'Show Image Before Title', 'spacious' ); ?>
				<br/>
				<input type="radio" id="<?php echo $this->get_field_id( 'image_position' ); ?>" name="<?php echo $this->get_field_name( 'image_position' ); ?>" value="below" style=""/><?php _e( 'Show Image After Title', 'spacious' ); ?>
				<br/>
			</p>
		<?php } else { ?>
			<p>
				<input type="radio" id="<?php echo $this->get_field_id( 'image_position' ); ?>" name="<?php echo $this->get_field_name( 'image_position' ); ?>" value="above" style=""/><?php _e( 'Show Image Before Title', 'spacious' ); ?>
				<br/>
				<input type="radio" id="<?php echo $this->get_field_id( 'image_position' ); ?>" name="<?php echo $this->get_field_name( 'image_position' ); ?>" value="below" style="" checked/><?php _e( 'Show Image After Title', 'spacious' ); ?>
				<br/>
			</p>
		<?php } ?>

		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance                              = $old_instance;
		$instance[ 'title' ]                   = strip_tags( $new_instance[ 'title' ] );
		$instance[ 'page_id' ]                 = absint( $new_instance[ 'page_id' ] );
		$instance[ 'disable_feature_image' ]   = isset( $new_instance[ 'disable_feature_image' ] ) ? 1 : 0;
		$instance[ 'enable_permalink_image' ]  = isset( $new_instance[ 'enable_permalink_image' ] ) ? 1 : 0;
		$instance[ 'image_position' ]          = $new_instance[ 'image_position' ];
		$instance[ 'disable_three_dots' ]      = isset( $new_instance[ 'disable_three_dots' ] ) ? 1 : 0;
		$instance[ 'read_more_button_enable' ] = isset( $new_instance[ 'read_more_button_enable' ] ) ? 1 : 0;

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );
		global $post;
		$title                   = apply_filters( 'widget_title', isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '' );
		$page_id                 = isset( $instance[ 'page_id' ] ) ? $instance[ 'page_id' ] : '';
		$disable_feature_image   = ! empty( $instance[ 'disable_feature_image' ] ) ? 'true' : 'false';
		$enable_permalink_image  = ! empty( $instance[ 'enable_permalink_image' ] ) ? 'true' : 'false';
		$disable_three_dots      = ! empty( $instance[ 'disable_three_dots' ] ) ? 'true' : 'false';
		$read_more_button_enable = ! empty( $instance[ 'read_more_button_enable' ] ) ? 'true' : 'false';
		$image_position          = isset( $instance[ 'image_position' ] ) ? $instance[ 'image_position' ] : 'above';

		if ( $page_id ) {
			$the_query = new WP_Query( 'page_id=' . $page_id );
			while ( $the_query->have_posts() ):$the_query->the_post();
				$page_name = get_the_title();

				$output = $before_widget;
				if ( $image_position == "below" ) {
					if ( $title ): $output .= $before_title . '<a href="' . get_permalink() . '" title="' . $title . '">' . $title . '</a>' . $after_title;
					else: $output .= $before_title . '<a href="' . get_permalink() . '" title="' . $page_name . '">' . $page_name . '</a>' . $after_title;
					endif;
				}
				if ( has_post_thumbnail() && $disable_feature_image != "true" ) {
					if ( $enable_permalink_image == "false" ) {
						$output .= '<div class="service-image">' . get_the_post_thumbnail( $post->ID, 'featured', array( 'title' => esc_attr( $page_name ), 'alt' => esc_attr( $page_name ) ) ) . '</div>';
					} else {
						$output .= '<div class="service-image">' . '<a href="' . get_the_permalink() . '" title="' . get_the_title() . '">' . get_the_post_thumbnail( $post->ID, 'featured', array( 'title' => esc_attr( $page_name ), 'alt' => esc_attr( $page_name ) ) ) . '</a></div>';
					}
				}

				if ( $image_position == "above" ) {
					if ( $title ): $output .= $before_title . '<a href="' . get_permalink() . '" title="' . $title . '">' . $title . '</a>' . $after_title;
					else: $output .= $before_title . '<a href="' . get_permalink() . '" title="' . $page_name . '">' . $page_name . '</a>' . $after_title;
					endif;
				}
				$three_dots = '...';
				if ( $disable_three_dots == "true" ) {
					$three_dots = '';
				}
				$output .= '<p>' . get_the_excerpt() . $three_dots . '</p>';
				if ( $read_more_button_enable == "false" ) {
					$output .= '<a class="read-more" href="' . get_permalink() . '">' . spacious_options( 'spacious_read_more_text', __( 'Read more', 'spacious' ) ) . '</a>';
				}
				$output .= $after_widget;
			endwhile;
			// Reset Post Data
			wp_reset_postdata();
			echo $output;
		}

	}
}

/****************************************************************************************/

/**
 * Featured service widget to show pages.
 */
class spacious_service_widget extends WP_Widget {
	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_service_block',
			'description'                 => __( 'Display some pages as services. Best for Business Top or Bottom sidebar.', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Services', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		for ( $i = 0; $i < 8; $i ++ ) {
			$var              = 'page_id' . $i;
			$defaults[ $var ] = '';
		}
		$defaults[ 'image_link' ]              = '0';
		$defaults[ 'read_more_button_enable' ] = '0';
		$defaults[ 'select_column' ]           = 'services-column-layout-3';
		$defaults[ 'open_in_new_tab' ]         = '0';
		$instance                              = wp_parse_args( (array) $instance, $defaults );
		for ( $i = 0; $i < 8; $i ++ ) {
			$var = 'page_id' . $i;
			$var = absint( $instance[ $var ] );
		}
		$image_link              = $instance[ 'image_link' ] ? 'checked="checked"' : '';
		$read_more_button_enable = $instance[ 'read_more_button_enable' ] ? 'checked="checked"' : '';
		$open_in_new_tab         = $instance[ 'open_in_new_tab' ] ? 'checked="checked"' : '';
		$select_column           = $instance[ 'select_column' ];

		?>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $image_link; ?> id="<?php echo $this->get_field_id( 'image_link' ); ?>" name="<?php echo $this->get_field_name( 'image_link' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'image_link' ); ?>"><?php _e( 'Link featured image to their respective page', 'spacious' ); ?></label>
		</p>
		<?php for ( $i = 0; $i < 8; $i ++ ) { ?>
			<p>
				<label for="<?php echo $this->get_field_id( key( $defaults ) ); ?>"><?php _e( 'Page', 'spacious' ); ?>
					:</label>
				<?php wp_dropdown_pages( array( 'show_option_none' => ' ', 'name' => $this->get_field_name( key( $defaults ) ), 'selected' => $instance[ key( $defaults ) ] ) ); ?>
			</p>
			<?php
			next( $defaults );// forwards the key of $defaults array
		} ?>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $read_more_button_enable; ?> id="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>" name="<?php echo $this->get_field_name( 'read_more_button_enable' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>"><?php _e( 'Disable the read more button.', 'spacious' ); ?></label>
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php echo $open_in_new_tab; ?> id="<?php echo $this->get_field_id( 'open_in_new_tab' ); ?>" name="<?php echo $this->get_field_name( 'open_in_new_tab' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'open_in_new_tab' ); ?>"><?php _e( 'Check to open in new tab.', 'spacious' ); ?></label>
		</p>
		<?php _e( 'Select the services column', 'spacious' ); ?>
		<p>
			<select id="<?php echo $this->get_field_id( 'select_column' ); ?>" name="<?php echo $this->get_field_name( 'select_column' ); ?>">
				<option value="services-column-layout-2" <?php if ( $select_column == 'services-column-layout-2' ) {
					echo 'selected="selected"';
				} ?> ><?php _e( 'Two Column', 'spacious' ); ?></option>
				<option value="services-column-layout-3" <?php if ( $select_column == 'services-column-layout-3' ) {
					echo 'selected="selected"';
				} ?> ><?php _e( 'Three Column', 'spacious' ); ?></option>
				<option value="services-column-layout-4" <?php if ( $select_column == 'services-column-layout-4' ) {
					echo 'selected="selected"';
				} ?> ><?php _e( 'Four Column', 'spacious' ); ?></option>
			</select>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		for ( $i = 0; $i < 8; $i ++ ) {
			$var              = 'page_id' . $i;
			$instance[ $var ] = absint( $new_instance[ $var ] );
		}

		$instance[ 'image_link' ]              = isset( $new_instance[ 'image_link' ] ) ? 1 : 0;
		$instance[ 'read_more_button_enable' ] = isset( $new_instance[ 'read_more_button_enable' ] ) ? 1 : 0;
		$instance[ 'select_column' ]           = $new_instance[ 'select_column' ];
		$instance[ 'open_in_new_tab' ]         = isset( $new_instance[ 'open_in_new_tab' ] ) ? 1 : 0;

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		global $post;
		$image_link              = ! empty( $instance[ 'image_link' ] ) ? 'true' : 'false';
		$read_more_button_enable = ! empty( $instance[ 'read_more_button_enable' ] ) ? 'true' : 'false';
		$open_in_new_tab         = ! empty( $instance[ 'open_in_new_tab' ] ) ? 'true' : 'false';
		$select_column           = isset( $instance[ 'select_column' ] ) ? $instance[ 'select_column' ] : 'services-column-layout-3';
		$page_array              = array();
		for ( $i = 0; $i < 8; $i ++ ) {
			$var     = 'page_id' . $i;
			$page_id = isset( $instance[ $var ] ) ? $instance[ $var ] : '';

			if ( ! empty( $page_id ) ) {
				array_push( $page_array, $page_id );
			}// Push the page id in the array
		}
		if ( ! empty( $page_array ) ) {
			$get_featured_pages = new WP_Query( array(
				'posts_per_page' => - 1,
				'post_type'      => array( 'page' ),
				'post__in'       => $page_array,
				'orderby'        => 'post__in',
			) );
			echo $before_widget; ?>
			<?php
			$j = 1;
			while ( $get_featured_pages->have_posts() ):$get_featured_pages->the_post();
				$page_title    = get_the_title();
				$service_class = '';
				if ( $select_column == 'services-column-layout-2' ) :
					if ( $j % 2 == 0 ) {
						$service_class = 'tg-one-half tg-one-half-last';
					} else {
						$service_class = 'tg-one-half tg-after-three-blocks-clearfix';
					}
				elseif ( $select_column == 'services-column-layout-3' ) :
					if ( $j % 2 == 1 && $j > 1 ) {
						$service_class = "tg-one-third";
					} else if ( $j % 3 == 1 && $j > 1 ) {
						$service_class = "tg-one-third tg-after-three-blocks-clearfix";
					} else {
						$service_class = "tg-one-third";
					}
				elseif ( $select_column == 'services-column-layout-4' ) :
					if ( $j % 4 == 1 ) {
						$service_class = "tg-one-fourth tg-column-1";
					} else if ( $j % 5 == 1 || $j == 2 ) {
						$service_class = 'tg-one-fourth tg-column-2';
					} else if ( $j % 6 == 1 || $j == 3 ) {
						$service_class = 'tg-one-fourth tg-after-two-blocks-clearfix tg-column-3';
					} else if ( $j % 7 == 1 || $j == 4 ) {
						$service_class = 'tg-one-fourth tg-one-fourth-last tg-column-4';
					}
				endif;

				?>
				<div class="<?php echo $service_class; ?>">
					<?php
					$new_tab = '';
					if ( $open_in_new_tab == 'true' ) {
						$new_tab = 'target="_blank"';
					}
					?>
					<?php
					if ( has_post_thumbnail() ) {
						if ( $image_link == 'true' ) {
							echo '<div class="service-image"><a title="' . get_the_title() . '" href="' . get_permalink() . '"' . esc_attr( $new_tab ) . '>' . get_the_post_thumbnail( $post->ID, 'featured' ) . '</a></div>';
						} else {
							echo '<div class="service-image">' . get_the_post_thumbnail( $post->ID, 'featured' ) . '</div>';
						}
					}
					?>
					<?php echo $before_title; ?>
					<a title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>" <?php echo esc_attr( $new_tab ); ?>><?php echo $page_title; ?></a><?php echo $after_title; ?>
					<?php the_excerpt(); ?>
					<?php if ( $read_more_button_enable == "false" ) { ?>
						<div class="more-link-wrap">
							<a class="more-link" title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>" <?php echo esc_attr( $new_tab ); ?>><?php echo spacious_options( 'spacious_read_more_text', __( 'Read more', 'spacious' ) ); ?></a>
						</div>
					<?php } ?>
				</div>
				<?php $j ++; ?>
			<?php endwhile;
			// Reset Post Data
			wp_reset_postdata();
			?>
			<?php
			echo $after_widget;
		}
	}
}

/**************************************************************************************/

/**
 * Featured call to action widget.
 */
class spacious_call_to_action_widget extends WP_Widget {
	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_call_to_action',
			'description'                 => __( 'Use this widget to show the call to action section.', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Call To Action Widget', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$spacious_defaults[ 'text_main' ]       = '';
		$spacious_defaults[ 'text_additional' ] = '';
		$spacious_defaults[ 'button_text' ]     = '';
		$spacious_defaults[ 'button_url' ]      = '';
		$spacious_defaults[ 'new_tab' ]         = '0';
		$spacious_defaults[ 'layout' ]          = 1;
		$spacious_defaults[ 'image' ]           = '';

		$instance = wp_parse_args( (array) $instance, $spacious_defaults );

		$text_main       = $instance[ 'text_main' ];
		$text_additional = $instance[ 'text_additional' ];
		$button_text     = $instance[ 'button_text' ];
		$button_url      = $instance[ 'button_url' ];
		$new_tab         = $instance[ 'new_tab' ] ? 'checked="checked"' : '';
		$layout          = absint( $instance[ 'layout' ] );
		$image           = ! empty( $instance[ 'image' ] ) ? $instance[ 'image' ] : '';
		?>


		<!-- Main Text -->
		<p>
			<?php esc_html_e( 'Call to Action Main Text', 'spacious' ); ?>
			<textarea class="widefat" rows="3" cols="20" id="<?php echo $this->get_field_id( 'text_main' ); ?>" name="<?php echo $this->get_field_name( 'text_main' ); ?>"><?php echo esc_textarea( $text_main ); ?></textarea>
		</p>
		<!-- Additional Text -->
		<p>
			<?php esc_html_e( 'Call to Action Additional Text', 'spacious' ); ?>
			<textarea class="widefat" rows="3" cols="20" id="<?php echo $this->get_field_id( 'text_additional' ); ?>" name="<?php echo $this->get_field_name( 'text_additional' ); ?>"><?php echo esc_textarea( $text_additional ); ?></textarea>
		</p>
		<!-- Button Text -->
		<p>
			<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php esc_html_e( 'Button Text:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>"/>
		</p>
		<!-- Button Redirect Link -->
		<p>
			<label for="<?php echo $this->get_field_id( 'button_url' ); ?>"><?php esc_html_e( 'Button Redirect Link:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'button_url' ); ?>" name="<?php echo $this->get_field_name( 'button_url' ); ?>" type="text" value="<?php echo esc_url( $button_url ); ?>"/>
		</p>
		<!-- Open in new tab -->
		<p>
			<input class="checkbox" type="checkbox" <?php echo esc_attr( $new_tab ); ?> id="<?php echo $this->get_field_id( 'new_tab' ); ?>" name="<?php echo $this->get_field_name( 'new_tab' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'new_tab' ); ?>"><?php esc_html_e( 'Open in new tab', 'spacious' ); ?></label>
		</p>
		<!-- Background image -->
		<p>
			<label for="<?php echo $this->get_field_id( 'image' ); ?>"><?php esc_html_e( 'Image:', 'spacious' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'image' ); ?>" name="<?php echo $this->get_field_name( 'image' ); ?>" type="text" value="<?php echo esc_url( $image ); ?>"/>
			<button class="upload_image_button button button-primary"><?php esc_html_e( 'Upload Image', 'spacious' ) ?></button>
		</p>
		<!-- Call to action styles -->
		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Choose style:', 'spacious' ); ?></label><br/>
			<input id="<?php echo $this->get_field_id( 'layout' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'layout' ); ?>" type="radio" <?php checked( $layout, 1 ) ?> value="1"/><?php esc_html_e( 'Style One', 'spacious' ); ?>
			<input id="<?php echo $this->get_field_id( 'layout' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'layout' ); ?>" type="radio" <?php checked( $layout, 2 ) ?> value="2"/><?php esc_html_e( 'Style Two', 'spacious' ); ?>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text_main' ] = $new_instance[ 'text_main' ];
		} else {
			$instance[ 'text_main' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text_main' ] ) ) );
		} // wp_filter_post_kses() expects slashed

		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text_additional' ] = $new_instance[ 'text_additional' ];
		} else {
			$instance[ 'text_additional' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text_additional' ] ) ) );
		} // wp_filter_post_kses() expects slashed

		$instance[ 'button_text' ] = strip_tags( $new_instance[ 'button_text' ] );
		$instance[ 'button_url' ]  = esc_url_raw( $new_instance[ 'button_url' ] );
		$instance[ 'new_tab' ]     = isset( $new_instance[ 'new_tab' ] ) ? 1 : 0;
		$instance[ 'layout' ]      = absint( $new_instance[ 'layout' ] );
		$instance[ 'image' ]       = ! empty( $new_instance[ 'image' ] ) ? esc_url_raw( $new_instance[ 'image' ] ) : '';

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		global $post;
		$new_tab         = ! empty( $instance[ 'new_tab' ] ) ? 'true' : 'false';
		$text_main       = empty( $instance[ 'text_main' ] ) ? '' : $instance[ 'text_main' ];
		$text_additional = empty( $instance[ 'text_additional' ] ) ? '' : $instance[ 'text_additional' ];
		$button_text     = isset( $instance[ 'button_text' ] ) ? $instance[ 'button_text' ] : '';
		$button_url      = isset( $instance[ 'button_url' ] ) ? $instance[ 'button_url' ] : '#';
		$layout          = ! empty( $instance[ 'layout' ] ) ? $instance[ 'layout' ] : 1;
		$image           = ! empty( $instance[ 'image' ] ) ? $instance[ 'image' ] : '';


		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Call to Action widget main text' . $this->id, $text_main );
			icl_register_string( 'Spacious Pro', 'TG: Call to Action widget additional text' . $this->id, $text_additional );
			icl_register_string( 'Spacious Pro', 'TG: Call to Action widget button text' . $this->id, $button_text );
			icl_register_string( 'Spacious Pro', 'TG: Call to Action widget redirect link' . $this->id, $button_url );
		}

		echo $before_widget;
		?>
		<div class="call-to-action-content-wrapper call-to-action-layout-<?php echo esc_attr( $layout ); ?> clearfix" style="<?php echo ! empty( $image ) ? 'background-image: url(' . esc_url( $image ) . ')' : ''; ?>">
			<div class="call-to-action-content">
				<?php if ( ! empty( $text_main ) ) { ?>
					<h3>
						<?php
						// For WPML plugin compatibility
						if ( function_exists( 'icl_t' ) ) {
							$text_main = icl_t( 'Spacious Pro', 'TG: Call to Action widget main text' . $this->id, $text_main );
						}

						echo esc_html( $text_main );
						?>
					</h3>
				<?php }

				if ( ! empty( $text_additional ) ) { ?>
					<p>
						<?php
						// For WPML plugin compatibility
						if ( function_exists( 'icl_t' ) ) {
							$text_additional = icl_t( 'Spacious Pro', 'TG: Call to Action widget additional text' . $this->id, $text_additional );
						}
						echo esc_html( $text_additional );
						?>
					</p>
					<?php
				}
				?>
			</div>
			<?php if ( ! empty( $button_text ) ) { ?>
				<?php
				// For WPML plugin compatibility
				if ( function_exists( 'icl_t' ) ) {
					$button_text = icl_t( 'Spacious Pro', 'TG: Call to Action widget button text' . $this->id, $button_text );
					$button_url  = icl_t( 'Spacious Pro', 'TG: Call to Action widget redirect link' . $this->id, $button_url );
				}
				?>
				<a class="call-to-action-button" <?php if ( $new_tab == 'true' ) {
					echo 'target="_blank"';
				} ?> href="<?php echo $button_url; ?>" title="<?php echo esc_attr( $button_text ); ?>"><?php echo esc_html( $button_text ); ?></a>
				<?php
			}
			?>
		</div>
		<?php
		echo $after_widget;
	}
}

/**************************************************************************************/

/**
 * Testimonial widget
 */
class spacious_testimonial_widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_testimonial',
			'description'                 => __( 'Display Testimonial', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Testimonial', 'spacious' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title  = apply_filters( 'widget_title', empty( $instance[ 'title' ] ) ? '' : $instance[ 'title' ], $instance, $this->id_base );
		$text   = apply_filters( 'widget_text', empty( $instance[ 'text' ] ) ? '' : $instance[ 'text' ], $instance );
		$name   = apply_filters( 'widget_name', empty( $instance[ 'name' ] ) ? '' : $instance[ 'name' ], $instance, $this->id_base );
		$byline = apply_filters( 'widget_byline', empty( $instance[ 'byline' ] ) ? '' : $instance[ 'byline' ], $instance, $this->id_base );

		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Testimonial widget text' . $this->id, $text );
			icl_register_string( 'Spacious Pro', 'TG: Testimonial widget name' . $this->id, $name );
			icl_register_string( 'Spacious Pro', 'TG: Testimonial widget byline' . $this->id, $byline );
		}

		echo $before_widget;
		if ( ! empty( $title ) ) {
			echo $before_title . esc_html( $title ) . $after_title;
		} ?>
		<div class="testimonial-icon"></div>
		<div class="testimonial-post"><?php
			// For WPML plugin compatibility
			if ( function_exists( 'icl_t' ) ) {
				$text = icl_t( 'Spacious Pro', 'TG: Testimonial widget text' . $this->id, $text );
			}
			echo '<p>' . esc_textarea( $text ) . '</p>'; ?></div>
		<div class="testimonial-author">
			<span><?php
				// For WPML plugin compatibility
				if ( function_exists( 'icl_t' ) ) {
					$name = icl_t( 'Spacious Pro', 'TG: Testimonial widget name' . $this->id, $name );
				}
				echo esc_html( $name ); ?></span>
			<?php
			// For WPML plugin compatibility
			if ( function_exists( 'icl_t' ) ) {
				$byline = icl_t( 'Spacious Pro', 'TG: Testimonial widget byline' . $this->id, $byline );
			}
			echo esc_html( $byline ); ?>
		</div>
		<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance             = $old_instance;
		$instance[ 'title' ]  = strip_tags( $new_instance[ 'title' ] );
		$instance[ 'name' ]   = strip_tags( $new_instance[ 'name' ] );
		$instance[ 'byline' ] = strip_tags( $new_instance[ 'byline' ] );
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		} // wp_filter_post_kses() expects slashed
		$instance[ 'filter' ] = isset( $new_instance[ 'filter' ] );

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '', 'name' => '', 'byline' => '' ) );
		$title    = strip_tags( $instance[ 'title' ] );
		$name     = strip_tags( $instance[ 'name' ] );
		$byline   = strip_tags( $instance[ 'byline' ] );
		$text     = esc_textarea( $instance[ 'text' ] );
		?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>"/>
		</p>
		<?php _e( 'Testimonial Description', 'spacious' ); ?>
		<textarea class="widefat" rows="8" cols="20" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo $text; ?></textarea>

		<p><label for="<?php echo $this->get_field_id( 'name' ); ?>"><?php _e( 'Name:', 'spacious' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'name' ); ?>" name="<?php echo $this->get_field_name( 'name' ); ?>" type="text" value="<?php echo esc_attr( $name ); ?>"/>
		</p>

		<p><label for="<?php echo $this->get_field_id( 'byline' ); ?>"><?php _e( 'Byline:', 'spacious' ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'byline' ); ?>" name="<?php echo $this->get_field_name( 'byline' ); ?>" type="text" value="<?php echo esc_attr( $byline ); ?>"/>
		</p>

		<?php
	}
}

/**************************************************************************************/

/**
 * Featured recent work widget to show pages.
 */
class spacious_recent_work_widget extends WP_Widget {
	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_recent_work',
			'description'                 => __( 'Show your some pages as recent work. Best for Business Top or Bottom sidebar.', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Featured Widget', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		for ( $i = 0; $i < 3; $i ++ ) {
			$var              = 'page_id' . $i;
			$defaults[ $var ] = '';
		}
		$att_defaults            = $defaults;
		$att_defaults[ 'title' ] = '';
		$att_defaults[ 'text' ]  = '';
		$instance                = wp_parse_args( (array) $instance, $att_defaults );
		for ( $i = 0; $i < 3; $i ++ ) {
			$var = 'page_id' . $i;
			$var = absint( $instance[ $var ] );
		}
		$title = esc_attr( $instance[ 'title' ] );
		$text  = esc_textarea( $instance[ 'text' ] );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
		</p>
		<?php _e( 'Description', 'spacious' ); ?>
		<textarea class="widefat" rows="10" cols="20" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo $text; ?></textarea>
		<?php
		for ( $i = 0; $i < 3; $i ++ ) {
			?>
			<p>
				<label for="<?php echo $this->get_field_id( key( $defaults ) ); ?>"><?php _e( 'Page', 'spacious' ); ?>
					:</label>
				<?php wp_dropdown_pages( array( 'show_option_none' => ' ', 'name' => $this->get_field_name( key( $defaults ) ), 'selected' => $instance[ key( $defaults ) ] ) ); ?>
			</p>
			<?php
			next( $defaults );// forwards the key of $defaults array
		}
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		for ( $i = 0; $i < 3; $i ++ ) {
			$var              = 'page_id' . $i;
			$instance[ $var ] = absint( $new_instance[ $var ] );
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		} // wp_filter_post_kses() expects slashed
		$instance[ 'filter' ] = isset( $new_instance[ 'filter' ] );

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		global $post;
		$title = apply_filters( 'widget_title', isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '' );
		$text  = apply_filters( 'widget_text', empty( $instance[ 'text' ] ) ? '' : $instance[ 'text' ], $instance );

		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Featured Widget text' . $this->id, $text );
		}

		$page_array = array();
		for ( $i = 0; $i < 3; $i ++ ) {
			$var     = 'page_id' . $i;
			$page_id = isset( $instance[ $var ] ) ? $instance[ $var ] : '';

			if ( ! empty( $page_id ) ) {
				array_push( $page_array, $page_id );
			}// Push the page id in the array
		}
		$get_featured_pages = new WP_Query( array(
			'posts_per_page' => - 1,
			'post_type'      => array( 'page' ),
			'post__in'       => $page_array,
			'orderby'        => 'post__in',
		) );
		echo $before_widget;
		?>
		<div class="tg-one-fourth tg-column-1">
			<?php
			if ( ! empty( $title ) ) {
				echo $before_title . esc_html( $title ) . $after_title;
			} ?>
			<p><?php
				// For WPML plugin compatibility
				if ( function_exists( 'icl_t' ) ) {
					$text = icl_t( 'Spacious Pro', 'TG: Featured Widget text' . $this->id, $text );
				}
				echo esc_textarea( $text ); ?></p>
		</div>
		<?php
		$i = 2;
		while ( $get_featured_pages->have_posts() ):$get_featured_pages->the_post();
			if ( $i % 4 == 0 ) {
				$class = 'tg-one-fourth tg-one-fourth-last' . ' tg-column-' . $i;
			} else if ( $i % 3 == 0 ) {
				$class = 'tg-one-fourth tg-after-two-blocks-clearfix' . ' tg-column-' . $i;
			} else {
				$class = 'tg-one-fourth' . ' tg-column-' . $i;
			}
			$page_title = get_the_title();
			?>
			<div class="<?php echo $class; ?>">
				<?php
				if ( has_post_thumbnail() ) {
					echo '<div class="service-image"><a title="' . get_the_title() . '"href="' . get_permalink() . '">' . get_the_post_thumbnail( $post->ID, 'featured-blog-medium' ) . '</a></div>';
				}
				?>
			</div>
			<?php
			$i ++;
		endwhile;
		// Reset Post Data
		wp_reset_query();
		?>
		<?php echo $after_widget;
	}
}

/**************************************************************************************/

/**
 * Featured Posts widget
 */
class spacious_featured_posts_widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_featured_posts',
			'description'                 => __( 'Display latest posts or posts of specific category', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Featured Posts', 'spacious' ), $widget_ops );
	}

	function form( $instance ) {
		$tg_defaults[ 'title' ]      = '';
		$tg_defaults[ 'text' ]       = '';
		$tg_defaults[ 'number' ]     = 4;
		$tg_defaults[ 'image_size' ] = 'featured-blog-medium';
		$tg_defaults[ 'type' ]       = 'latest';
		$tg_defaults[ 'category' ]   = '';
		$instance                    = wp_parse_args( (array) $instance, $tg_defaults );
		$title                       = esc_attr( $instance[ 'title' ] );
		$text                        = esc_textarea( $instance[ 'text' ] );
		$number                      = $instance[ 'number' ];
		$type                        = $instance[ 'type' ];
		$category                    = $instance[ 'category' ];
		$image_size                  = $instance[ 'image_size' ];
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
		</p>
		<?php _e( 'Description', 'spacious' ); ?>
		<textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo $text; ?></textarea>
		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to display:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3"/>
		</p>

		<p>
			<input type="radio" <?php checked( $image_size, 'featured' ) ?> id="<?php echo $this->get_field_id( 'image_size' ); ?>" name="<?php echo $this->get_field_name( 'image_size' ); ?>" value="featured"/><?php _e( 'Large Featured Image', 'spacious' ); ?>
			<br/>
			<input type="radio" <?php checked( $image_size, 'featured-blog-medium' ) ?> id="<?php echo $this->get_field_id( 'image_size' ); ?>" name="<?php echo $this->get_field_name( 'image_size' ); ?>" value="featured-blog-medium"/><?php _e( 'Medium Featured Image', 'spacious' ); ?>
			<br/></p>

		<p>
			<input type="radio" <?php checked( $type, 'latest' ) ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="latest"/><?php _e( 'Show latest Posts', 'spacious' ); ?>
			<br/>
			<input type="radio" <?php checked( $type, 'category' ) ?> id="<?php echo $this->get_field_id( 'type' ); ?>" name="<?php echo $this->get_field_name( 'type' ); ?>" value="category"/><?php _e( 'Show posts from a category', 'spacious' ); ?>
			<br/></p>

		<p>
			<label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Select category', 'spacious' ); ?>
				:</label>
			<?php wp_dropdown_categories( array( 'show_option_none' => ' ', 'name' => $this->get_field_name( 'category' ), 'selected' => $category ) ); ?>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		}
		$instance[ 'number' ]     = absint( $new_instance[ 'number' ] );
		$instance[ 'image_size' ] = $new_instance[ 'image_size' ];
		$instance[ 'type' ]       = $new_instance[ 'type' ];
		$instance[ 'category' ]   = $new_instance[ 'category' ];

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		global $post;
		$title      = apply_filters( 'widget_title', isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '' );
		$text       = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
		$number     = empty( $instance[ 'number' ] ) ? 4 : $instance[ 'number' ];
		$image_size = isset( $instance[ 'image_size' ] ) ? $instance[ 'image_size' ] : 'featured-blog-medium';
		$type       = isset( $instance[ 'type' ] ) ? $instance[ 'type' ] : 'latest';
		$category   = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';

		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Featured posts widget description text' . $this->id, $text );
		}

		if ( $type == 'latest' ) {
			$get_featured_posts = new WP_Query( array(
				'posts_per_page'      => $number,
				'post_type'           => 'post',
				'ignore_sticky_posts' => true,
			) );
		} else {
			$get_featured_posts = new WP_Query( array(
				'posts_per_page' => $number,
				'post_type'      => 'post',
				'category__in'   => $category,
			) );
		}
		echo $before_widget;
		?>
		<?php
		if ( $image_size == 'featured-blog-medium' ) {
			$featured    = 'featured-blog-medium';
			$image_class = 'post-featured-image';
		} else {
			$featured    = 'featured';
			$image_class = 'post-featured-iamge-large';
		}

		if ( ! empty( $title ) ) {
			echo $before_title . esc_html( $title ) . $after_title;
		} ?>
		<p class="widget-desc"><?php
			// For WPML plugin compatibility
			if ( function_exists( 'icl_t' ) ) {
				$text = icl_t( 'Spacious Pro', 'TG: Featured posts widget description text' . $this->id, $text );
			}
			echo esc_textarea( $text ); ?></p>
		<?php
		$i = 1;
		while ( $get_featured_posts->have_posts() ):$get_featured_posts->the_post();
			if ( $i % 2 == 0 ) {
				$class = 'tg-one-half tg-one-half-last';
			} else {
				$class = 'tg-one-half';
			}
			if ( $i % 2 == 1 && $i > 1 ) {
				$class .= ' tg-featured-posts-clearfix';
			}
			?>
			<div class="<?php echo $class; ?>">
				<header class="entry-header">
					<h2 class="entry-title">
						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
					</h2><!-- .entry-title -->
				</header>
				<?php
				if ( has_post_thumbnail() ) {
					$image           = '';
					$title_attribute = get_the_title( $post->ID );
					$image           .= '<figure class="' . $image_class . '">';
					$image           .= '<a href="' . get_permalink() . '" title="' . the_title( '', '', false ) . '">';
					$image           .= get_the_post_thumbnail( $post->ID, $featured, array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ) ) ) . '</a>';
					$image           .= '</figure>';

					echo $image;
				}
				?>

				<div class="entry-content clearfix">
					<?php
					the_excerpt();
					?>
				</div>

				<footer class="entry-meta-bar clearfix">
					<div class="entry-meta clearfix">
						<span class="by-author"><a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>"><?php the_author(); ?></a></span>
						<span class="date"><a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( get_the_time() ); ?>"><?php the_time( get_option( 'date_format' ) ); ?></a></span>
						<?php if ( spacious_options( 'spacious_post_meta_category', 0 ) == 0 ) { ?>
							<?php if ( has_category() ) { ?>
								<span class="category"><?php the_category( ', ' ); ?></span>
							<?php } ?>
						<?php } ?>
						<?php if ( spacious_options( 'spacious_post_meta_comments', 0 ) == 0 ) { ?>
							<?php if ( comments_open() ) { ?>
								<span class="comments"><?php comments_popup_link( __( 'No Comments', 'spacious' ), __( '1 Comment', 'spacious' ), __( '% Comments', 'spacious' ), '', __( 'Comments Off', 'spacious' ) ); ?></span>
							<?php } ?>
						<?php } ?>
						<?php if ( spacious_options( 'spacious_post_meta_edit_button', 0 ) == 0 ) { ?>
							<?php edit_post_link( __( 'Edit', 'spacious' ), '<span class="edit-link">', '</span>' ); ?>
						<?php } ?>
						<span class="read-more-link"><a class="read-more" href="<?php the_permalink(); ?>"><?php echo spacious_options( 'spacious_read_more_text', __( 'Read more', 'spacious' ) ); ?></a></span>
					</div>
				</footer>

			</div>
			<?php
			$i ++;
		endwhile;
		// Reset Post Data
		wp_reset_query();
		?>
		<?php echo $after_widget;
	}

}


/**
 * Clients images widget
 */
class spacious_our_clients_widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_our_clients',
			'description'                 => __( 'Widget to show clients/partners images', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Our Clients', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$instance        = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '', 'image-1' => '', 'image-2' => '', 'image-3' => '', 'image-4' => '', 'image-5' => '', 'image-6' => '', 'image-7' => '', 'image-8' => '', 'image-9' => '', 'image-10' => '', 'link-1' => '', 'link-2' => '', 'link-3' => '', 'link-4' => '', 'link-5' => '', 'link-6' => '', 'link-7' => '', 'link-8' => '', 'link-9' => '', 'link-10' => '', 'hover-text1' => '', 'hover-text2' => '', 'hover-text3' => '', 'hover-text4' => '', 'hover-text5' => '', 'hover-text6' => '', 'hover-text7' => '', 'hover-text8' => '', 'hover-text9' => '', 'hover-text10' => '', 'carousel_enable' => 0 ) );
		$title           = esc_attr( $instance[ 'title' ] );
		$text            = esc_textarea( $instance[ 'text' ] );
		$carousel_enable = $instance[ 'carousel_enable' ] ? 'checked="checked"' : '';
		for ( $i = 1; $i < 11; $i ++ ) {
			$image                   = 'image-' . $i;
			$link                    = 'link-' . $i;
			$hover_text              = 'hover-text' . $i;
			$instance[ $image ]      = esc_url( $instance[ $image ] );
			$instance[ $link ]       = esc_url( $instance[ $link ] );
			$instance[ $hover_text ] = strip_tags( $instance[ $hover_text ] );
		}
		?>
		<p><?php _e( 'Note: To add the image. Go to Media->Add New. Upload an image. Copy the image path link and paste in image input field. Recommended size for the image is 200px * 75px.', 'spacious' ); ?></p>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
		</p>
		<?php _e( 'Description', 'spacious' ); ?>
		<textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo $text; ?></textarea>

		<?php for ( $i = 1; $i < 11; $i ++ ) {
			$image      = 'image-' . $i;
			$link       = 'link-' . $i;
			$hover_text = 'hover-text' . $i;
			?>
			<p>
				<label for="<?php echo $this->get_field_id( $image ); ?>"><?php _e( 'Image Path Link ', 'spacious' );
					echo $i; ?></label>
				<input style="width:100%;" id="<?php echo $this->get_field_id( $image ); ?>" name="<?php echo $this->get_field_name( $image ); ?>" type="text" value="<?php echo $instance[ $image ]; ?>"/>
			</p>
			<p><?php _e( 'Redirect Link ', 'spacious' );
				echo $i; ?>
				<input style="width:100%;" name="<?php echo $this->get_field_name( $link ); ?>" type="text" value="<?php if ( isset ( $instance[ $link ] ) ) {
					echo esc_url( $instance[ $link ] );
				} ?>"/></p>
			<p>
				<label for="<?php echo $this->get_field_id( $hover_text ); ?>"><?php _e( 'Hover Title Text ', 'spacious' );
					echo $i; ?></label>
				<input style="width:100%;" id="<?php echo $this->get_field_id( $hover_text ); ?>" name="<?php echo $this->get_field_name( $hover_text ); ?>" type="text" value="<?php echo $instance[ $hover_text ]; ?>"/>
			</p>
			<hr/>
		<?php } ?>

		<p>
			<input class="checkbox" type="checkbox" <?php echo $carousel_enable; ?> id="<?php echo $this->get_field_id( 'carousel_enable' ); ?>" name="<?php echo $this->get_field_name( 'carousel_enable' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'carousel_enable' ); ?>"><?php esc_html_e( 'Enable carousel', 'spacious' ); ?></label>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		}

		$instance[ 'carousel_enable' ] = isset( $new_instance[ 'carousel_enable' ] ) ? 1 : 0;

		for ( $i = 1; $i < 11; $i ++ ) {
			$image                   = 'image-' . $i;
			$link                    = 'link-' . $i;
			$hover_text              = 'hover-text' . $i;
			$instance[ $image ]      = esc_url_raw( $new_instance[ $image ] );
			$instance[ $link ]       = esc_url_raw( $new_instance[ $link ] );
			$instance[ $hover_text ] = strip_tags( $new_instance[ $hover_text ] );
		}

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		$carousel_enable = ! empty( $instance[ 'carousel_enable' ] ) ? 'true' : 'false';
		if ( ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) && ( $carousel_enable == 'true' ) ) {
			wp_enqueue_script( 'jquery_cycle' );
			wp_enqueue_script( 'jquery-swipe' );
		}

		$title = apply_filters( 'widget_title', isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '' );
		$text  = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';

		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Our Clients text' . $this->id, $text );
		}

		$image_array      = array();
		$link_array       = array();
		$hover_text_array = array();

		$j = 0;
		for ( $i = 1; $i < 11; $i ++ ) {
			$image      = 'image-' . $i;
			$link       = 'link-' . $i;
			$hover_text = 'hover-text' . $i;
			$image      = isset( $instance[ $image ] ) ? $instance[ $image ] : '';
			$link       = isset( $instance[ $link ] ) ? $instance[ $link ] : '';
			$hover_text = isset( $instance[ $hover_text ] ) ? $instance[ $hover_text ] : '';

			array_push( $image_array, $image );
			array_push( $link_array, $link );
			array_push( $hover_text_array, $hover_text );
			// For WPML plugin compatibility
			if ( function_exists( 'icl_register_string' ) && ! empty( $image ) ) {
				icl_register_string( 'Spacious Pro', 'TG: Our Clients Image Path' . $this->id . $j, $image_array[ $j ] );
				if ( ! empty( $link ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Our Clients Redirect Link' . $this->id . $j, $link_array[ $j ] );
				}
				if ( ! empty( $hover_text ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Our Clients Image Hover text' . $this->id . $j, $hover_text_array[ $j ] );
				}
			}
			$j ++;
		}

		echo $before_widget;
		if ( ! empty( $title ) ) {
			echo $before_title . esc_html( $title ) . $after_title;
		} ?>
		<p class="widget-desc"><?php
			// For WPML plugin compatibility
			if ( function_exists( 'icl_t' ) ) {
				$text = icl_t( 'Spacious Pro', 'TG: Our Clients text' . $this->id, $text );
			}
			echo esc_textarea( $text ); ?></p>
		<?php
		if ( ! empty( $image_array ) ) {
			$output = '';
			if ( $carousel_enable == 'true' ) {
				$output .= '<div id="' . esc_attr( $this->id ) . '_clients-cycle-prev" class="clients-cycle-prev"></div>';
				$output .= '<div id="' . esc_attr( $this->id ) . '_clients-cycle-next" class="clients-cycle-next"></div>';
			} ?>

			<div class="our-clients-wrapper">

				<?php
				if ( $carousel_enable == 'false' ) {
					$output .= '<div class="spacious_clients_wrap">';
				} else {
					$output .= '<div class="spacious_clients_wrap slide" data-cycle-fx="carousel" data-cycle-timeout="2000" data-cycle-slides="> div" data-cycle-prev="#spacious_our_clients_widget-2_clients-cycle-prev" data-cycle-next="#spacious_our_clients_widget-2_clients-cycle-next">';
				} ?>

				<?php
				for ( $i = 1; $i < 11; $i ++ ) {
					$j = $i - 1;
					if ( ! empty( $image_array[ $j ] ) ) {
						// For WPML plugin compatibility
						if ( function_exists( 'icl_t' ) ) {
							$image_array[ $j ] = icl_t( 'Spacious Pro', 'TG: Our Clients Image Path' . $this->id . $j, $image_array[ $j ] );

							if ( ! empty( $hover_text_array[ $j ] ) ) {
								$hover_text_array[ $j ] = icl_t( 'Spacious Pro', 'TG: Our Clients Image Hover text' . $this->id . $j, $hover_text_array[ $j ] );
							}
							if ( ! empty( $link_array[ $j ] ) ) {
								$link_array[ $j ] = icl_t( 'Spacious Pro', 'TG: Our Clients Redirect Link' . $this->id . $j, $link_array[ $j ] );
							}
						}

						$output .= '<div class="spacious_single_client">';
						if ( ! empty( $link_array[ $j ] ) ) {
							$output .= '<a href="' . $link_array[ $j ] . '" title="' . $hover_text_array[ $j ] . '" target="_blank">
												<img src="' . $image_array[ $j ] . '" alt="' . $hover_text_array[ $j ] . '">
											</a>';
						} else {
							$output .= '<img src="' . $image_array[ $j ] . '" title="' . $hover_text_array[ $j ] . '" alt="' . $hover_text . '">';
						}
						$output .= '</div>';
					}
				}

				$output .= '</div>';
				echo $output;
				?>

			</div>

		<?php }

		echo $after_widget;
	}

}

/****************************************************************************************/

/**
 * Featured team widget to show pages.
 */
class spacious_team_widget extends WP_Widget {
	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_team_block',
			'description'                 => esc_html__( 'Display some pages as team. Best for Business Top or Bottom sidebar.', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = esc_html__( 'TG: Team', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$defaults                              = array();
		$defaults[ 'title' ]                   = '';
		$defaults[ 'text' ]                    = '';
		$defaults[ 'image_link' ]              = '';
		$defaults[ 'title_link' ]              = '';
		$defaults[ 'read_more_button_enable' ] = '';
		$defaults[ 'select_column' ]           = 'teams-column-layout-3';
		$defaults[ 'open_in_new_tab' ]         = '';

		for ( $i = 0; $i < 8; $i ++ ) {
			$defaults[ 'page_' . $i ]        = '';
			$defaults[ 'designation_' . $i ] = '';
			$defaults[ 'fbook_' . $i ]       = '';
			$defaults[ 'twitter_' . $i ]     = '';
			$defaults[ 'gplus_' . $i ]       = '';
		}

		$instance = wp_parse_args( (array) $instance, $defaults );

		$title                   = $instance[ 'title' ];
		$text                    = $instance[ 'text' ];
		$image_link              = $instance[ 'image_link' ] ? 'checked="checked"' : '';
		$title_link              = $instance[ 'title_link' ] ? 'checked="checked"' : '';
		$read_more_button_enable = $instance[ 'read_more_button_enable' ] ? 'checked="checked"' : '';
		$open_in_new_tab         = $instance[ 'open_in_new_tab' ] ? 'checked="checked"' : '';
		$select_column           = $instance[ 'select_column' ];
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<?php esc_html_e( 'Description', 'spacious' ); ?>
		<textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id( 'text' ); ?>" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo esc_textarea( $text ); ?></textarea>

		<?php
		for ( $i = 0; $i < 8; $i ++ ) : ?>
			<p>
				<label for="<?php echo $this->get_field_id( 'page_' . $i ); ?>"><?php esc_html_e( 'Page:', 'spacious' ); ?></label>
				<?php
				$arg = array(
					'class'            => 'widefat',
					'show_option_none' => ' ',
					'name'             => $this->get_field_name( 'page_' . $i ),
					'id'               => $this->get_field_id( 'page_' . $i ),
					'selected'         => absint( $instance[ 'page_' . $i ] ),
				);
				wp_dropdown_pages( $arg ); ?>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'designation_' . $i ); ?>"><?php esc_html_e( 'Designation:', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'designation_' . $i ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'designation_' . $i ); ?>" type="text" value="<?php if ( isset ( $instance[ 'designation_' . $i ] ) ) {
					echo esc_attr( $instance[ 'designation_' . $i ] );
				} ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'fbook_' . $i ); ?>"><?php esc_html_e( 'Facebook:', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'fbook_' . $i ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'fbook_' . $i ); ?>" type="text" value="<?php if ( isset ( $instance[ 'fbook_' . $i ] ) ) {
					echo esc_url( $instance[ 'fbook_' . $i ] );
				} ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'twitter_' . $i ); ?>"><?php esc_html_e( 'Twitter:', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'twitter_' . $i ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'twitter_' . $i ); ?>" type="text" value="<?php if ( isset ( $instance[ 'twitter_' . $i ] ) ) {
					echo esc_url( $instance[ 'twitter_' . $i ] );
				} ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'gplus_' . $i ); ?>"><?php esc_html_e( 'Google Plus:', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'gplus_' . $i ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'gplus_' . $i ); ?>" type="text" value="<?php if ( isset ( $instance[ 'gplus_' . $i ] ) ) {
					echo esc_url( $instance[ 'gplus_' . $i ] );
				} ?>"/>
			</p>

			<hr/>

		<?php endfor; ?>

		<p>
			<input class="checkbox" type="checkbox" <?php echo $image_link; ?> id="<?php echo $this->get_field_id( 'image_link' ); ?>" name="<?php echo $this->get_field_name( 'image_link' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'image_link' ); ?>"><?php esc_html_e( 'Link featured image to their respective page', 'spacious' ); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php echo $title_link; ?> id="<?php echo $this->get_field_id( 'title_link' ); ?>" name="<?php echo $this->get_field_name( 'title_link' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'title_link' ); ?>"><?php esc_html_e( 'Link title to their respective page', 'spacious' ); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php echo $read_more_button_enable; ?> id="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>" name="<?php echo $this->get_field_name( 'read_more_button_enable' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'read_more_button_enable' ); ?>"><?php esc_html_e( 'Enable the read more button.', 'spacious' ); ?></label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php echo $open_in_new_tab; ?> id="<?php echo $this->get_field_id( 'open_in_new_tab' ); ?>" name="<?php echo $this->get_field_name( 'open_in_new_tab' ); ?>"/>
			<label for="<?php echo $this->get_field_id( 'open_in_new_tab' ); ?>"><?php esc_html_e( 'Check to open in new tab.', 'spacious' ); ?></label>
		</p>

		<?php esc_html_e( 'Select the teams column', 'spacious' ); ?>

		<p>
			<select id="<?php echo $this->get_field_id( 'select_column' ); ?>" name="<?php echo $this->get_field_name( 'select_column' ); ?>">
				<option value="teams-column-layout-2" <?php if ( $select_column == 'teams-column-layout-2' ) {
					echo 'selected="selected"';
				} ?> ><?php esc_html_e( 'Two Column', 'spacious' ); ?></option>
				<option value="teams-column-layout-3" <?php if ( $select_column == 'teams-column-layout-3' ) {
					echo 'selected="selected"';
				} ?> ><?php esc_html_e( 'Three Column', 'spacious' ); ?></option>
				<option value="teams-column-layout-4" <?php if ( $select_column == 'teams-column-layout-4' ) {
					echo 'selected="selected"';
				} ?> ><?php esc_html_e( 'Four Column', 'spacious' ); ?></option>
			</select>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		}

		for ( $i = 0; $i < 8; $i ++ ) {
			$instance[ 'page_' . $i ]        = absint( $new_instance[ 'page_' . $i ] );
			$instance[ 'designation_' . $i ] = sanitize_text_field( $new_instance[ 'designation_' . $i ] );
			$instance[ 'fbook_' . $i ]       = esc_url_raw( $new_instance[ 'fbook_' . $i ] );
			$instance[ 'twitter_' . $i ]     = esc_url_raw( $new_instance[ 'twitter_' . $i ] );
			$instance[ 'gplus_' . $i ]       = esc_url_raw( $new_instance[ 'gplus_' . $i ] );
		}
		$instance[ 'image_link' ]              = isset( $new_instance[ 'image_link' ] ) ? 1 : 0;
		$instance[ 'title_link' ]              = isset( $new_instance[ 'title_link' ] ) ? 1 : 0;
		$instance[ 'read_more_button_enable' ] = isset( $new_instance[ 'read_more_button_enable' ] ) ? 1 : 0;
		$instance[ 'select_column' ]           = sanitize_key( $new_instance[ 'select_column' ] );
		$instance[ 'open_in_new_tab' ]         = isset( $new_instance[ 'open_in_new_tab' ] ) ? 1 : 0;

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		global $post;
		$title                   = apply_filters( 'widget_title', isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : '' );
		$text                    = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
		$image_link              = ! empty( $instance[ 'image_link' ] ) ? 'true' : 'false';
		$title_link              = ! empty( $instance[ 'title_link' ] ) ? 'true' : 'false';
		$read_more_button_enable = ! empty( $instance[ 'read_more_button_enable' ] ) ? 'true' : 'false';
		$open_in_new_tab         = ! empty( $instance[ 'open_in_new_tab' ] ) ? 'true' : 'false';
		$select_column           = isset( $instance[ 'select_column' ] ) ? $instance[ 'select_column' ] : 'teams-column-layout-3';
		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) && ! empty( $text ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Team widget description text' . $this->id, $text );
		}

		$page        = array();
		$designation = array();
		$fbook       = array();
		$twitter     = array();
		$gplus       = array();
		for ( $i = 0; $i < 8; $i ++ ) {
			$page[]        = isset( $instance[ 'page_' . $i ] ) ? $instance[ 'page_' . $i ] : '';
			$designation[] = isset( $instance[ 'designation_' . $i ] ) ? $instance[ 'designation_' . $i ] : '';
			$fbook[]       = isset( $instance[ 'fbook_' . $i ] ) ? $instance[ 'fbook_' . $i ] : '';
			$twitter[]     = isset( $instance[ 'twitter_' . $i ] ) ? $instance[ 'twitter_' . $i ] : '';
			$gplus[]       = isset( $instance[ 'gplus_' . $i ] ) ? $instance[ 'gplus_' . $i ] : '';

			// For WPML plugin compatibility
			if ( function_exists( 'icl_register_string' ) ) {
				if ( ! empty ( $designation ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Team widget team member designation' . $this->id . $i, $designation[ $i ] );
				}
			}
		}

		if ( ! empty( $page ) ) {
			$get_featured_pages = new WP_Query( array(
				'posts_per_page' => count( $page ),
				'post_type'      => array( 'page' ),
				'post__in'       => $page,
				'orderby'        => 'post__in',
			) );
			echo $before_widget;

			if ( ! empty( $title ) ) {
				echo $before_title . esc_html( $title ) . $after_title;
			} ?>
			<p class="widget-desc"><?php
				// For WPML plugin compatibility
				if ( function_exists( 'icl_t' ) ) {
					$text = icl_t( 'Spacious Pro', 'TG: Team widget description text' . $this->id, $text );
				}
				echo esc_textarea( $text );
				?></p>
			<div class="team-member-wrapper clearfix <?php echo esc_attr( $select_column ); ?>">
				<?php
				$key = 0;
				while ( $get_featured_pages->have_posts() ):$get_featured_pages->the_post();
					$post_count = $key + 1;
					$team_class = '';
					$col_num    = '';
					if ( $select_column == 'teams-column-layout-2' ) :
						if ( $post_count % 2 == 0 ) {
							$team_class = 'tg-one-half tg-one-half-last team-member';
						} else {
							$team_class = 'tg-one-half team-member';
						}
						$col_num = 2;
					elseif ( $select_column == 'teams-column-layout-3' ) :
						if ( $post_count % 3 == 0 ) {
							$team_class = "tg-one-third tg-one-third-last team-member";
						} else {
							$team_class = "tg-one-third team-member";
						}
						$col_num = 3;
					elseif ( $select_column == 'teams-column-layout-4' ) :
						if ( $post_count % 4 == 0 ) {
							$team_class = 'tg-one-fourth tg-one-fourth-last team-member';
						} else {
							$team_class = 'tg-one-fourth team-member';
						}
						$col_num = 4;
					endif;
					?>
					<div class="<?php echo esc_attr( $team_class ); ?>">
						<?php
						$new_tab = '';
						if ( $open_in_new_tab == "true" ) {
							$new_tab = 'target="_blank"';
						}
						?>
						<?php
						if ( has_post_thumbnail() ) {
							if ( $image_link == 'true' ) {
								echo '<div class="team-image"><a title="' . esc_attr( get_the_title() ) . '" href="' . esc_url( get_permalink() ) . '"' . esc_attr( $new_tab ) . '>' . get_the_post_thumbnail( $post->ID, 'featured-blog-medium' ) . '</a></div>';
							} else {
								echo '<div class="team-image">' . get_the_post_thumbnail( $post->ID, 'featured-blog-medium' ) . '</div>';
							}
						}
						?>
						<h3 class="team-title">
							<?php if ( $title_link == 'true' ) : ?>
								<a title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>" <?php echo esc_attr( $new_tab ); ?>><?php the_title(); ?></a>
							<?php else : ?>
								<?php the_title(); ?>
							<?php endif; ?>

						</h3><!-- .team-title -->
						<?php if ( ! empty( $designation[ $key ] ) ) :
							// For WPML plugin compatibility
							if ( function_exists( 'icl_t' ) ) {
								$designation[ $key ] = icl_t( 'Spacious Pro', 'TG: Team widget team member designation' . $this->id . $key, $designation[ $key ] );
							} ?>
							<span class="team-designation"><?php echo esc_html( $designation[ $key ] ); ?></span>
						<?php endif; ?>

						<?php if ( ! empty( $fbook ) || ! empty( $twitter ) || ! empty( $gplus ) ) : ?>
							<div class="team-social-icon">
								<ul>
									<?php if ( $fbook[ $key ] != '' ) : ?>
										<li>
											<a href="<?php echo esc_url( $fbook[ $key ] ); ?>"><i class="fa fa-facebook" aria-hidden="true"></i></a>
										</li>
									<?php endif; ?>

									<?php if ( $twitter[ $key ] != '' ) : ?>
										<li>
											<a href="<?php echo esc_url( $twitter[ $key ] ); ?>"><i class="fa fa-twitter" aria-hidden="true"></i></a>
										</li>
									<?php endif; ?>
									<?php if ( $gplus[ $key ] != '' ) : ?>
										<li>
											<a href="<?php echo esc_url( $gplus[ $key ] ); ?>"><i class="fa fa-google-plus" aria-hidden="true"></i></a>
										</li>
									<?php endif; ?>
								</ul>
							</div><!-- .team-social-icon -->
						<?php endif; ?>

						<div class="team-description">
							<?php the_excerpt(); ?>
						</div><!-- .team-description -->
						<?php if ( $read_more_button_enable == "true" ) { ?>
							<div class="more-link-wrap">
								<a class="more-link" title="<?php the_title_attribute(); ?>" href="<?php the_permalink(); ?>" <?php echo esc_attr( $new_tab ); ?>><?php echo spacious_options( 'spacious_read_more_text', esc_html__( 'Read more', 'spacious' ) ); ?></a>
							</div><!-- .more-link-wrap -->
						<?php } ?>
					</div>
					<?php if ( $post_count % $col_num == 0 ) {
						echo '<div class="clearfix"></div>';
					} ?>
					<?php $key ++; ?>
				<?php endwhile;
				// Reset Post Data
				wp_reset_postdata();
				?>
			</div>
			<?php
			echo $after_widget;
		}
	}
}

/****************************************************************************************/

/**
 * Fun Facts widget
 */
class spacious_fun_facts_widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'classname'                   => 'widget_fun_facts',
			'description'                 => __( 'Widget to show Fun Facts', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = __( 'TG: Fun Facts', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'facts_title' => '', 'facts_desc' => '', 'fact_num-1' => '', 'fact_num-2' => '', 'fact_num-3' => '', 'fact_num-4' => '', 'fact-1' => '', 'fact-2' => '', 'fact-3' => '', 'fact-4' => '', 'icon-1' => '', 'icon-2' => '', 'icon-3' => '', 'icon-4' => '' ) );

		$instance[ 'facts_title' ] = sanitize_text_field( $instance[ 'facts_title' ] );
		$instance[ 'facts_desc' ]  = sanitize_text_field( $instance[ 'facts_desc' ] );

		for ( $i = 1; $i <= 4; $i ++ ) {
			$fact_num              = 'fact_num-' . $i;
			$fact                  = 'fact-' . $i;
			$icon                  = 'icon-' . $i;
			$instance[ $fact_num ] = absint( $instance[ $fact_num ] );
			$instance[ $fact ]     = sanitize_text_field( $instance[ $fact ] );
			$instance[ $icon ]     = esc_attr( $instance[ $icon ] );
		} ?>

		<p>
			<label for="<?php echo $this->get_field_id( 'facts_title' ); ?>"><?php _e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'facts_title' ); ?>" name="<?php echo $this->get_field_name( 'facts_title' ); ?>" type="text" value="<?php echo $instance[ 'facts_title' ]; ?>"/>
		</p>

		<?php _e( 'Description:', 'spacious' ); ?>
		<textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id( 'facts_desc' ); ?>" name="<?php echo $this->get_field_name( 'facts_desc' ); ?>"><?php echo $instance[ 'facts_desc' ]; ?></textarea>

		<?php for ( $i = 1; $i <= 4; $i ++ ) {
			$fact_num = 'fact_num-' . $i;
			$fact     = 'fact-' . $i;
			$icon     = 'icon-' . $i;
			?>
			<p>
				<label for="<?php echo $this->get_field_id( $fact_num ); ?>"><?php _e( 'Fact number: ', 'spacious' );
					echo $i; ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( $fact_num ); ?>" name="<?php echo $this->get_field_name( $fact_num ); ?>" type="text" value="<?php echo $instance[ $fact_num ]; ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( $fact ); ?>"><?php _e( 'Fact Detail:', 'spacious' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( $fact ); ?>" name="<?php echo $this->get_field_name( $fact ); ?>" type="text" value="<?php echo $instance[ $fact ]; ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( $icon ); ?>"><?php _e( 'Icon Class:', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( $icon ); ?>" name="<?php echo $this->get_field_name( $icon ); ?>" placeholder="fa-trophy" type="text" value="<?php echo $instance[ $icon ]; ?>"/>
			</p>
			<hr/>
		<?php } ?>

		<p>
			<?php
			$url  = 'http://fontawesome.io/icons/';
			$link = sprintf( __( '<a href="%s" target="_blank">Refer here</a> For Icon Class', 'spacious' ), esc_url( $url ) );
			echo $link;
			?>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance[ 'facts_title' ] = sanitize_text_field( $new_instance[ 'facts_title' ] );

		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'facts_desc' ] = $new_instance[ 'facts_desc' ];
		} else {
			$instance[ 'facts_desc' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'facts_desc' ] ) ) ); // wp_filter_post_kses() expects slashed
		}

		for ( $i = 1; $i <= 4; $i ++ ) {
			$fact_num              = 'fact_num-' . $i;
			$fact                  = 'fact-' . $i;
			$icon                  = 'icon-' . $i;
			$instance[ $fact_num ] = absint( $new_instance[ $fact_num ] );
			$instance[ $fact ]     = sanitize_text_field( $new_instance[ $fact ] );
			$instance[ $icon ]     = sanitize_text_field( $new_instance[ $icon ] );
		}

		return $instance;
	}

	function widget( $args, $instance ) {
		if ( is_active_widget( false, false, $this->id_base ) || is_customize_preview() ) {
			wp_enqueue_script( 'jquery-waypoints' );
			wp_enqueue_script( 'jquery-counterup' );
		}
		extract( $args );
		extract( $instance );

		$facts_title = apply_filters( 'widget_title', isset( $instance[ 'facts_title' ] ) ? $instance[ 'facts_title' ] : '' );
		$facts_desc  = apply_filters( 'widget_text', empty( $instance[ 'facts_desc' ] ) ? '' : $instance[ 'facts_desc' ], $instance );

		echo $before_widget; ?>

		<div class="section-wrapper">
			<div class="tg-container fact clearfix">
				<?php if ( ! empty( $facts_title ) ) {
					echo $before_title . esc_html( $facts_title ) . $after_title;
				}
				if ( ! empty( $facts_desc ) ) { ?>
					<p class="widget-desc"><?php echo esc_textarea( $facts_desc ); ?></p>
				<?php } ?>

				<div class="counter-wrapper">
					<?php
					for ( $i = 1; $i <= 4; $i ++ ) {
						$fact_num = 'fact_num-' . $i;
						$fact     = 'fact-' . $i;
						$icon     = 'icon-' . $i;

						$fact_num = isset( $instance[ $fact_num ] ) ? $instance[ $fact_num ] : '';
						$fact     = isset( $instance[ $fact ] ) ? $instance[ $fact ] : '';
						$icon     = isset( $instance[ $icon ] ) ? $instance[ $icon ] : '';

						// For Multilingual compatibility
						if ( ! empty( $fact ) ) {
							if ( function_exists( 'icl_register_string' ) ) {
								icl_register_string( 'Spacious Pro', 'TG: Fun Facts' . $this->id . $i, $fact );
							}

							if ( function_exists( 'icl_t' ) ) {
								$fact = icl_t( 'Spacious Pro', 'TG: Fun Facts' . $this->id . $i, $fact );
							}
						}

						if ( isset( $fact_num ) ) : ?>
							<div class="counter-block-wrapper clearfix">
								<?php
								echo '<span class="counter-icon"> <i class="fa ' . esc_html( $icon ) . '"></i> </span>';
								echo '<span class="counter">' . $fact_num . '</span>';
								echo '<span class="counter-text">' . esc_html( $fact ) . '</span>';
								?>
							</div>
						<?php endif;
					}
					?>
				</div>
			</div>
		</div>
		<?php
		echo $after_widget;
	}
}

/**************************************************************************************/

/**
 * Pricing Table widget
 */
class spacious_pricing_table_widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'classname'   => 'widget_table_pricing',
			'description' => esc_html__( 'Use this widdget to show the Pricing Table plan. Best for Business Top or Bottom sidebar.', 'spacious' ),
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = esc_html__( 'TG: Pricing Table', 'spacious' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$defaults              = array();
		$defaults[ 'title' ]   = '';
		$defaults[ 'text' ]    = '';
		$defaults[ 'layout' ]  = 1;
		$defaults[ 'col_num' ] = 3;
		for ( $col_count = 0; $col_count < $defaults[ 'col_num' ]; $col_count ++ ) {
			$defaults[ 'package_badge_' . $col_count ]       = '';
			$defaults[ 'package_badge_bg_' . $col_count ]    = '#b50101';
			$defaults[ 'package_name_' . $col_count ]        = '';
			$defaults[ 'package_price_' . $col_count ]       = '';
			$defaults[ 'package_desc_' . $col_count ]        = '';
			$defaults[ 'package_subtitle_' . $col_count ]    = '';
			$defaults[ 'package_feature_num_' . $col_count ] = '4';
			$defaults[ 'package_features_' . $col_count ]    = '';
			$defaults[ 'package_btn_txt_' . $col_count ]     = '';
			$defaults[ 'package_btn_url_' . $col_count ]     = '';
			$defaults[ 'package_color_' . $col_count ]       = '#79cc8c';
		}

		$instance = wp_parse_args( (array) $instance, $defaults );
		$title    = $instance[ 'title' ];
		$text     = $instance[ 'text' ];
		$layout   = $instance[ 'layout' ];
		$col_num  = $instance[ 'col_num' ];
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title:', 'spacious' ); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<?php esc_html_e( 'Description:', 'spacious' ); ?>
		<textarea id="<?php echo $this->get_field_id( 'text' ); ?>" class="widefat" rows="8" cols="20" name="<?php echo $this->get_field_name( 'text' ); ?>"><?php echo esc_textarea( $text ); ?></textarea>
		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Choose style:', 'spacious' ); ?></label><br/>
			<input id="<?php echo $this->get_field_id( 'layout' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'layout' ); ?>" type="radio" <?php checked( $layout, '1' ) ?> value="1"/><?php esc_html_e( 'Style One', 'spacious' ); ?>
			<input id="<?php echo $this->get_field_id( 'layout' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'layout' ); ?>" type="radio" <?php checked( $layout, '2' ) ?> value="2"/><?php esc_html_e( 'Style Two', 'spacious' ); ?>
		</p>

		<p>
			<?php esc_html_e( 'Note: Enter number of columns for Pricing Table (default 3 columns) and save it then enter the data in respective field.', 'spacious' ); ?>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'col_num' ); ?>" class="widefat"><?php esc_html_e( 'Display no of Columns:', 'spacious' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'col_num' ); ?>" name="<?php echo $this->get_field_name( 'col_num' ); ?>">
				<option value="2" <?php echo esc_attr( '2' == $col_num ? 'selected="selected"' : '' ); ?> ><?php esc_html_e( 'Two', 'spacious' ); ?></option>
				<option value="3" <?php echo esc_attr( '3' == $col_num ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Three', 'spacious' ); ?></option>
				<option value="4" <?php echo esc_attr( '4' == $col_num ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Four', 'spacious' ); ?></option>
			</select>
		</p>
		<hr/>
		<?php for ( $col_count = 0; $col_count < $instance[ 'col_num' ]; $col_count ++ ) : ?>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_name_' . $col_count ); ?>"><?php esc_html_e( 'Title :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_name_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_name_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_name_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_price_' . $col_count ); ?>"><?php esc_html_e( 'Price :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_price_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_price_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_price_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_desc_' . $col_count ); ?>"><?php esc_html_e( 'Description :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_desc_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_desc_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_desc_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_subtitle_' . $col_count ); ?>"><?php esc_html_e( 'Sub Title :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_subtitle_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_subtitle_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_subtitle_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_badge_' . $col_count ); ?>"><?php esc_html_e( 'Badge :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_badge_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_badge_' . $col_count ); ?>" type="text" maxlength="9" value="<?php echo esc_attr( $instance[ 'package_badge_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_badge_bg_' . $col_count ); ?>"><?php esc_html_e( 'Badge background :', 'spacious' ); ?></label><br/>
				<input id="<?php echo $this->get_field_id( 'package_badge_bg_' . $col_count ); ?>" class="widefat tg-color-picker" name="<?php echo $this->get_field_name( 'package_badge_bg_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_badge_bg_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<?php esc_html_e( 'Note: Enter the number of features to display in column (default 4 features) and save it then enter the data in respective field.', 'spacious' ); ?>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_feature_num_' . $col_count ); ?>"><?php esc_html_e( 'Number of features to display :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_feature_num_' . $col_count ); ?>" class="tiny-text" step="1" min="1" name="<?php echo $this->get_field_name( 'package_feature_num_' . $col_count ); ?>" type="number" value="<?php echo absint( $instance[ 'package_feature_num_' . $col_count ] ); ?>"/>
			</p>

			<p><?php esc_html_e( 'Features :', 'spacious' ); ?></p>

			<?php for ( $feature_count = 0; $feature_count < $instance[ 'package_feature_num_' . $col_count ]; $feature_count ++ ) : ?>
				<p>
					<label for="<?php echo $this->get_field_id( 'package_features_' . $col_count ); ?>[<?php echo absint( $feature_count ); ?>]"></label>
					<input id="<?php echo $this->get_field_id( 'package_features_' . $col_count ); ?>[<?php echo absint( $feature_count ); ?>]" class="widefat" name="<?php echo $this->get_field_name( 'package_features_' . $col_count ); ?>[]" type="text" value="<?php if ( isset( $instance[ 'package_features_' . $col_count ][ $feature_count ] ) ) {
						echo esc_attr( $instance[ 'package_features_' . $col_count ][ $feature_count ] );
					} ?>"/>
				</p>
			<?php endfor; ?>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_btn_txt_' . $col_count ); ?>"><?php esc_html_e( 'Button Text :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_btn_txt_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_btn_txt_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_btn_txt_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_btn_url_' . $col_count ); ?>"><?php esc_html_e( 'Button URL :', 'spacious' ); ?></label>
				<input id="<?php echo $this->get_field_id( 'package_btn_url_' . $col_count ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'package_btn_url_' . $col_count ); ?>" type="text" value="<?php echo esc_url( $instance[ 'package_btn_url_' . $col_count ] ); ?>"/>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'package_color_' . $col_count ); ?>"><?php esc_html_e( 'Color :', 'spacious' ); ?></label><br/>
				<input id="<?php echo $this->get_field_id( 'package_color_' . $col_count ); ?>" class="widefat tg-color-picker" name="<?php echo $this->get_field_name( 'package_color_' . $col_count ); ?>" type="text" value="<?php echo esc_attr( $instance[ 'package_color_' . $col_count ] ); ?>"/>
			</p>

			<hr>
		<?php endfor; ?>

		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance[ 'title' ]   = sanitize_text_field( $new_instance[ 'title' ] );
		$instance[ 'layout' ]  = absint( $new_instance[ 'layout' ] );
		$instance[ 'col_num' ] = absint( $new_instance[ 'col_num' ] );

		for ( $col_count = 0; $col_count < $instance[ 'col_num' ]; $col_count ++ ) {
			$instance[ 'package_badge_' . $col_count ]       = sanitize_text_field( $new_instance[ 'package_badge_' . $col_count ] );
			$instance[ 'package_badge_bg_' . $col_count ]    = isset( $new_instance[ 'package_badge_bg_' . $col_count ] ) ? esc_attr( $new_instance[ 'package_badge_bg_' . $col_count ] ) : '#b50101';
			$instance[ 'package_name_' . $col_count ]        = sanitize_text_field( $new_instance[ 'package_name_' . $col_count ] );
			$instance[ 'package_price_' . $col_count ]       = sanitize_text_field( $new_instance[ 'package_price_' . $col_count ] );
			$instance[ 'package_desc_' . $col_count ]        = sanitize_text_field( $new_instance[ 'package_desc_' . $col_count ] );
			$instance[ 'package_subtitle_' . $col_count ]    = sanitize_text_field( $new_instance[ 'package_subtitle_' . $col_count ] );
			$instance[ 'package_feature_num_' . $col_count ] = isset( $new_instance[ 'package_feature_num_' . $col_count ] ) ? absint( $new_instance[ 'package_feature_num_' . $col_count ] ) : 4;
			$instance[ 'package_btn_txt_' . $col_count ]     = sanitize_text_field( $new_instance[ 'package_btn_txt_' . $col_count ] );
			$instance[ 'package_btn_url_' . $col_count ]     = esc_url_raw( $new_instance[ 'package_btn_url_' . $col_count ] );
			$instance[ 'package_color_' . $col_count ]       = isset( $new_instance[ 'package_color_' . $col_count ] ) ? esc_attr( $new_instance[ 'package_color_' . $col_count ] ) : '#79cc8c';
			$col_features                                    = 'package_features_' . $col_count;
			$instance[ $col_features ]                       = array();
			if ( isset( $new_instance[ $col_features ] ) ) {
				foreach ( $new_instance[ $col_features ] as $feature ) {
					$instance[ $col_features ][] = sanitize_text_field( $feature );
				}
			}
		}
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'text' ] = $new_instance[ 'text' ];
		} else {
			$instance[ 'text' ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'text' ] ) ) );
		} // wp_filter_post_kses() expects slashed

		return $instance;
	}

	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );
		$title = apply_filters( 'widget_title', empty( $instance[ 'title' ] ) ? '' : $instance[ 'title' ], $instance );
		$text  = isset( $instance[ 'text' ] ) ? $instance[ 'text' ] : '';
		// For WPML plugin compatibility
		if ( function_exists( 'icl_register_string' ) && ! empty( $text ) ) {
			icl_register_string( 'Spacious Pro', 'TG: Pricing Table widget description text' . $this->id, $text );
		}
		$layout        = empty( $instance[ 'layout' ] ) ? '1' : $instance[ 'layout' ];
		$col_num       = empty( $instance[ 'col_num' ] ) ? '3' : $instance[ 'col_num' ];
		$badge         = array();
		$badge_bg      = array();
		$packages      = array();
		$prices        = array();
		$package_descs = array();
		$subtitles     = array();
		$feature_num   = array();
		$features      = array();
		$btn_text      = array();
		$btn_URL       = array();
		$colors        = array();
		for ( $col_count = 0; $col_count < $col_num; $col_count ++ ) {
			$badge[]         = isset( $instance[ 'package_badge_' . $col_count ] ) ? $instance[ 'package_badge_' . $col_count ] : '';
			$badge_bg[]      = isset( $instance[ 'package_badge_bg_' . $col_count ] ) ? $instance[ 'package_badge_bg_' . $col_count ] : '';
			$packages[]      = isset( $instance[ 'package_name_' . $col_count ] ) ? $instance[ 'package_name_' . $col_count ] : '';
			$prices[]        = isset( $instance[ 'package_price_' . $col_count ] ) ? $instance[ 'package_price_' . $col_count ] : '';
			$package_descs[] = isset( $instance[ 'package_desc_' . $col_count ] ) ? $instance[ 'package_desc_' . $col_count ] : '';
			$subtitles[]     = isset( $instance[ 'package_subtitle_' . $col_count ] ) ? $instance[ 'package_subtitle_' . $col_count ] : '';
			$feature_num[]   = isset( $instance[ 'package_feature_num_' . $col_count ] ) ? $instance[ 'package_feature_num_' . $col_count ] : '';
			$btn_text[]      = isset( $instance[ 'package_btn_txt_' . $col_count ] ) ? $instance[ 'package_btn_txt_' . $col_count ] : '';
			$btn_URL[]       = isset( $instance[ 'package_btn_url_' . $col_count ] ) ? $instance[ 'package_btn_url_' . $col_count ] : '';
			$colors[]        = isset( $instance[ 'package_color_' . $col_count ] ) ? $instance[ 'package_color_' . $col_count ] : '';
			$features[]      = isset( $instance[ 'package_features_' . $col_count ] ) ? $instance[ 'package_features_' . $col_count ] : '';

			// For WPML plugin compatibility
			if ( function_exists( 'icl_register_string' ) && ! empty( $packages ) ) {
				icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Title' . $this->id . $col_count, $packages[ $col_count ] );
				if ( ! empty( $prices ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Price' . $this->id . $col_count, $prices[ $col_count ] );
				}
				if ( ! empty( $package_descs ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Description' . $this->id . $col_count, $package_descs[ $col_count ] );
				}
				if ( ! empty( $subtitles ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Sub Title' . $this->id . $col_count, $subtitles[ $col_count ] );
				}
				if ( ! empty( $badge ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Badge' . $this->id . $col_count, $badge[ $col_count ] );
				}
				if ( ! empty( $btn_text ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Pricing Table Package Button Text' . $this->id . $col_count, $btn_text[ $col_count ] );
				}
				if ( ! empty( $features ) ) {
					foreach ( $features[ $col_count ] as $key => $value ) {
						icl_register_string( 'Spacious Pro', 'TG: Pricing Table Table Features' . $this->id . $col_count . $key, $value );
					}
				}
			}
		}
		echo $before_widget; ?>

		<div class="section-wrapper">

			<div class="tg-container pricing-table pricing-column-<?php echo esc_attr( $col_num ); ?> pricing-table-layout-<?php echo esc_attr( $layout ); ?> clearfix">
				<?php if ( ! empty( $title ) ) : ?>
					<h3 class="widget-title"><?php echo esc_html( $title ); ?></h3>
				<?php endif; ?>

				<?php if ( ! empty( $text ) ) : ?>
					<p class="widget-desc"><?php
						// For WPML plugin compatibility
						if ( function_exists( 'icl_t' ) ) {
							$text = icl_t( 'Spacious Pro', 'TG: Pricing Table widget description text' . $this->id, $text );
						}
						echo esc_textarea( $text ); ?></p>
				<?php endif; ?>

				<?php if ( ! empty( $packages ) ) : ?>

					<?php for ( $col_count = 0; $col_count < $col_num; $col_count ++ ) :
						$item = $col_count + 1;
						$column_class = '';
						if ( $col_num == 2 ) :
							if ( $item % 2 == 0 ) {
								$column_class = 'tg-one-half tg-one-half-last';
							} else {
								$column_class = 'tg-one-half';
							}
						elseif ( $col_num == 3 ) :
							if ( $item % 3 == 0 ) {
								$column_class = "tg-one-third tg-one-third-last";
							} else {
								$column_class = "tg-one-third";
							}
						elseif ( $col_num == 4 ) :
							if ( $item % 4 == 0 ) {
								$column_class = 'tg-one-fourth tg-one-fourth-last';
							} else {
								$column_class = 'tg-one-fourth';
							}
						endif;
						?>
						<div class="<?php echo esc_attr( $column_class ) ?>">
							<?php if ( ! empty( $colors ) || ! empty( $badge_bg ) ) {
								$dark_color = spacious_darkcolor( $colors[ $col_count ], - 20 ); ?>
								<!-- Widget CSS -->
								<style type="text/css">
									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-title,

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-price,

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-btn a {
										background: <?php echo esc_attr( $colors[ $col_count ] ) ?>;
									}

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-price:after {
										border-top-color: <?php echo esc_attr( $colors[ $col_count ] ) ?>;
									}

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-subtitle {
										color: <?php echo esc_attr( $colors[ $col_count ] ) ?>;
									}

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-layout-2 .pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-title,

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-btn a:hover {
										background: <?php echo esc_attr( $dark_color ) ?>;
									}

									#
									<?php echo esc_attr( $this->id ); ?>
									.pricing-table-wrapper-<?php echo absint( $col_count ); ?> .pricing-as-popular {
										background: <?php echo esc_attr( $badge_bg[ $col_count ] ) ?>;
									}
								</style>
							<?php } ?>

							<?php if ( $packages[ $col_count ] != '' ) : ?>
								<div class="pricing-table-wrapper-<?php echo absint( $col_count ); ?> pricing-table-wrapper">
									<?php if ( $badge[ $col_count ] ) :
										// For WPML plugin compatibility
										if ( function_exists( 'icl_t' ) ) {
											$badge[ $col_count ] = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Badge' . $this->id . $col_count, $badge[ $col_count ] );
										} ?>
										<span class="pricing-as-popular"><?php echo esc_html( $badge[ $col_count ] ); ?></span>
									<?php endif; ?>

									<?php // For WPML plugin compatibility
									if ( function_exists( 'icl_t' ) ) {
										$packages[ $col_count ] = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Name' . $this->id . $col_count, $packages[ $col_count ] );
									} ?>
									<?php if ( ! empty( $packages[ $col_count ] ) ) : ?>
										<h4 class="pricing-title"><?php echo esc_html( $packages[ $col_count ] ); ?></h4>
									<?php endif; ?>

									<?php // For WPML plugin compatibility
									if ( function_exists( 'icl_t' ) ) {
										$prices[ $col_count ]        = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Price' . $this->id . $col_count, $prices[ $col_count ] );
										$package_descs[ $col_count ] = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Description' . $this->id . $col_count, $package_descs[ $col_count ] );

									} ?>

									<?php if ( ! empty( $packages[ $col_count ] ) || ! empty( $prices[ $col_count ] ) || ! empty( $package_descs[ $col_count ] ) ) : ?>
										<div class="pricing-price">
											<span class="pricing-currnecy"><?php echo esc_html( $prices[ $col_count ] ); ?></span><span class="pricing-date"><?php echo esc_html( $package_descs[ $col_count ] ); ?></span>
										</div>
									<?php endif; ?>
									<?php if ( ! empty( $feature_num ) || ! empty( $subtitles[ $col_count ] ) ) : ?>
										<ul class="pricing-list-wrapper">
											<?php // For WPML plugin compatibility
											if ( function_exists( 'icl_t' ) ) {
												$subtitles[ $col_count ] = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Subname' . $this->id . $col_count, $subtitles[ $col_count ] );
											}
											if ( $subtitles[ $col_count ] != '' ) : ?>
												<span class="pricing-subtitle"><?php echo esc_html( $subtitles[ $col_count ] ); ?></span>
											<?php endif; ?>
											<?php if ( ! empty( $features[ $col_count ] ) ) :
												foreach ( $features[ $col_count ] as $key => $value ) {
													if ( $value != '' ) {
														// For WPML plugin compatibility
														if ( function_exists( 'icl_t' ) ) {
															$value = icl_t( 'Spacious Pro', 'TG: Pricing Table Table Features' . $this->id . $col_count . $key, $value );
														}
														echo '<li class="pricing-list">' . esc_html( $value ) . '</li>';
													}
												}
											endif; ?>
										</ul>
									<?php endif; ?>

									<?php // For WPML plugin compatibility
									if ( function_exists( 'icl_t' ) ) {
										$btn_text[ $col_count ] = icl_t( 'Spacious Pro', 'TG: Pricing Table Package Button Text' . $this->id . $col_count, $btn_text[ $col_count ] );
									} ?>

									<?php if ( ! empty( $btn_text[ $col_count ] ) ) : ?>
										<div class="pricing-btn">
											<a href="<?php echo esc_url( $btn_URL[ $col_count ] ); ?>"><?php echo esc_html( $btn_text[ $col_count ] ); ?></a>
										</div>
									<?php endif; ?>
								</div><!-- pricing-table-wrapper -->
								<?php $item ++; endif; ?>
						</div> <!-- end of column -->
					<?php endfor; ?>
				<?php endif; ?>
			</div>
		</div>

		<?php echo $after_widget;
	}
}

/**************************************************************************************/

/**
 * Spacious class to implement a Accordian widget
 *
 * @since 2.1.5
 */
class spacious_accordian_widget extends WP_Widget {

	/**
	 * Sets up a new Accordian widget instance.
	 *
	 * @since  2.1.5
	 * @access public
	 */
	public function __construct() {
		$widget_ops  = array(
			'classname'                   => 'tg_widget_accordian',
			'description'                 => esc_html__( 'Show a Accordian.', 'spacious' ),
			'customize_selective_refresh' => true,
		);
		$control_ops = array( 'width' => 200, 'height' => 250 );
		parent::__construct( false, $name = esc_html__( 'TG: Accordian', 'spacious' ), $widget_ops, $control_ops );
	}

	/**
	 * Outputs the content of the Accordian widget
	 *
	 * @since  2.1.5
	 * @access public
	 *
	 * @param  array $args     Arguments including 'before_title', 'after_title'
	 * @param  array $instance Settings for the current Accordian widget instance.
	 */
	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );

		$accordian_title = apply_filters( 'widget_title', isset( $instance[ 'accordian_title' ] ) ? $instance[ 'accordian_title' ] : '' );
		$accordian_desc  = apply_filters( 'widget_text', isset( $instance[ 'accordian_desc' ] ) ? $instance[ 'accordian_desc' ] : '' );
		$accordian_count = isset( $instance[ 'accordian_count' ] ) ? absint( $instance[ 'accordian_count' ] ) : 1;

		// Ready array for WPML plugin compatibility
		$accordian_item_heading_arr = array();
		$accordian_item_content_arr = array();

		for ( $i = 1; $i <= $accordian_count; $i ++ ) {
			$accordian_item_heading_name = 'accordian_item_heading_' . $i;
			$accordian_item_content_name = 'accordian_item_content_' . $i;

			$accordian_item_heading = isset( $instance[ $accordian_item_heading_name ] ) ? $instance[ $accordian_item_heading_name ] : '';
			$accordian_item_content = isset( $instance[ $accordian_item_content_name ] ) ? $instance[ $accordian_item_content_name ] : '';

			array_push( $accordian_item_heading_arr, $accordian_item_heading );
			array_push( $accordian_item_content_arr, $accordian_item_content );

			// For WPML plugin compatibility
			if ( function_exists( 'icl_register_string' && ! empty( $accordian_item_heading ) ) ) {
				if ( ! empty( $accordian_item_heading ) ) {
					icl_register_string( 'Spacious Pro', 'TG: Accordian widget item heading ' . $this->id . ( $i - 1 ), $accordian_item_heading_arr[ $i - 1 ] );
					icl_register_string( 'Spacious Pro', 'TG: Accordian widget item content ' . $this->id . ( $i - 1 ), $accordian_item_content_arr[ $i - 1 ] );
				}
			}
		}

		echo $before_widget;

		if ( ! empty( $accordian_title ) ) {
			echo $before_title . esc_html( $accordian_title ) . $after_title;
		}
		?>
		<?php if ( ! empty( $accordian_desc ) ) { ?>
			<p class="widget-desc">
				<?php echo esc_textarea( $accordian_desc ); ?>
			</p>
		<?php } ?>

		<?php if ( ! empty( $accordian_item_heading_arr ) ) { ?>
			<div id="tg-accordion" class="tg-accordion">

				<?php
				for ( $i = 1; $i <= $accordian_count; $i ++ ) :
					if ( ! empty( $accordian_item_heading_arr[ $i - 1 ] ) ) {
						if ( function_exists( 'icl_t' ) ) {
							$accordian_item_heading_arr[ $i - 1 ] = icl_t( 'Spacious Pro', 'TG: Accordian widget item heading ' . $this->id . ( $i - 1 ), $accordian_item_heading_arr[ $i - 1 ] );
							$accordian_item_content_arr[ $i - 1 ] = icl_t( 'Spacious Pro', 'TG: Accordian widget item content ' . $this->id . ( $i - 1 ), $accordian_item_content_arr[ $i - 1 ] );
						}
						?>
						<div class="accordian-item">
							<div class="accordian-header">
								<?php echo esc_html( $accordian_item_heading_arr[ $i - 1 ] ); ?>
								<i class="fa fa-angle-down" aria-hidden="true"></i>
							</div> <!-- /.accordian-header -->
							<div class="accordian-content"><?php echo esc_html( $accordian_item_content_arr[ $i - 1 ] ); ?></div>
						</div> <!-- /.accordian-item -->
					<?php } ?>
				<?php endfor; ?>

			</div> <!-- /#tg-accordion-wrapper -->
		<?php } ?>


		<?php echo $after_widget;
	}

	/**
	 * Updates settings for the Accordian widget instance.
	 *
	 * @since  2.1.5
	 * @access public
	 *
	 * @param array $new_instance
	 * @param array $old_instance
	 *
	 * @return array Updated settings to save.
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;

		$instance[ 'accordian_title' ] = sanitize_text_field( $new_instance[ 'accordian_title' ] );

		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance[ 'accordian_desc' ] = $new_instance[ 'accordian_desc' ];
		} else {
			$instance[ 'accordian_desc' ] = force_balance_tags( stripslashes( wp_filter_post_kses( addslashes( $new_instance[ 'accordian_desc' ] ) ) ) );
		}

		$instance[ 'accordian_count' ] = absint( $new_instance[ 'accordian_count' ] );
		$accordian_count               = $instance[ 'accordian_count' ];

		for ( $i = 1; $i <= $accordian_count; $i ++ ) {
			$heading_field_name = 'accordian_item_heading_' . $i;
			$content_field_name = 'accordian_item_content_' . $i;

			$instance[ $heading_field_name ] = sanitize_text_field( $new_instance[ $heading_field_name ] );

			if ( current_user_can( 'unfiltered_html' ) ) {
				$instance[ $content_field_name ] = $new_instance[ $content_field_name ];
			} else {
				$instance[ $content_field_name ] = stripslashes( wp_filter_post_kses( addslashes( $new_instance[ $content_field_name ] ) ) );
			}
		}

		return $instance;
	}

	/**
	 * Outputs the settings form for the Accordian widget.
	 *
	 * @since  2.1.5
	 * @access public
	 *
	 * @param  array $instance Current settings.
	 */
	function form( $instance ) {
		$defaults = array(
			'accordian_title' => '',
			'accordian_desc'  => '',
			'accordian_count' => 1,
		);

		$accordian_count = isset( $instance[ 'accordian_count' ] ) ? absint( $instance[ 'accordian_count' ] ) : 1;

		for ( $i = 1; $i <= $accordian_count; $i ++ ) {
			$heading_field_name = 'accordian_item_heading_' . $i;
			$content_field_name = 'accordian_item_content_' . $i;

			$defaults[ $heading_field_name ] = '';
			$defaults[ $content_field_name ] = '';
		}

		$instance               = wp_parse_args( (array) $instance, $defaults );
		?>
		<!-- Accordian title -->
		<p>
			<label for="<?php echo $this->get_field_id( 'accordian_title' ); ?>">
				<?php esc_html_e( 'Title:', 'spacious' ); ?>
			</label>
			<input type="text" name="<?php echo $this->get_field_name( 'accordian_title' ) ?>" id="<?php echo $this->get_field_id( 'accordian_title' ); ?>" value="<?php echo esc_html( $instance[ 'accordian_title' ] ); ?>" class="widefat"/>
		</p>

		<!-- Accordian description -->
		<p>
			<label for="<?php echo $this->get_field_id( 'accordian_desc' ); ?>">
				<?php esc_html_e( 'Description:', 'spacious' ); ?>
			</label>
			<textarea rows="5" name="<?php echo $this->get_field_name( 'accordian_desc' ); ?>" id="<?php echo $this->get_field_id( 'accordian_desc' ) ?>" class="widefat"><?php echo esc_textarea( $instance[ 'accordian_desc' ] ); ?></textarea>
		</p>

		<!-- Number of accordian -->
		<p>
			<label for="<?php echo $this->get_field_id( 'accordian_count' ); ?>">
				<?php esc_html_e( 'Number of accordian to show:', 'spacious' ); ?>
			</label>
			<input type="number" min="1" name="<?php echo $this->get_field_name( 'accordian_count' ) ?>" id="<?php echo $this->get_field_id( 'accordian_count' ); ?>" value="<?php echo $accordian_count; ?>" class="widefat"/>
		</p>

		<!-- Accordian -->
		<?php
		for ( $i = 1; $i <= $accordian_count; $i ++ ) :
			$heading_field_name = 'accordian_item_heading_' . $i;
			$content_field_name = 'accordian_item_content_' . $i;
			?>
			<div class="tg-accordian-wrapper">
				<p>
					<label for="<?php echo $this->get_field_id( $heading_field_name ) ?>"><?php esc_html_e( 'Accordian heading:', 'spacious' ); ?></label>
					<input type="text" name="<?php echo $this->get_field_name( $heading_field_name ) ?>" id="<?php echo $this->get_field_id( $heading_field_name ); ?>" value="<?php echo esc_attr( $instance[ $heading_field_name ] ); ?>" class="widefat"/>
				</p>
				<p>
					<label for="<?php echo $this->get_field_id( $content_field_name ) ?>"><?php esc_html_e( 'Accordian content:', 'spacious' ); ?></label>
					<textarea rows="5" name="<?php echo $this->get_field_name( $content_field_name ); ?>" id="<?php echo $this->get_field_id( $content_field_name ) ?>" class="widefat"><?php echo esc_textarea( $instance[ $content_field_name ] ); ?></textarea>
				</p>
			</div> <!-- /.accordian-wrapper -->
		<?php endfor; ?>

		<?php
	}
}
